/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.controls;

import java.awt.Toolkit;

import javax.swing.text.AttributeSet;
import javax.swing.text.BadLocationException;
import javax.swing.text.PlainDocument;

/**
 * Document class only for double values.
 * 
 * @author Ralf Ratering
 * @version $Id: DoubleDocument.java,v 1.1 2004/05/25 14:58:54 rmenday Exp $
 * @see DoubleTextField
 */
class DoubleDocument extends PlainDocument {

	private double min, max;

	/**
	 * Constructor initializes with min and max
	 * 
	 * @param min
	 *            minimal value
	 * @param max
	 *            maximal value
	 */
	public DoubleDocument(double min, double max) {
		this.min = min;
		this.max = max;
	}

	/**
	 * Overwrites the function "insertString" of class PlainDocument for int
	 * only input.
	 * 
	 * @param offset
	 *            >=0 where String should be inserted
	 * @param str
	 *            String to insert
	 * @param a
	 *            attributes for inserted content
	 * @exception BadLocationException
	 *                Description of Exception
	 */
	public void insertString(int offset, String str, AttributeSet a)
			throws BadLocationException {
		boolean valid = true;
		String tmp = getText(0, offset) + str
				+ getText(offset, getLength() - offset);
		if (min >= 0 || (!tmp.equals("-"))) {
			try {
				double i = Double.parseDouble(tmp);
			}
			catch (NumberFormatException e) {
				valid = false;
			}
		}
		if (valid) {
			// if all right put the digit on screen
			super.insertString(offset, str, a);
		}
		else {
			// beep if wrong input
			Toolkit.getDefaultToolkit().beep();
		}
	}

	/**
	 * Set Maximum
	 * 
	 * @param max
	 *            maximum
	 */
	public void setMaximum(double max) {
		this.max = max;
	}

	/**
	 * Set Minimum
	 * 
	 * @param min
	 *            minimum
	 */
	public void setMinimum(double min) {
		this.min = min;
	}
}