/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.controls;

import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JTextField;

/**
 * Text field only for double. A beep indicates a wrong input try.
 * 
 * @author Ralf Ratering
 * @version $Id: DoubleTextField.java,v 1.1 2004/05/25 14:58:54 rmenday Exp $
 */
public class DoubleTextField extends JTextField {

	/**
	 * Minimal main
	 * 
	 * @param args
	 *            The command line arguments
	 */
	public static void main(String[] args) {
		Box panel = new Box(BoxLayout.Y_AXIS);
		panel.add(new DoubleTextField(-10., 200.));
		panel.add(new DoubleTextField("-0.1", -0.5, 10.0));
		JPanel subPanel = new JPanel();
		subPanel.add(panel);
		JFrame frame = new JFrame();
		frame.getContentPane().add(subPanel);
		frame.setSize(400, 400);
		frame.show();
	}
	private double min, max;

	/**
	 * Constructor sets length of textfield according to min and max value. This
	 * class does not perform a range check!
	 * 
	 * @param min
	 *            minimal value
	 * @param max
	 *            maximal value
	 */
	public DoubleTextField(double min, double max) {
		this(null, min, max);
	}

	/**
	 * Constructor sets length of textfield according to min and max value and
	 * initializes it with a double value This class does not perform a range
	 * check!
	 * 
	 * @param start
	 *            initial double value
	 * @param min
	 *            minimal value
	 * @param max
	 *            maximal value
	 */
	public DoubleTextField(double start, int min, int max) {
		super(new DoubleDocument(min, max), new Double(start).toString(), Math
				.max(("" + min).length(), ("" + max).length()));
		this.min = min;
		this.max = max;
	}

	/**
	 * Constructor sets length of textfield according to min and max value and
	 * initializes it with a String. This class does not perform a range check!
	 * 
	 * @param text
	 *            String that should contain a double value
	 * @param min
	 *            minimal value
	 * @param max
	 *            maximal value
	 */
	public DoubleTextField(String text, double min, double max) {
		super(new DoubleDocument(min, max), text, Math.max(("" + min).length(),
				("" + max).length()));
		this.min = min;
		this.max = max;
	}

	/**
	 * Get double value from textfield
	 * 
	 * @return String from textfield as double value
	 */
	public double getValue() {
		if (getText().equals("")) {
			setValue(0.0);
		}
		return Double.parseDouble(getText());
	}

	/**
	 * Set maximal value and adjust textfield length
	 * 
	 * @param max
	 *            new maximal value
	 */
	public void setMaximum(double max) {
		this.max = max;
		// convert min and max to String by adding ""
		setColumns(Math.max(("" + min).length(), ("" + max).length()));
		((DoubleDocument) getDocument()).setMaximum(max);
	}

	/**
	 * Set minimal value and adjust textfield length
	 * 
	 * @param min
	 *            new minimal value
	 */
	public void setMinimum(double min) {
		this.min = min;
		// convert min and max to String by adding ""
		setColumns(Math.max(("" + min).length(), ("" + max).length()));
		((DoubleDocument) getDocument()).setMinimum(min);
	}

	/**
	 * Set textfield to an double value
	 * 
	 * @param value
	 *            new integer value
	 */
	public void setValue(double value) {
		setText((new Double(value)).toString());
	}
}