/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.controls;

import java.awt.BorderLayout;
import java.awt.Dialog;
import java.awt.Frame;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.logging.Logger;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JProgressBar;
import javax.swing.JSlider;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

/**
 * @author Ralf Ratering
 * @version $Id: IndeterminateProgressMonitor.java,v 1.2 2003/06/30 06:52:10
 *          rrate Exp $
 */
public class IndeterminateProgressMonitor extends JDialog {

	private static Logger logger = Logger
			.getLogger("com.pallas.unicore.client.controls");

	public static void main(String args[]) {
		final IndeterminateProgressMonitor progressMonitor = new IndeterminateProgressMonitor(
				new Frame());
		progressMonitor.setLabel("Unknown process in unknown progress.....");
		JButton startButton = new JButton("Start");
		startButton.addActionListener(new ActionListener() {

			public void actionPerformed(ActionEvent evt) {
				progressMonitor.show();
			}
		});
		JButton stopButton = new JButton("Stop");
		stopButton.addActionListener(new ActionListener() {

			public void actionPerformed(ActionEvent evt) {
				progressMonitor.dispose();
			}
		});
		final JSlider fpsSlider = new JSlider(1, 30, 3);
		final JLabel fpsLabel = new JLabel("FPS: ");
		final JFrame frame = new JFrame("Test ProgressMonitor");
		fpsSlider.addChangeListener(new ChangeListener() {

			public void stateChanged(ChangeEvent e) {
				fpsLabel.setText("FPS: " + fpsSlider.getValue());
				frame.pack();
				if (fpsSlider.getValueIsAdjusting()) {
					return;
				}
			}
		});
		JPanel buttonPanel = new JPanel();
		buttonPanel.add(startButton);
		buttonPanel.add(stopButton);
		JPanel sliderPanel = new JPanel();
		sliderPanel.add(fpsLabel);
		sliderPanel.add(fpsSlider);
		frame.getContentPane().add(buttonPanel, BorderLayout.CENTER);
		frame.getContentPane().add(sliderPanel, BorderLayout.SOUTH);
		frame.pack();
		frame.show();
	}
	private JProgressBar progressBar = new JProgressBar();

	public IndeterminateProgressMonitor(Dialog parent) {
		super(parent, false);
		initComponents();
	}

	public IndeterminateProgressMonitor(Frame parent) {
		super(parent, false);
		initComponents();
	}

	private void initComponents() {
		progressBar.setIndeterminate(true);
		progressBar.setStringPainted(true);
		getContentPane().add(progressBar, BorderLayout.CENTER);
		pack();
	}

	public void pack() {
		super.pack();
		setLocationRelativeTo(getParent());
	}

	public void setLabel(String message) {
		progressBar.setString(message);
		pack();
	}
}