/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.dialogs;

import java.awt.BorderLayout;
import java.awt.GridLayout;
import java.util.ResourceBundle;

import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.border.EmptyBorder;

/**
 *  Dialog to login with alias and password.
 *
 *@author     Ralf Ratering
 *@version    $Id: ChangeAliasDialog.java,v 1.1 2004/05/25 14:58:47 rmenday Exp $
 */
public class ChangeAliasDialog extends GenericDialog {
	static ResourceBundle res = ResourceBundle.getBundle("com.pallas.unicore.client.dialogs.ResourceStrings");
	private JTextField oldAliasField = new JTextField(15);
	private String alias;


	/**
	 *  Constructor builds gui and sets a title
	 *
	 *@param  title   dialog title
	 *@param  parent  dialog parent - important for modal dialogs
	 */
	public ChangeAliasDialog(JFrame parent, String title, String oldAlias) {
		// build generic dialog, assumed to be always modal
		super(parent, title, true, OK_CANCEL);
		alias = oldAlias;
		buildComponents();
		pack();
	}


	/**
	 *  Get the entered user name
	 *
	 *@return    name as string
	 */
	public String getAlias() {
		return alias;
	}



	/**
	 *  Put focus into password field and make okButton default
	 */
	public void show() {
		oldAliasField.requestFocus();
		super.show();
	}


	/**
	 *  Sets password to null
	 *
	 *@return    true if dialog can be disposed
	 */
	protected boolean cancelValues() {
		return true;
	}


	/**
	 *  Takes current textfield entry as password
	 *
	 *@return    true if dialog can be disposed
	 */
	protected boolean applyValues() {
		alias = oldAliasField.getText();
		return true;
	}


	/**
	 *  Add a password field to the parent dialog
	 */
	private void buildComponents() {
		JLabel aliasLabel = new JLabel(res.getString("CHANGE_ALIAS"));

		JPanel aliasPanel = new JPanel();
		aliasPanel.add(aliasLabel);
		aliasPanel.add(oldAliasField);
		oldAliasField.setText(alias);

		JPanel subPanel = new JPanel(new GridLayout(1, 1, 10, 10));
		subPanel.add(aliasPanel);

        // add some spacing around
        subPanel.setBorder(new EmptyBorder(5, 20, 5, 20));

		getContentPane().add(subPanel, BorderLayout.CENTER);
	}


	/**
	 *  Minimal main
	 *
	 *@param  args  The command line arguments
	 */
	public static void main(String[] args) {
		JFrame frame = new JFrame();
		frame.setSize(400, 400);
		frame.show();

		ChangeAliasDialog dialog = new ChangeAliasDialog(frame, "TEST: PasswordDialog","test");
		dialog.show();
	}
}
