/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.dialogs;

import java.awt.BorderLayout;
import java.awt.Color;
import java.util.ResourceBundle;
import javax.swing.JFrame;
import javax.swing.JScrollPane;
import com.pallas.unicore.client.graphs.DependencyEditor;
import com.pallas.unicore.container.GroupContainer;

/**
 * Simple dialog to display a dependency graph
 * 
 * @author Ralf Ratering
 * @version $Id: DependencyViewer.java,v 1.1 2004/05/25 14:58:47 rmenday Exp $
 */
public class DependencyViewer extends GenericDialog {

	static ResourceBundle res = ResourceBundle
			.getBundle("com.pallas.unicore.client.dialogs.ResourceStrings");
	private DependencyEditor dependencyDisplay;

	/**
	 * Constructor
	 * 
	 * @param parentFrame
	 *            reference to parent JFrame
	 * @param container
	 *            Description of the Parameter
	 */
	public DependencyViewer(JFrame parentFrame, GroupContainer container) {
		super(parentFrame, res.getString("UNICORE_JMC"), true, OK);
		dependencyDisplay = new DependencyEditor(container);
		dependencyDisplay.setBackground(new Color(0, 100, 200));
		dependencyDisplay.setColor(Color.white);
		dependencyDisplay.setSelectionColor(Color.green);
		dependencyDisplay.updateValues();
		JScrollPane scrollPane = new JScrollPane(dependencyDisplay);
		getContentPane().add(scrollPane, BorderLayout.CENTER);
		setResizable(true);
		setSize(400, 400);
	}

	/**
	 * React to OK button
	 * 
	 * @return true always
	 */
	protected boolean applyValues() {
		return true;
	}

	/**
	 * Overwrite method from super class
	 * 
	 * @return true always
	 */
	protected boolean cancelValues() {
		return true;
	}
}