/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.dialogs;

import java.awt.BorderLayout;
import java.awt.Frame;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ResourceBundle;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import com.pallas.unicore.client.panels.ResourceInfoPanel;
import com.pallas.unicore.client.panels.ResourceRequestInfoPanel;
import com.pallas.unicore.extensions.NamedResourceSet;

/**
 * Dialog that displays site resources for a vsite
 * 
 * @author Ralf Ratering
 * @version $Id: ResourceInfoDialog.java,v 1.1 2004/05/25 14:58:47 rmenday Exp $
 */
public class ResourceInfoDialog extends JDialog {

	/**
	 * Listen to close button
	 */
	private class ButtonListener implements ActionListener {

		public void actionPerformed(ActionEvent event) {
			dispose();
		}
	}
	static ResourceBundle res = ResourceBundle
			.getBundle("com.pallas.unicore.client.dialogs.ResourceStrings");
	private JButton closeButton;

	/**
	 * Constructor builds gui
	 */
	public ResourceInfoDialog(Frame owner, NamedResourceSet resources,
			boolean showRequests) {
		super(owner, res.getString("RESOURCEINFO_TITLE"), false);
		JPanel infoPanel;
		if (resources == null || resources.isEmpty()) {
			infoPanel = new JPanel(new BorderLayout());
			infoPanel.add(new JLabel("Resource set is empty."),
					BorderLayout.CENTER);
		}
		else {
			if (showRequests) {
				infoPanel = new ResourceRequestInfoPanel(resources);
			}
			else {
				infoPanel = new ResourceInfoPanel(resources);
			}
		}
		closeButton = new JButton(res.getString("CLOSE"));
		closeButton.setToolTipText(res.getString("CLOSE_TIP"));
		closeButton.addActionListener(new ButtonListener());
		JScrollPane scrollPane = new JScrollPane(infoPanel);
		// add to main panel
		getContentPane().add(scrollPane, BorderLayout.CENTER);
		getContentPane().add(closeButton, BorderLayout.SOUTH);
		pack();
	}

	/**
	 * Overwrite show() method to position dialog
	 */
	public void show() {
		setSize(600, 450);
		setLocationRelativeTo(getParent());
		super.show();
	}
}