/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.explorer;

import java.awt.BorderLayout;
import java.awt.Cursor;
import java.awt.event.ActionEvent;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.io.File;
import java.io.FileNotFoundException;
import java.util.Vector;
import java.util.logging.Logger;
import javax.swing.AbstractAction;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRootPane;
import javax.swing.JScrollPane;
import javax.swing.JSplitPane;
import javax.swing.JTextField;
import javax.swing.SwingUtilities;
import javax.swing.border.SoftBevelBorder;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.event.TreeSelectionListener;
import javax.swing.filechooser.FileFilter;
import javax.swing.filechooser.FileSystemView;
import javax.swing.table.TableColumnModel;
import com.pallas.unicore.client.controls.GenericFileFilter;
import com.pallas.unicore.client.remotefilechooser.RemoteFile;

/**
 * @author Ralf Ratering
 * @version $Id: SelectorPanel.java,v 1.1 2004/05/25 14:58:53 rmenday Exp $
 */
public class SelectorPanel extends JPanel {

	class FilterListener implements ItemListener {

		public void itemStateChanged(ItemEvent e) {
			if (e.getStateChange() == ItemEvent.DESELECTED) {
				return;
			}
			table.setFileFilter((FileFilter) filterBox.getSelectedItem());
		}
	}

	class RefreshAction extends AbstractAction {

		RefreshAction() {
			super("Refresh");
		}

		public void actionPerformed(ActionEvent e) {
			refresh();
		}
	}

	protected class StatusBar extends JPanel {

		private JLabel label = new JLabel();

		public StatusBar() {
			buildComponents();
		}

		private void buildComponents() {
			setLayout(new BoxLayout(this, BoxLayout.X_AXIS));
			add(label);
		}

		public void setText(String text) {
			label.setText(text);
			super.revalidate();
		}
	}

	protected class TableHeaderListener extends MouseAdapter {

		public TableHeaderListener() {
		}

		public void mouseClicked(MouseEvent e) {
			TableColumnModel columnModel = table.getColumnModel();
			int viewColumn = columnModel.getColumnIndexAtX(e.getX());
			int column = table.convertColumnIndexToModel(viewColumn);
			table.sortByColumn(column);
		}
	}

	protected class TableMouseListener extends MouseAdapter {

		public void mouseClicked(MouseEvent e) {
			selectedFile = table.getSelectedFile();
			if (e.getClickCount() > 1) {
				if (selectedFile.isDirectory()) {
					tree.setSelectedObject(selectedFile);
				}
				else {
					firePropertyChange(FILE_SELECTED_PROPERTY, null,
							selectedFile);
				}
			}
		}

		public void mousePressed(MouseEvent e) {
			selectedFile = table.getSelectedFile();
			if (selectedFile instanceof RemoteFile) {
				nameField
						.setText(((RemoteFile) selectedFile).getSubspacePath());
			}
			else {
				nameField.setText(selectedFile.getAbsolutePath());
			}
		}

		public void mouseReleased(MouseEvent e) {
			selectedFile = table.getSelectedFile();
			if (selectedFile instanceof RemoteFile) {
				nameField
						.setText(((RemoteFile) selectedFile).getSubspacePath());
			}
			else {
				nameField.setText(selectedFile.getAbsolutePath());
			}
		}
	}

	protected class TreeListener implements TreeSelectionListener {

		public TreeListener() {
		}

		public void valueChanged(TreeSelectionEvent e) {
			updateNodeSelection();
		}
	}
	public final static GenericFileFilter DEFAULT_FILTER = new GenericFileFilter();
	public final static String FILE_SELECTED_PROPERTY = "FILE_SELECTED";
	protected static Logger logger = Logger
			.getLogger("com.pallas.unicore.client.explorer");
	private JComboBox filterBox;
	private JPanel leftPanel;
	private JTextField nameField;
	private boolean preemptiveMode = false;
	private File selectedFile;
	private JSplitPane splitPane;
	private StatusBar statusBar;
	private SelectorTable table;
	private SelectorTree tree;
	private FileSystemView view;

	public SelectorPanel(boolean preemptiveMode) {
		this(null, FileSystemView.getFileSystemView(), preemptiveMode);
	}

	public SelectorPanel(File currentDir, boolean preemptiveMode) {
		this(currentDir, FileSystemView.getFileSystemView(), preemptiveMode);
	}

	public SelectorPanel(File selectedFile, FileSystemView view,
			boolean preemptiveMode) {
		this.preemptiveMode = preemptiveMode;
		if (selectedFile == null) {
			selectedFile = view.getDefaultDirectory();
		}
		this.selectedFile = selectedFile;
		this.view = view;
		buildComponents();
	}

	public SelectorPanel(FileSystemView view, boolean preemptiveMode) {
		this(null, view, preemptiveMode);
	}

	public void addFileFilter(FileFilter filter) {
		for (int i = 0; i < filterBox.getItemCount(); i++) {
			FileFilter existing = (FileFilter) filterBox.getItemAt(i);
			if (existing.getDescription().equals(filter.getDescription())) {
				return;
			}
		}
		filterBox.addItem(filter);
	}

	protected void buildComponents() {
		// build tree
		tree = new SelectorTree(selectedFile, view, preemptiveMode);
		tree.addTreeSelectionListener(new TreeListener());
		// get initial node from tree
		DirNode currentNode = tree.getSelectedNode();
		File[] listing = currentNode.getListing();
		// build table
		table = new SelectorTable(view, true);
		table.getTableHeader().addMouseListener(new TableHeaderListener());
		table.addMouseListener(new TableMouseListener());
		table.setListing(listing);
		JScrollPane tablePane = new JScrollPane(table);
		// build status bar
		statusBar = new StatusBar();
		statusBar.setText("Objects: " + listing.length);
		statusBar.setBorder(new SoftBevelBorder(SoftBevelBorder.LOWERED));
		filterBox = new JComboBox();
		filterBox.addItem(DEFAULT_FILTER);
		filterBox.addItemListener(new FilterListener());
		JLabel filterLabel = new JLabel("Filter: ");
		filterLabel.setLabelFor(filterBox);
		JButton refreshButton = new JButton(new RefreshAction());
		JPanel filterPanel = new JPanel();
		filterPanel.setLayout(new BoxLayout(filterPanel, BoxLayout.X_AXIS));
		filterPanel.add(filterLabel);
		filterPanel.add(filterBox);
		filterPanel.add(refreshButton);
	
		JPanel rightPanel = new JPanel(new BorderLayout());
		rightPanel.add(filterPanel, BorderLayout.NORTH);
		rightPanel.add(tablePane, BorderLayout.CENTER);
		rightPanel.add(statusBar, BorderLayout.SOUTH);
		// build name field
		nameField = new JTextField(currentNode.getDir().getAbsolutePath());
		JLabel nameLabel = new JLabel("Filename: ");
		nameLabel.setLabelFor(nameField);
		JScrollPane treePane = new JScrollPane(tree);
		leftPanel = new JPanel(new BorderLayout());
		leftPanel.add(treePane, BorderLayout.CENTER);
		splitPane = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT, leftPanel,
				rightPanel);
		JPanel namePanel = new JPanel();
		namePanel.setLayout(new BoxLayout(namePanel, BoxLayout.X_AXIS));
		namePanel.add(nameLabel);
		namePanel.add(nameField);
		setLayout(new BorderLayout());
		add(splitPane, BorderLayout.CENTER);
		add(namePanel, BorderLayout.SOUTH);
		if (selectedFile.isFile()) {
			table.setSelectedObject(selectedFile);
		}
		if (selectedFile instanceof RemoteFile) {
			nameField.setText(((RemoteFile) selectedFile).getSubspacePath());
		}
		else {
			nameField.setText(selectedFile.getAbsolutePath());
		}
	}

	public int getDividerLocation() {
		return splitPane.getDividerLocation();
	}

	public Vector getFileFilters() {
		Vector filters = new Vector();
		for (int i = 0; i < filterBox.getItemCount(); i++) {
			filters.add(filterBox.getItemAt(i));
		}
		return filters;
	}

	public File getSelectedFile() {
		if (selectedFile instanceof RemoteFile) {
			RemoteFile remoteFile = (RemoteFile) selectedFile;
			// check if we picked an existing file
			if (remoteFile.getSubspacePath().equals(nameField.getText().trim())) {
				return remoteFile;
			}
			// we want to build a new remote file
			else {
				return new RemoteFile(nameField.getText().trim(), remoteFile
						.getStorage(), remoteFile.getFileSystem());
			}
		}
		else {
			if (selectedFile.getAbsolutePath().equals(
					nameField.getText().trim())) {
				return selectedFile;
			}
			else {
				return new File(nameField.getText().trim());
			}
		}
	}

	public FileFilter getSelectedFileFilter() {
		return (FileFilter) filterBox.getSelectedItem();
	}

	public SelectorTable getSelectorTable() {
		return this.table;
	}

	public void refresh() {
		tree.refresh(tree.getSelectedNode());
		updateNodeSelection();
	}

	public void removeFileFilter(FileFilter filter) {
		filterBox.removeItem(filter);
	}

	public void removeFileFilters() {
		filterBox.removeAllItems();
		filterBox.addItem(DEFAULT_FILTER);
	}

	public void setDividerLocation(double value) {
		splitPane.setDividerLocation(value);
	}

	public void setDividerLocation(int value) {
		splitPane.setDividerLocation(value);
	}

	public void setFilename(String filename) {
		File currentDir = tree.getSelectedNode().getDir();
		if (currentDir instanceof RemoteFile) {
			nameField.setText(((RemoteFile) currentDir).getSubspacePath()
					+ RemoteFile.separatorChar + filename);
		}
		else {
			nameField.setText(currentDir + File.separator + filename);
		}
	}

	public void setSelectedFile(final File selectedFile)
			throws FileNotFoundException {
		this.selectedFile = selectedFile;
		if (selectedFile.isDirectory()) {
			tree.setCurrentDirectory(selectedFile);
			table.setSelectedObject(null);
		}
		else {
			tree.setCurrentDirectory(selectedFile.getParentFile());
			// make sure table is up to date now
			updateNodeSelection();
			// wait until table is up to date, befor selecting new entry
			Runnable runner = new Runnable() {

				public void run() {
					table.setSelectedObject(selectedFile);
					updateNameField();
				}
			};
			SwingUtilities.invokeLater(runner);
		}
	}

	public void setSelectedFileFilter(FileFilter filter) {
		filterBox.setSelectedItem(filter);
	}

	private void updateNameField() {
		if (selectedFile instanceof RemoteFile) {
			nameField.setText(((RemoteFile) selectedFile).getSubspacePath());
		}
		else {
			nameField.setText(selectedFile.getAbsolutePath());
		}
	}

	private void updateNodeSelection() {
		final JRootPane rootPane = getRootPane();
		final DirNode node = tree.getSelectedNode();
		if (node == null) {
			return;
		}
		selectedFile = node.getDir();
		updateNameField();
		String path = selectedFile.getAbsolutePath();
		if (rootPane != null) {
			if (node.isUpToDate()) {
				statusBar.setText("Building file table for: " + path);
			}
			else {
				statusBar.setText("Scanning directory " + path);
			}
			rootPane.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
		}
		Runnable runner = new Runnable() {

			public void run() {
				long start = System.currentTimeMillis();
				// if node is not up to date
				// a complete scan is running in the background
				if (!node.isUpToDate()) {
					tree.addNextLevel(node);
				}
				File[] listing = node.getListing();
				table.setListing(listing);
				if (rootPane != null) {
					rootPane.setCursor(Cursor
							.getPredefinedCursor(Cursor.DEFAULT_CURSOR));
				}
				statusBar.setText("Objects: " + listing.length);
				long end = System.currentTimeMillis();
				logger.fine("TIME(s): " + (end - start) / 1000.0);
			}
		};
		SwingUtilities.invokeLater(runner);
	}
}