/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.graphics;

import java.awt.Dimension;
import java.awt.Point;
import java.awt.Rectangle;
import java.awt.geom.Line2D;
import java.awt.geom.Point2D;

/**
 * @author Ralf Ratering
 * @version $Id: ClipRectangle.java,v 1.1 2004/05/25 14:58:54 rmenday Exp $
 */
public class ClipRectangle extends Rectangle {

	/**
	 * The main program for the ClipRectangle class
	 * 
	 * @param args
	 *            The command line arguments
	 */
	public static void main(String[] args) {
		ClipRectangle clipRectangle1 = new ClipRectangle();
	}

	public ClipRectangle() {
	}

	public ClipRectangle(Dimension d) {
		super(d);
	}

	public ClipRectangle(int width, int height) {
		super(width, height);
	}

	public ClipRectangle(int x, int y, int width, int height) {
		super(x, y, width, height);
	}

	public ClipRectangle(Point p) {
		super(p);
	}

	public ClipRectangle(Point p, Dimension d) {
		super(p, d);
	}

	public ClipRectangle(Rectangle r) {
		super(r);
	}

	public Point2D findIntersection(Line2D line) {
		if (!intersectsLine(line)) {
			return null;
		}
		// x1==x and y1==y
		double x2 = x + width;
		double y2 = y + height;
		double lx1 = line.getX1();
		double ly1 = line.getY1();
		double lx2 = line.getX2();
		double ly2 = line.getY2();
		if (line.intersectsLine(new Line2D.Double(x, y, x2, y))) {
			double sy = y;
			double sx = lx1 + (lx2 - lx1) * (sy - ly1) / (ly2 - ly1);
			return new Point2D.Double(sx, sy);
		}
		if (line.intersectsLine(new Line2D.Double(x2, y, x2, y2))) {
			double sx = x2;
			double sy = ly1 + (ly2 - ly1) * (sx - lx1) / (lx2 - lx1);
			return new Point2D.Double(sx, sy);
		}
		if (line.intersectsLine(new Line2D.Double(x2, y2, x, y2))) {
			double sy = y2;
			double sx = lx1 + (lx2 - lx1) * (sy - ly1) / (ly2 - ly1);
			return new Point2D.Double(sx, sy);
		}
		if (line.intersectsLine(new Line2D.Double(x, y2, x, y))) {
			double sx = x;
			double sy = ly1 + (ly2 - ly1) * (sx - lx1) / (lx2 - lx1);
			return new Point2D.Double(sx, sy);
		}
		return null;
	}
}