/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.graphs;

import javax.swing.ImageIcon;
import com.pallas.unicore.container.ActionContainer;

/**
 * Class representing an ActionContainer in a dependency graph
 * 
 * @author Ralf Ratering
 * @version $Id: ContainerVertex.java,v 1.1 2004/05/25 14:58:45 rmenday Exp $
 */
public class ContainerVertex extends DAGVertex {

	private ActionContainer container;

	/**
	 * Constructor for the ContainerVertex object
	 * 
	 * @param container
	 *            container represented by this vertex
	 */
	public ContainerVertex(ActionContainer container) {
		super(container.getName());
		this.container = container;
	}

	/**
	 * Gets the Container of the ContainerVertex object
	 */
	public ActionContainer getContainer() {
		return container;
	}

	/**
	 * Gets the Icon of the ContainerVertex object
	 */
	public ImageIcon getImageIcon() {
		if (container != null) {
			return container.getStatusIcon();
		}
		return null;
	}
}