/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.panels;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.FocusAdapter;
import java.awt.event.FocusEvent;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.text.DateFormat;
import java.text.ParsePosition;
import java.util.Date;
import javax.swing.JCheckBox;
import javax.swing.JFormattedTextField;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import com.pallas.unicore.client.controls.LayoutTools;
import com.pallas.unicore.resourcemanager.ResourceManager;

/**
 * @author Ralf Ratering
 * @version $Id: DatePanel.java,v 1.1 2004/05/25 14:58:48 rmenday Exp $
 */
public class DatePanel extends JPanel {

	protected static DateFormat dateFormatter = ResourceManager
			.getDateFormatter(), timeFormatter = ResourceManager
			.getTimeFormatter(), completeFormatter = ResourceManager
			.getCompleteFormatter(), utcFormatter = ResourceManager
			.getUTCFormatter();
	private Component additionalComponent1, additionalComponent2;
	private JFormattedTextField localDateField, localTimeField;
	private JCheckBox todayBox;
	private JLabel waitLabel, localTimeLabel, localDateLabel, utcLabel,
			utcTimeLabel;

	public DatePanel() {
		this(null, null);
	}

	public DatePanel(Component additionalComponent1,
			Component additionalComponent2) {
		this.additionalComponent1 = additionalComponent1;
		this.additionalComponent2 = additionalComponent2;
		buildComponents();
		setEnabled(false);
	}

	private void buildComponents() {
		GridBagLayout g = new GridBagLayout();
		setLayout(g);
		GridBagConstraints c = new GridBagConstraints();
		int row = 0;
		if (additionalComponent1 != null) {
			c = LayoutTools.makegbc(0, row, 1, 0, false);
			add(additionalComponent1, c);
		}
		if (additionalComponent2 != null) {
			c = LayoutTools.makegbc(1, row, 1, 0, true);
			add(additionalComponent2, c);
		}
		row++;
		localTimeLabel = new JLabel("Time (hh:mm:ss): ");
		localTimeLabel.setToolTipText("Time at local workstation.");
		c = LayoutTools.makegbc(0, row, 1, 0, false);
		add(localTimeLabel, c);
		TextFieldListener actionListener = new TextFieldListener();
		TextFieldFocusListener focusListener = new TextFieldFocusListener();
		localTimeField = new JFormattedTextField(timeFormatter);
		localTimeField.addActionListener(actionListener);
		localTimeField.addFocusListener(focusListener);
		localTimeField.setValue(new Date());
		localTimeField.setToolTipText("Insert time at local workstation.");
		c = LayoutTools.makegbc(1, row, 2, 100, true);
		add(localTimeField, c);
		row++;
		localDateLabel = new JLabel("Date (mm/dd/yyyy): ");
		localDateLabel.setToolTipText("Date at local workstation.");
		c = LayoutTools.makegbc(0, row, 1, 0, false);
		add(localDateLabel, c);
		localDateField = new JFormattedTextField(dateFormatter);
		localDateField.addActionListener(actionListener);
		localDateField.addFocusListener(focusListener);
		localDateField.setToolTipText("Insert date at local workstation.");
		localDateField.setValue(new Date());
		c = LayoutTools.makegbc(1, row, 1, 100, true);
		add(localDateField, c);
		todayBox = new JCheckBox("Today");
		todayBox.addItemListener(new CheckBoxListener());
		todayBox.setToolTipText("Always use today as date.");
		c = LayoutTools.makegbc(2, row, 1, 50, false);
		add(todayBox, c);
		row++;
		utcLabel = new JLabel("UTC Time:");
		c = LayoutTools.makegbc(0, row, 1, 0, false);
		add(utcLabel, c);
		utcTimeLabel = new JLabel();
		utcTimeLabel.setToolTipText("Local time converted to UTC.");
		c = LayoutTools.makegbc(1, row, 1, 0, true);
		add(utcTimeLabel, c);
	}

	public Date getDate() {
		String dateString = localTimeField.getText().trim() + " "
				+ localDateField.getText().trim();
		ParsePosition pos = new ParsePosition(0);
		return completeFormatter.parse(dateString, pos);
	}

	public boolean getUseToday() {
		return todayBox.isSelected();
	}

	public void setDate(Date date) {
		localDateField.setText(dateFormatter.format(date));
		localTimeField.setText(timeFormatter.format(date));
	}

	public void setEnabled(boolean enabled) {
		localTimeLabel.setEnabled(enabled);
		localTimeField.setEnabled(enabled);
		localDateLabel.setEnabled(enabled);
		localDateField.setEnabled(enabled && !todayBox.isSelected());
		todayBox.setEnabled(enabled);
		utcLabel.setEnabled(enabled);
		utcTimeLabel.setEnabled(enabled);
	}

	public void setUseToday(boolean useToday) {
		todayBox.setSelected(useToday);
	}

	private void updateUTCTime() {
		Date date = getDate();
		if (date != null) {
			utcTimeLabel.setText(utcFormatter.format(date));
		}
	}

	public void updateValues() {
		if (todayBox.isSelected()) {
			localDateField.setText(dateFormatter.format(new Date()));
		}
		updateUTCTime();
	}

	public static void main(String args[]) {
		JFrame frame = new JFrame("Date Panel Test");
		frame.getContentPane().add(new DatePanel(), BorderLayout.CENTER);
		frame.pack();
		frame.setVisible(true);
	}

	private class CheckBoxListener implements ItemListener {

		public void itemStateChanged(ItemEvent e) {
			if (todayBox.isSelected()) {
				localDateField.setText(dateFormatter.format(new Date()));
				localDateField.setEnabled(false);
			}
			else {
				localDateField.setEnabled(true);
			}
		}
	}

	private class TextFieldFocusListener extends FocusAdapter {

		public void focusLost(FocusEvent e) {
			updateUTCTime();
		}
	}

	private class TextFieldListener implements ActionListener {

		public void actionPerformed(ActionEvent e) {
			updateUTCTime();
		}
	}
}