/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.panels;

import java.awt.GridLayout;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import javax.swing.JComboBox;
import javax.swing.JFrame;
import javax.swing.JPanel;
import com.pallas.unicore.container.ControlContainer;
import com.pallas.unicore.container.DoRepeatContainer;
import com.pallas.unicore.extensions.TestType;

/**
 * @author Ralf Ratering
 * @author Sven Haubold
 * @author Kirsten Foerster
 * @version $Id: DoRepeatPanel.java,v 1.1 2004/05/25 14:58:48 rmenday Exp $
 */
public class DoRepeatPanel extends GroupDependencyPanel {

	private class SelectionListener implements ItemListener {

		public void itemStateChanged(ItemEvent ev) {
			if (ev.getStateChange() == ItemEvent.DESELECTED) {
				return;
			}
			JComboBox testBox = (JComboBox) ev.getSource();
			TestType test = (TestType) testBox.getSelectedItem();
			if (ev.getSource() == returnCodeTestPanel.getTestBox()) {
				returnCodeTestPanel.setEnabled(test.isEnabled());
				if (test.isEnabled()) {
					fileTestPanel.setEnabled(false);
					timeTestPanel.setEnabled(false);
				}
			}
			else if (ev.getSource() == fileTestPanel.getTestBox()) {
				fileTestPanel.setEnabled(test.isEnabled());
				if (test.isEnabled()) {
					returnCodeTestPanel.setEnabled(false);
					timeTestPanel.setEnabled(false);
				}
			}
			else if (ev.getSource() == timeTestPanel.getTestBox()) {
				timeTestPanel.setEnabled(test.isEnabled());
				if (test.isEnabled()) {
					returnCodeTestPanel.setEnabled(false);
					fileTestPanel.setEnabled(false);
				}
			}
		}
	}

	public static void main(String args[]) {
		JFrame frame = new JFrame("Do Repeat Panel");
		frame.getContentPane().add(
				new DoRepeatPanel(new JFrame(), new DoRepeatContainer()));
		frame.addWindowListener(new WindowAdapter() {

			public void windowClosing(WindowEvent ev) {
				System.exit(0);
			}
		});
		frame.pack();
		frame.setVisible(true);
	}
	private FileTestPanel fileTestPanel;
	private ReturnCodeTestPanel returnCodeTestPanel;
	private TimeTestPanel timeTestPanel;

	public DoRepeatPanel(JFrame parentFrame, DoRepeatContainer container) {
		super(parentFrame, container);
	}

	/**
	 * Apply values from gui to JobContainer
	 */
	public void applyValues() {
		logger.fine("Aplying do repeat panel " + container);
		fileTestPanel.applyValues();
		timeTestPanel.applyValues();
		returnCodeTestPanel.applyValues();
		super.applyValues();
	}

	protected JPanel buildControlPanel() {
		JPanel panel = new JPanel(new GridLayout(3, 1, 10, 10));
		ControlContainer controlContainer = (ControlContainer) container;
		returnCodeTestPanel = new ReturnCodeTestPanel(controlContainer, true);
		fileTestPanel = new FileTestPanel(controlContainer, true);
		timeTestPanel = new TimeTestPanel(controlContainer, true);
		SelectionListener selectionListener = new SelectionListener();
		returnCodeTestPanel.getTestBox().addItemListener(selectionListener);
		fileTestPanel.getTestBox().addItemListener(selectionListener);
		timeTestPanel.getTestBox().addItemListener(selectionListener);
		setTitledBorder("Do Repeat");
		panel.add(returnCodeTestPanel);
		panel.add(fileTestPanel);
		panel.add(timeTestPanel);
		return panel;
	}

	/**
	 * Fill values from JobContainer into gui
	 */
	public void resetValues() {
		logger.fine("Resetting do repeat panel " + container);
		DoRepeatContainer doRepeatContainer = (DoRepeatContainer) container;
		fileTestPanel.resetValues();
		timeTestPanel.resetValues();
		returnCodeTestPanel.resetValues();
		super.resetValues();
	}

	public void updateValues(boolean vsiteChanged) {
		logger.fine("Updating do repeat panel " + container
				+ ". Vsite changed: " + vsiteChanged);
		returnCodeTestPanel.updateValues(vsiteChanged);
		fileTestPanel.updateValues(vsiteChanged);
		timeTestPanel.updateValues(vsiteChanged);
		super.updateValues(vsiteChanged);
	}
}