package com.pallas.unicore.client.panels;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JSplitPane;
import javax.swing.border.TitledBorder;

import com.pallas.unicore.client.graphs.DependencyEditor;
import com.pallas.unicore.container.GroupContainer;

/**
 *  Class for control group panels
 *
 *@author     Ralf Ratering
 *@version    $Id: GroupDependencyPanel.java,v 1.1 2004/05/25 14:58:47 rmenday Exp $
 */
public class GroupDependencyPanel extends GroupPanel {

	
	class ArrangeAction extends AbstractAction {
		
		public ArrangeAction() {
			super(res.getString("ARRANGE_GRAPH"));
		}

		public void actionPerformed(ActionEvent event) {
			dependencyEditor.arrangeGraph(80, 80);
			// update graph
			dependencyEditor.updateValues();
			// update panel size to make scrollbars appear
			dependencyEditor.revalidate();
		}
	}

	private DependencyEditor dependencyEditor;

	
	public GroupDependencyPanel(JFrame parentFrame, GroupContainer container) {
		this(parentFrame, container, true);
	}


	public GroupDependencyPanel(
		JFrame parentFrame,
		GroupContainer container,
		boolean editableNameField) {
		super(parentFrame, container, editableNameField);
	}

	/**
	 *  Apply values from gui to JobContainer
	 */
	public void applyValues() {
		dependencyEditor.applyValues();
		super.applyValues();
	}

	/**
	 *  Build GUI
	 */
	protected void buildComponents() {
		add(buildNamePanel(), BorderLayout.NORTH);
		// split pane between lists and dependency display
		JPanel controlPanel = buildControlPanel();
		if (controlPanel != null) {
			JSplitPane splitPane =
				new JSplitPane(
					JSplitPane.HORIZONTAL_SPLIT,
					new JScrollPane(controlPanel),
					buildDependencyPanel());
			add(splitPane, BorderLayout.CENTER);
		} else {
			add(buildDependencyPanel(), BorderLayout.CENTER);
		}
	}

	
	protected JPanel buildDependencyPanel() {
		dependencyEditor = new DependencyEditor(container);
		dependencyEditor.setBackground(new Color(0, 100, 200));
		dependencyEditor.setColor(Color.white);
		dependencyEditor.setSelectionColor(Color.green);

		JScrollPane dependencyScrollPane = new JScrollPane(dependencyEditor);
		dependencyScrollPane.setViewportView(dependencyEditor);

		JButton arrangeButton = new JButton(new ArrangeAction());

		JPanel dependencyControlPanel = new JPanel();
		dependencyControlPanel.add(arrangeButton);

		JPanel dependencyPanel = new JPanel(new BorderLayout());
		dependencyPanel.setBorder(
			new TitledBorder(res.getString("DEPENDENCY_BORDER")));
		dependencyPanel.add(dependencyScrollPane, BorderLayout.CENTER);
		dependencyPanel.add(dependencyControlPanel, BorderLayout.SOUTH);

		return dependencyPanel;
	}


	public DependencyEditor getDependencyEditor() {
		return dependencyEditor;
	}

	/**
	 * Fill values from JobContainer into gui
	 */
	public void resetValues() {
		dependencyEditor.resetValues();
		super.resetValues();
	}

	/**
	 *  Update dependency display
	 *
	 *@param  vsiteChanged  true, if vsite has changed since last update or
	 *      reset
	 */
	public void updateValues(boolean vsiteChanged) {
		dependencyEditor.updateValues();
		super.updateValues(vsiteChanged);
	}

}
