/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.panels;

import java.awt.BorderLayout;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.util.Date;
import javax.swing.BoxLayout;
import javax.swing.JComboBox;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import com.pallas.unicore.container.HoldJobContainer;
import com.pallas.unicore.container.JobContainer;
import com.pallas.unicore.extensions.HoldJobTest;
import com.pallas.unicore.extensions.TestType;

/**
 * @author Ralf Ratering
 * @version $Id: HoldJobTestPanel.java,v 1.1 2004/05/25 14:58:48 rmenday Exp $
 */
public class HoldJobTestPanel extends AbstractTestPanel {

	private class SelectionListener implements ItemListener {

		public void itemStateChanged(ItemEvent ev) {
			if (ev.getStateChange() == ItemEvent.DESELECTED) {
				return;
			}
			if (ev.getSource() == testBox) {
				JComboBox comboBox = (JComboBox) ev.getSource();
				TestType test = ((TestType) comboBox.getSelectedItem());
				datePanel.setEnabled(test.isEnabled()
						&& !test.equals(HoldJobTest.FOREVER));
				datePanel.updateValues();
			}
		}
	}

	public static void main(String args[]) {
		JFrame frame = new JFrame("Hold Job Test");
		frame.getContentPane().add(
				new HoldJobTestPanel(new HoldJobContainer(new JobContainer())),
				BorderLayout.CENTER);
		frame.pack();
		frame.setVisible(true);
	}
	private HoldJobContainer container;
	private DatePanel datePanel;

	public HoldJobTestPanel(HoldJobContainer container) {
		super(container);
		this.container = container;
		buildComponents();
	}

	public void applyValues() {
		TestType type = (TestType) testBox.getSelectedItem();
		HoldJobTest test = container.getHoldJobTest();
		test.setType(type);
		test.setUseToday(datePanel.getUseToday());
		if (type.equals(HoldJobTest.FOREVER)) {
			test.setDate(new Date(Long.MAX_VALUE));
		}
		else {
			test.setDate(datePanel.getDate());
		}
	}

	private void buildComponents() {
		JPanel waitPanel = new JPanel();
		waitPanel.setLayout(new BoxLayout(waitPanel, BoxLayout.X_AXIS));
		JLabel waitLabel = new JLabel("Wait: ");
		waitLabel.setToolTipText("Wait until the chosen date has expired.");
		waitPanel.add(waitLabel);
		testBox = new JComboBox(HoldJobTest.getTypes());
		testBox.setToolTipText("Wait until the chosen date has expired.");
		testBox.addItemListener(new SelectionListener());
		waitPanel.add(testBox);
		datePanel = new DatePanel(waitLabel, testBox);
		setLayout(new BorderLayout());
		add(datePanel, BorderLayout.CENTER);
	}

	public void resetValues() {
		HoldJobTest test = container.getHoldJobTest();
		testBox.setSelectedItem(test.getType());
		datePanel.setDate(test.getDate());
		datePanel.setUseToday(test.getUseToday());
	}

	public void updateValues(boolean vsiteChanged) {
		datePanel.updateValues();
	}
}