package com.pallas.unicore.client.panels;

import java.awt.BorderLayout;
import java.util.ResourceBundle;
import java.util.logging.Logger;
import javax.swing.BorderFactory;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.border.TitledBorder;
import org.unicore.Vsite;
import com.pallas.unicore.container.ActionContainer;
import com.pallas.unicore.container.JobContainer;

/**
 * Abstract base class for all panels that corresponds to a node in the jpa
 * tree.
 * 
 * @author Ralf Ratering
 * @version $Id: JPAPanel.java,v 1.1 2004/05/25 14:58:48 rmenday Exp $
 */
public abstract class JPAPanel extends JPanel implements Applyable {

	protected static Logger logger = Logger
			.getLogger("com.pallas.unicore.client.panels");
	protected static ResourceBundle res = ResourceBundle
			.getBundle("com.pallas.unicore.client.panels.ResourceStrings");
	private ActionContainer container;
	/**
	 * reference to parent JFrame
	 */
	protected JFrame parentFrame;
	private Vsite vsite;

	public JPAPanel(JFrame parentFrame, ActionContainer container) {
		this.parentFrame = parentFrame;
		this.container = container;
		JobContainer parent = container.getParentJobContainer();
		if (parent == null) {
			parent = (JobContainer) container;
		}
		setBorder(BorderFactory.createEtchedBorder());
		setLayout(new BorderLayout());
	}

	/**
	 * Apply the current GUI values to the container
	 */
	public abstract void applyValues();

	/**
	 * Get a reference to the parent frame
	 * 
	 * @return parentFrame
	 */
	public JFrame getParentFrame() {
		return parentFrame;
	}

	public boolean hasVsiteChanged() {
		JobContainer parent = container.getParentJobContainer();
		if (parent == null) {
			parent = (JobContainer) container;
		}
		logger.finer("Check vsite change for : " + container + ", New Vsite : "
				+ vsite + ", Old Vsite: " + parent.getVsite());
		boolean changed = ((vsite == null && parent.getVsite() != null) || vsite != null
				&& !vsite.equals(parent.getVsite()));
		logger.finer("Vsite Changed: " + changed);
		vsite = parent.getVsite();
		return changed;
	}

	/**
	 * Reset current GUI entries to last container contents.
	 */
	public abstract void resetValues();

	/**
	 * Sets the titledBorder attribute of the JPAPanel object
	 * 
	 * @param title
	 *            The new titledBorder value
	 */
	public void setTitledBorder(String title) {
		setBorder(new TitledBorder(title));
	}

	public void updateValues() {
		updateValues(hasVsiteChanged());
	}

	/**
	 * Method that will be called whenever the panel becomes visible
	 * 
	 * @param vsiteChanged
	 *            true, if vsite has changed since last update or reset
	 */
	public abstract void updateValues(boolean vsiteChanged);
}