/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.panels;

import java.util.Vector;
import javax.swing.JFrame;
import org.unicore.resources.CapacityResource;
import org.unicore.resources.Memory;
import org.unicore.resources.PerformanceResource;
import com.pallas.unicore.client.tables.AdjustTable;
import com.pallas.unicore.client.tables.TableSorter;
import com.pallas.unicore.extensions.NamedResourceSet;

/**
 * Panel to display information about a ResourceSet of a vsite.
 * 
 * @author Ralf Ratering
 * @version $Id: ResourceRequestInfoPanel.java,v 1.2 2003/06/30 06:54:29 rrate
 *          Exp $
 */
public class ResourceRequestInfoPanel extends ResourceInfoPanel {

	/**
	 * The main program for the ResourceInfoPanel class
	 * 
	 * @param args
	 *            The command line arguments
	 */
	public static void main(String[] args) {
		NamedResourceSet siteResources = new NamedResourceSet("bla");
		siteResources.add(new Memory("Memory", 100.0, 50.0, 10.0));
		ResourceRequestInfoPanel resourceInformationPanel = new ResourceRequestInfoPanel(
				siteResources);
		JFrame app = new JFrame();
		app.getContentPane().add(resourceInformationPanel);
		app.pack();
		app.show();
	}

	/**
	 * Constructor for the ResourceRequestInfoPanel object
	 * 
	 * @param resourceSet
	 *            Description of the Parameter
	 */
	public ResourceRequestInfoPanel(NamedResourceSet resourceSet) {
		super(resourceSet);
	}

	/**
	 * Build a table displaying all CapacityResources
	 * 
	 * @param capacities
	 *            Description of Parameter
	 * @return table to be displayed
	 */
	protected AdjustTable getCapacityTable(Vector capacities) {
		String[] columnNames = {"Description", "Request", "Minimum", "Maximum",
				"Default", "Units"};
		InfoTableModel tableModel = new InfoTableModel(columnNames, 0);
		// Instead of making the table display the data as it would normally
		// with:
		// AdjustTable tableView = new AdjustTable(dataModel);
		// Add a sorter, by using the following three lines instead of the one
		// above.
		TableSorter sorter = new TableSorter(tableModel);
		AdjustTable table = new AdjustTable();
		table.setModel(sorter);
		sorter.addMouseListenerToHeaderInTable(table);
		for (int i = 0; i < capacities.size(); i++) {
			CapacityResource resource = (CapacityResource) capacities
					.elementAt(i);
			String desc = resource.getDescription();
			if (desc.equals("")) {
				desc = resource.toString();
			}
			Object[] rowData = {desc, new Double(resource.getDefaultRequest()),
					new Double(resource.getMinRequest()),
					new Double(resource.getMaxRequest()),
					new Double(resource.getDefaultRequest()),
					resource.getUnits()};
			tableModel.addRow(rowData);
		}
		if (table.getRowCount() == 0) {
			return null;
		}
		else {
			return table;
		}
	}

	/**
	 * Build a table displaying all CapacityResources
	 * 
	 * @param performances
	 *            Description of Parameter
	 * @return table to be displayed
	 */
	protected AdjustTable getPerformanceTable(Vector performances) {
		String[] columnNames = {"Description", "Request", "Minimum", "Maximum",
				"Default", "Performance", "Units"};
		InfoTableModel tableModel = new InfoTableModel(columnNames, 0);
		// Instead of making the table display the data as it would normally
		// with:
		// AdjustTable tableView = new AdjustTable(dataModel);
		// Add a sorter, by using the following three lines instead of the one
		// above.
		TableSorter sorter = new TableSorter(tableModel);
		AdjustTable table = new AdjustTable();
		table.setModel(sorter);
		sorter.addMouseListenerToHeaderInTable(table);
		for (int i = 0; i < performances.size(); i++) {
			PerformanceResource resource = (PerformanceResource) performances
					.elementAt(i);
			String desc = resource.getDescription();
			if (desc.equals("")) {
				desc = resource.toString();
			}
			Object[] rowData = {desc, new Double(resource.getRequest()),
					new Double(resource.getMinRequest()),
					new Double(resource.getMaxRequest()),
					new Double(resource.getDefaultRequest()),
					new Double(resource.getPerformance()), resource.getUnits()};
			tableModel.addRow(rowData);
		}
		if (table.getRowCount() == 0) {
			return null;
		}
		else {
			return table;
		}
	}
}