/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.panels;

import java.awt.BorderLayout;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.util.Vector;
import javax.swing.DefaultComboBoxModel;
import javax.swing.JComboBox;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.border.TitledBorder;
import com.pallas.unicore.client.controls.IntTextField;
import com.pallas.unicore.client.controls.LayoutTools;
import com.pallas.unicore.container.ActionContainer;
import com.pallas.unicore.container.ControlContainer;
import com.pallas.unicore.container.DoRepeatContainer;
import com.pallas.unicore.extensions.ReturnCodeTest;
import com.pallas.unicore.extensions.TestType;

/**
 * @author Ralf Ratering
 * @author Kirsten Foerster
 * @version $Id: ReturnCodeTestPanel.java,v 1.1 2004/05/25 14:58:48 rmenday Exp $
 */
public class ReturnCodeTestPanel extends AbstractTestPanel {

	private class TestBoxListener implements ItemListener {

		public void itemStateChanged(ItemEvent e) {
			if (e.getStateChange() == ItemEvent.DESELECTED) {
				return;
			}
			updateControls();
		}
	}
	private static int rightInsets = 24;

	/**
	 * only for testing
	 * 
	 * @param args
	 *            Description of the Parameter
	 */
	public static void main(String args[]) {
		JFrame frame = new JFrame("Return Code Test");
		frame.getContentPane().add(
				new ReturnCodeTestPanel(new DoRepeatContainer(), true),
				BorderLayout.CENTER);
		frame.pack();
		frame.setVisible(true);
	}
	private ControlContainer controlContainer;
	private boolean repeatMode;
	private JComboBox taskBox;
	private DefaultComboBoxModel taskBoxModel;
	private JLabel testLabel, valueLabel, taskLabel;
	private IntTextField valueField;

	public ReturnCodeTestPanel(ControlContainer controlContainer,
			boolean repeatMode) {
		super(controlContainer);
		this.controlContainer = controlContainer;
		this.repeatMode = repeatMode;
		buildComponents();
		setEnabled(false);
	}

	/**
	 * Apply values from this gui to ReturnCodeTest
	 */
	public void applyValues() {
		ReturnCodeTest test = controlContainer.getReturnCodeTest();
		test.setType((TestType) testBox.getSelectedItem());
		test.setValue(new Integer(valueField.getText().trim()).intValue());
		test.setTestContainer((ActionContainer) taskBox.getSelectedItem());
	}

	/**
	 * Build all components of this panel
	 */
	private void buildComponents() {
		GridBagLayout g = new GridBagLayout();
		setLayout(g);
		GridBagConstraints c = new GridBagConstraints();
		if (repeatMode) {
			testLabel = new JLabel("Repeat Until: ");
			testLabel
					.setToolTipText("Repeat the job task until the status of the return code is achieved.");
		}
		else {
			testLabel = new JLabel("If: ");
			testLabel
					.setToolTipText("Interrogate the status of the return code.");
		}
		c = LayoutTools.makegbc(0, 0, 1, 0, false);
		c.insets = new Insets(5, 5, 5, rightInsets);
		add(testLabel, c);
		testBox = new JComboBox(ReturnCodeTest.getTypes());
		testBox.addItemListener(new TestBoxListener());
		if (repeatMode) {
			testBox
					.setToolTipText("Repeat the job task until the status of the return code is achieved.");
		}
		else {
			testBox
					.setToolTipText("Interrogate the status of the return code.");
		}
		c = LayoutTools.makegbc(1, 0, 2, 100, true);
		add(testBox, c);
		valueLabel = new JLabel("Value: ");
		valueLabel.setToolTipText("the value of the return code");
		c = LayoutTools.makegbc(0, 1, 1, 0, false);
		c.insets = new Insets(5, 5, 5, rightInsets);
		add(valueLabel, c);
		valueField = new IntTextField(0, 100);
		valueField.setToolTipText("the value of the return code");
		c = LayoutTools.makegbc(1, 1, 2, 100, true);
		add(valueField, c);
		taskLabel = new JLabel("Task: ");
		taskLabel.setToolTipText("Choose a task.");
		c = LayoutTools.makegbc(0, 2, 1, 0, false);
		c.insets = new Insets(5, 5, 5, rightInsets);
		add(taskLabel, c);
		taskBoxModel = new DefaultComboBoxModel();
		taskBox = new JComboBox();
		taskBox.setModel(taskBoxModel);
		taskBox.setToolTipText("Choose a task.");
		c = LayoutTools.makegbc(1, 2, 2, 100, true);
		add(taskBox, c);
		setBorder(new TitledBorder("Return Code Test"));
	}

	/**
	 * Fill values from ReturnCodeTest into this gui.
	 */
	public void resetValues() {
		ReturnCodeTest test = controlContainer.getReturnCodeTest();
		testBox.setSelectedItem(test.getType());
		valueField.setText(new Integer(test.getValue()).toString());
		if (test.getTestContainer() != null) {
			taskBoxModel.setSelectedItem(test.getTestContainer());
		}
	}

	public void setEnabled(boolean enabled) {
		super.setEnabled(enabled);
		taskLabel.setEnabled(enabled);
		taskBox.setEnabled(enabled);
		if (enabled) {
			updateControls();
		}
		else {
			valueLabel.setEnabled(false);
			valueField.setEnabled(false);
		}
	}

	private void updateControls() {
		TestType type = (TestType) testBox.getSelectedItem();
		boolean enabled = type.isEnabled()
				&& !type.equals(ReturnCodeTest.SUCCESSFUL)
				&& !type.equals(ReturnCodeTest.NOT_SUCCESSFUL);
		valueLabel.setEnabled(enabled);
		valueField.setEnabled(enabled);
	}

	public void updateValues(boolean vsiteChanged) {
		logger.finest("Updating values in return code test " + controlContainer
				+ ", vsite changed: " + vsiteChanged);
		Object selectedTask = taskBoxModel.getSelectedItem();
		taskBoxModel.removeAllElements();
		Vector tasks = null;
		if (repeatMode) {
			tasks = controlContainer.getTasks();
		}
		else {
			tasks = controlContainer.getParentContainer().getTasks();
		}
		for (int i = 0; i < tasks.size(); i++) {
			if (!tasks.elementAt(i).equals(controlContainer)) {
				taskBoxModel.addElement(tasks.elementAt(i));
			}
		}
		if (valueField.getText().equals("")) {
			valueField.setText("0");
		}
		if (tasks.contains(selectedTask)) {
			taskBoxModel.setSelectedItem(selectedTask);
		}
		if (taskBoxModel.getSelectedItem() == null
				&& taskBoxModel.getSize() > 0) {
			taskBox.setSelectedIndex(0);
		}
	}
}