/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.panels;

import java.text.NumberFormat;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JProgressBar;
import javax.swing.JTextField;
import javax.swing.SwingUtilities;
import javax.swing.border.Border;
import com.pallas.unicore.resourcemanager.ResourceManager;

/**
 * @author Thomas Kentemich
 * @author Ralf Ratering
 * @version $Id: StatusPanel.java,v 1.1 2004/05/25 14:58:48 rmenday Exp $
 */
public class StatusPanel extends JPanel {

	private final static Logger logger = Logger
			.getLogger("com.pallas.unicore.client.panels");
	private Icon connectedIcon = new ImageIcon(ResourceManager
			.getImage("estab_conn.gif"));
	private JLabel connectionStatus;
	private JLabel identity;
	private JProgressBar memoryBar;
	private String memoryString = "Java heap memory: ";
	private JTextField message;
	private Icon notConnectedIcon = new ImageIcon(ResourceManager
			.getImage("no_conn.gif"));
	private JProgressBar progressBar;

	public StatusPanel() {
		this.setLayout(new BoxLayout(this, BoxLayout.X_AXIS));
		buildComponents();
	}

	private void buildComponents() {
		Border border = BorderFactory.createLoweredBevelBorder();
		connectionStatus = new JLabel();
		connectionStatus.setIcon(notConnectedIcon);
		add(connectionStatus);
		identity = new JLabel("No identity");
		identity.setBorder(border);
		identity.setToolTipText("Current identity");
		add(identity);
		message = new JTextField();
		message.setBorder(border);
		message.setToolTipText("Status messages");
		message.setEditable(false);
		add(message);
		add(Box.createHorizontalGlue());
		progressBar = new JProgressBar(0, 1);
		progressBar.setBorder(border);
		add(progressBar);
		memoryBar = new JProgressBar(0, 100);
		memoryBar.setBorder(border);
		memoryBar.setStringPainted(true);
		startMemoryUpdate();
		add(memoryBar);
	}

	public JProgressBar getProgressBar() {
		return progressBar;
	}

	public void setConnected(final boolean connected) {
		Runnable runner = new Runnable() {

			public void run() {
				if (connected) {
					connectionStatus.setIcon(connectedIcon);
					connectionStatus
							.setToolTipText("Client is in online mode.");
				}
				else {
					connectionStatus.setIcon(notConnectedIcon);
					connectionStatus
							.setToolTipText("Client is in offline mode. Job can be prepared, but not submitted.");
				}
			}
		};
		SwingUtilities.invokeLater(runner);
	}

	public void setIdentity(final String myIdentity) {
		Runnable runner = new Runnable() {

			public void run() {
				identity.setText(myIdentity);
			}
		};
		SwingUtilities.invokeLater(runner);
	}

	public void setProgressMaxValue(int max) {
		progressBar.setMaximum(max);
	}

	public synchronized void setProgressString(final String in) {
		Runnable runner = new Runnable() {

			public void run() {
				progressBar.setStringPainted(true);
				progressBar.setString(in);
				progressBar.revalidate();
			}
		};
		SwingUtilities.invokeLater(runner);
	}

	public synchronized void setProgressValue(final int value) {
		// progressBar.setStringPainted(true);
		Runnable runner = new Runnable() {

			public void run() {
				progressBar.setValue(value);
			}
		};
		SwingUtilities.invokeLater(runner);
	}

	public synchronized void clearProgressBar() {
		// progressBar.setStringPainted(true);
		Runnable runner = new Runnable() {

			public void run() {
				progressBar.setValue(0);
				progressBar.setString("");
			}
		};
		SwingUtilities.invokeLater(runner);
	}

	public synchronized void setStatusMessage(final String messageString) {
		Runnable runner = new Runnable() {

			public void run() {
				message.setText(messageString);
			}
		};
		SwingUtilities.invokeLater(runner);
	}

	private void startMemoryUpdate() {
		Thread thread = new Thread() {

			private double freeMemory;
			private double maxMem;
			private NumberFormat nf;
			/**
			 * Main processing method for the CustomProgressMonitor object
			 */
			private double totalMem;
			private double usedMemory;

			public void run() {
				nf = NumberFormat.getNumberInstance();
				nf.setMaximumFractionDigits(2);
				nf.setMaximumIntegerDigits(3);
				nf.setMinimumFractionDigits(2);
				nf.setMinimumIntegerDigits(1);
				while (true) {
					totalMem = Runtime.getRuntime().totalMemory() / 1024.0 / 1024.0;
					maxMem = Runtime.getRuntime().maxMemory() / 1024.0 / 1024.0;
					freeMemory = Runtime.getRuntime().freeMemory() / 1024.0 / 1024.0;
					usedMemory = totalMem - freeMemory;
					// memoryBar.setValue((int)(usedMemory / totalMem * 100));
					Runnable runner = new Runnable() {

						public void run() {
							memoryBar.setToolTipText("Allocated: "
									+ nf.format(usedMemory) + "Mb Total: "
									+ nf.format(totalMem) + "Mb Max: "
									+ nf.format(maxMem) + "Mb");
							memoryBar.setString(nf.format(usedMemory) + "Mb/"
									+ nf.format(totalMem) + "Mb");
							memoryBar
									.setValue((int) ((usedMemory / totalMem) * 100.0));
						}
					};
					SwingUtilities.invokeLater(runner);
					try {
						Thread.sleep(20000);
					}
					catch (InterruptedException e) {
						logger.log(Level.SEVERE, "", e);
					}
				}
			}
		};
		thread.start();
	}

	public void startProgressBar() {
		Runnable runner = new Runnable() {

			public void run() {
				progressBar.setStringPainted(true);
				progressBar.setValue(0);
				progressBar.setIndeterminate(true);
			}
		};
		SwingUtilities.invokeLater(runner);
	}

	public void startWaiting() {
		progressBar.setIndeterminate(true);
	}

	public void stopProgressBar() {
		Runnable runner = new Runnable() {

			public void run() {
				progressBar.setStringPainted(false);
				progressBar.setValue(0);
				progressBar.setIndeterminate(false);
			}
		};
		SwingUtilities.invokeLater(runner);
	}

	public void stopWaiting() {
		progressBar.setIndeterminate(false);
	}
}