/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.panels;

import java.awt.BorderLayout;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import javax.swing.JComboBox;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.border.TitledBorder;
import com.pallas.unicore.container.ControlContainer;
import com.pallas.unicore.container.DoRepeatContainer;
import com.pallas.unicore.extensions.TestType;
import com.pallas.unicore.extensions.TimeTest;

/**
 * @author Ralf Ratering
 * @author Kirsten Foerster
 * @version $Id: TimeTestPanel.java,v 1.1 2004/05/25 14:58:47 rmenday Exp $
 */
public class TimeTestPanel extends AbstractTestPanel {

	private class SelectionListener implements ItemListener {

		public void itemStateChanged(ItemEvent ev) {
			if (ev.getStateChange() == ItemEvent.DESELECTED) {
				return;
			}
			if (ev.getSource() == testBox) {
				JComboBox comboBox = (JComboBox) ev.getSource();
				TestType test = ((TestType) comboBox.getSelectedItem());
				datePanel.setEnabled(test.isEnabled());
				datePanel.updateValues();
			}
		}
	}

	/**
	 * only for testing
	 * 
	 *  
	 */
	public static void main(String args[]) {
		JFrame frame = new JFrame("TimeTest");
		TimeTestPanel panel = new TimeTestPanel(new DoRepeatContainer(), true);
		panel.applyValues();
		panel.resetValues();
		frame.getContentPane().add(panel, BorderLayout.CENTER);
		frame.pack();
		frame.setVisible(true);
	}
	private ControlContainer controlContainer;
	private DatePanel datePanel;
	private boolean repeatMode;

	public TimeTestPanel(ControlContainer controlContainer, boolean repeatMode) {
		super(controlContainer);
		this.controlContainer = controlContainer;
		this.repeatMode = repeatMode;
		buildComponents();
	}

	/**
	 * Apply values from this gui to TimeTest.
	 */
	public void applyValues() {
		TimeTest test = controlContainer.getTimeTest();
		test.setDate(datePanel.getDate());
		test.setUseToday(datePanel.getUseToday());
		test.setType((TestType) testBox.getSelectedItem());
	}

	/**
	 * Build all components of this panel.
	 */
	private void buildComponents() {
		JLabel testLabel = new JLabel();
		if (repeatMode) {
			testLabel.setText("Repeat Until: ");
			testLabel
					.setToolTipText("Repeat group until the choosen date has expired.");
		}
		else {
			testLabel.setText("If: ");
			testLabel
					.setToolTipText("Take branch dependent on execution date.");
		}
		testBox = new JComboBox(TimeTest.getTypes());
		testBox.addItemListener(new SelectionListener());
		if (repeatMode) {
			testBox
					.setToolTipText("Repeat group until the choosen date has expired.");
		}
		else {
			testBox.setToolTipText("Take branch dependent on execution date.");
		}
		datePanel = new DatePanel(testLabel, testBox);
		setBorder(new TitledBorder("Time Test"));
		setLayout(new BorderLayout());
		add(datePanel, BorderLayout.CENTER);
	}

	/**
	 * Fill values from TimeTest into this gui.
	 */
	public void resetValues() {
		TimeTest test = controlContainer.getTimeTest();
		testBox.setSelectedItem(test.getType());
		datePanel.setDate(test.getDate());
		datePanel.setUseToday(test.getUseToday());
	}

	public void updateValues(boolean vsiteChanged) {
		datePanel.updateValues();
	}
}