/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.plugins.command;

import java.io.File;
import java.util.ResourceBundle;
import org.unicore.resources.Resource;
import org.unicore.resources.Storage;
import com.pallas.unicore.container.GroupContainer;
import com.pallas.unicore.container.UserContainer;
import com.pallas.unicore.container.errorspec.ErrorSet;
import com.pallas.unicore.container.errorspec.UError;
import com.pallas.unicore.extensions.FileStorage;
import com.pallas.unicore.extensions.NamedResourceSet;
import com.pallas.unicore.resourcemanager.ResourceManager;

/**
 * Container needed to import and execute a command on a vsite.
 * 
 * @author Thomas Kentemich
 * @version $Id: CommandContainer.java,v 1.1 2004/05/25 14:58:53 rmenday Exp $
 */
public class CommandContainer extends UserContainer {

	// field definitions for storing the container in XML format
	private static String[][] persistentXMLFields = {{"COMMANDDIRECTORY",
			"commandDirectory"}};
	// local command directory
	private static ResourceBundle res = ResourceBundle
			.getBundle("com.pallas.unicore.client.plugins.command.ResourceStrings");
	final static long serialVersionUID = -8765069416469853521L;
	private String commandDirectory;

	public CommandContainer(GroupContainer parentContainer) {
		super(parentContainer);
	}

	public ErrorSet checkContents() {
		ErrorSet err = super.checkContents();
		if (getVsite() == null) {
			return err;
		}
		if ((softwareResource == null) && (commandImport == null)) {
			err.add(new UError(getIdentifier(), res.getString("NO_SELECTION")));
		}
		else if (commandImport != null) {
			if (commandImport.getSourceName().equals("")) {
				err.add(new UError(getIdentifier(), res
						.getString("NO_EXECUTABLE")));
			}
			else if (commandImport.getStorageItem().equals(
					FileStorage.NSPACE_STRING)) {
				File commandFile = new File(commandImport.getSourceName());
				if (!commandFile.exists()) {
					err.add(new UError(getIdentifier(), res
							.getString("MISSING_LOCALIMPORT")
							+ commandImport.getSourceName()));
				}
			}
			else {
				// search for StorageResource in site resources
				NamedResourceSet siteResources = ResourceManager
						.getResourceSet(getVsite());
				Storage storage = (Storage) commandImport.getStorageItem();
				Resource resource = siteResources.findResource(storage);
				if (resource == null) {
					err.add(new UError(id, res.getString("STORAGE_RESOURCE")
							+ storage + res.getString("NOT_AVAILABLE")
							+ getVsite()));
				}
			}
		}
		else if (softwareResource != null) {
			// search for SoftwareResource in site resources
			NamedResourceSet siteResources = ResourceManager
					.getResourceSet(getVsite());
			Resource resource = siteResources.findResource(softwareResource);
			if (resource == null) {
				err.add(new UError(id, res.getString("SOFTWARE_RESOURCE")
						+ softwareResource + res.getString("NOT_AVAILABLE")
						+ getVsite()));
			}
		}
		setErrors(err);
		return err;
	}

	public String getCommandDirectory() {
		return commandDirectory;
	}

	public void setCommandDirectory(String commandDirectory) {
		this.commandDirectory = commandDirectory;
	}
}