/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.plugins.compile;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.ImageIcon;
import javax.swing.JMenuItem;
import com.pallas.unicore.client.panels.JPAPanel;
import com.pallas.unicore.client.util.TaskPlugable;
import com.pallas.unicore.container.ActionContainer;
import com.pallas.unicore.container.GroupContainer;

/**
 * This class manages the execute Compile plugin
 * 
 * @author Thomas Kentemich
 * @version $Id: CompilePlugin.java,v 1.1 2004/05/25 14:58:47 rmenday Exp $
 */
public class CompilePlugin extends TaskPlugable {

	// plugin in specific user defaults
	private CompileDefaults compileDefaults;

	/**
	 * Get a short info message for the plugin
	 * 
	 * @return String with info message
	 */
	public String getPluginInfo() {
		return "Execute Compile Plugin\n" + "(C)2000-2004 Intel";
	}

	/**
	 * Gets the name attribute of the CompilePlugin object
	 * 
	 * @return The name value
	 */
	public String getName() {
		return "Compile";
	}

	/**
	 * Gets the settingsItem attribute of the CompilePlugin object
	 * 
	 * @return The settingsItem value
	 */
	public JMenuItem getSettingsItem() {
		// handling setting menu events must be done by the plugin writers
		// as this is an optional feature
		JMenuItem settingsItem = new JMenuItem("Compile Defaults", 'C');
		settingsItem.addActionListener(new SettingsListener());
		return settingsItem;
	}

	/**
	 * Return a new container for this plugin
	 * 
	 * @param parentContainer
	 *            Description of the Parameter
	 * @return new initialized instance of plugin container
	 */
	public ActionContainer getContainerInstance(GroupContainer parentContainer) {
		// build new plugin container
		FortranContainer container = new FortranContainer(parentContainer);
		container.setName("New_Compile" + counter);
		container.setIcon(new ImageIcon(getIconImage()));
		// count instance
		counter++;
		return container;
	}

	/**
	 * Build a new panel that manages the settings of a plugin container
	 * 
	 * @param tCont
	 *            plugin container to build panel for
	 * @return JPAPanel that represents container settings in GUI
	 */
	public JPAPanel getPanelInstance(ActionContainer tCont) {
		// build new plugin panel
		CompileJPAPanel panel = new CompileJPAPanel(getClient(),
				(FortranContainer) tCont);
		return panel;
	}

	/**
	 * Gets the iconPath attribute of the CompilePlugin object
	 * 
	 * @return The iconPath value
	 */
	public String getIconPath() {
		return "com/pallas/unicore/client/plugins/compile/compile.gif";
	}

	/**
	 * Called to inititialize the plugin
	 */
	public void startPlugin() {
		compileDefaults = new CompileDefaults();
	}

	/**
	 * Called when terminating
	 */
	public void stopPlugin() {
		// do nothing
	}

	/**
	 * Show a dialog that configures plugin defaults
	 */
	private void showDefaultDialog() {
		CompileDefaultsDialog compileDefaultsDialog = new CompileDefaultsDialog(
				getClient(), compileDefaults);
		compileDefaultsDialog.show();
	}

	/**
	 * Listener class for settings menu entry
	 *  
	 */
	private class SettingsListener implements ActionListener {

		public void actionPerformed(ActionEvent event) {
			showDefaultDialog();
		}
	}
}