/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.plugins.compile;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.GridLayout;
import java.awt.Insets;
import java.util.Enumeration;
import java.util.Vector;
import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.border.TitledBorder;
import org.unicore.ajo.LinkMapLevel;
import com.pallas.unicore.container.CompileContainer;

/**
 * Panel to define options for linker
 * 
 * @author Thomas Kentemich
 * @version $Id: LinkerOptionPanel.java,v 1.1 2004/05/25 14:58:47 rmenday Exp $
 */
public class LinkerOptionPanel extends JPanel {

	// container to be modified
	protected CompileContainer compileContainer;
	//some ComboBoxes
	private JComboBox linkMapLevel;
	// some check boxes
	private JCheckBox linkForDebug, linkForProfiling;

	/**
	 * Constructor builds GUI
	 * 
	 * @param container
	 *            to be modified
	 */
	public LinkerOptionPanel(CompileContainer container) {
		this.compileContainer = container;
		buildComponents();
	}

	/**
	 * Apply gui entries to container
	 */
	public void applyValues() {
		compileContainer.setLinkForDebug(linkForDebug.isSelected());
		compileContainer.setLinkForProfile(linkForProfiling.isSelected());
		compileContainer.setLinkMapLevel((LinkMapLevel) linkMapLevel
				.getSelectedItem());
	}

	/**
	 * Fill gui elements with container values
	 */
	public void resetValues() {
		linkForDebug.setSelected(compileContainer.getLinkForDebug());
		linkForProfiling.setSelected(compileContainer.getLinkForProfiling());
		if (compileContainer.getLinkMapLevel() != null) {
			linkMapLevel.setSelectedItem(compileContainer.getLinkMapLevel());
		}
	}

	/**
	 * Build gui elements
	 */
	private void buildComponents() {
		// edit area
		Vector items = new Vector();
		Enumeration enum = LinkMapLevel.elements();
		while (enum.hasMoreElements()) {
			items.add(enum.nextElement());
		}
		linkMapLevel = new JComboBox(items);
		linkMapLevel.setSelectedItem(LinkMapLevel.NONE);
		GridBagLayout gridbag = new GridBagLayout();
		GridBagConstraints c = new GridBagConstraints();
		c.insets = new Insets(5, 5, 5, 5);
		c.anchor = GridBagConstraints.WEST;
		JPanel gridPanel = new JPanel(new GridLayout(2, 2, 10, 5));
		gridPanel.add(new JLabel("Linkmap level:"));
		gridPanel.add(linkMapLevel);
		linkForDebug = new JCheckBox("Generate debug output");
		linkForProfiling = new JCheckBox("Generate profiling output");
		gridPanel.add(linkForDebug);
		gridPanel.add(linkForProfiling);
		JPanel subPanel1 = new JPanel();
		subPanel1.setBorder(new TitledBorder("Runtime Options"));
		subPanel1.add(gridPanel);
		JPanel mainPanel = new JPanel(new BorderLayout());
		mainPanel.add(subPanel1, BorderLayout.CENTER);
		JScrollPane scrollPane = new JScrollPane(mainPanel);
		setLayout(new BorderLayout());
		add(scrollPane, BorderLayout.CENTER);
	}

	private void addToPanel(JPanel panel, Component l, Component r,
			GridBagLayout g, GridBagConstraints c) {
		c.gridwidth = GridBagConstraints.RELATIVE;
		g.setConstraints(l, c);
		panel.add(l);
		c.anchor = GridBagConstraints.WEST;
		c.gridwidth = GridBagConstraints.REMAINDER;
		g.setConstraints(r, c);
		panel.add(r);
	}
}