/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.plugins.proxycertificate;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.security.Security;
import java.security.cert.X509Certificate;
import java.util.Enumeration;
import java.util.Vector;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.help.HelpSet;
import javax.swing.JMenuItem;
import org.unicore.User;
import org.unicore.Vsite;
import org.unicore.ajo.AbstractAction;
import org.unicore.ajo.AbstractJob;
import org.unicore.ajo.ActionGroup;
import org.unicore.idiomatic.Transfer;
import org.unicore.idiomatic.TransferFile;
import org.unicore.resources.Resource;
import org.unicore.resources.TextInfoResource;
import org.unicore.sets.ResourceEnumeration;
import com.pallas.unicore.client.panels.JPAPanel;
import com.pallas.unicore.client.util.ExtensionPlugable;
import com.pallas.unicore.container.ActionContainer;
import com.pallas.unicore.container.GroupContainer;
import com.pallas.unicore.extensions.NamedResourceSet;
import com.pallas.unicore.resourcemanager.ResourceManager;

/**
 * @author Thomas Kentemich
 * @version $Id: ProxyCertificatePlugin.java,v 1.1 2004/05/25 14:58:52 rmenday Exp $
 */
public class ProxyCertificatePlugin extends ExtensionPlugable {

	private final static Logger logger = Logger
			.getLogger("com.pallas.unicore.client.plugins.proxycertificate");
	private ProxyCertificateDefaults proxyCertificateDefaults;

	/**
	 * Constructor for the ProxyCertificatePlugin object
	 */
	public ProxyCertificatePlugin() {
	}

	/**
	 * Return additional services provided by this plugin
	 * 
	 *  
	 */
	public Object setupSpecialVsiteFeatures(Vsite vsite, AbstractJob job)
			throws Exception {
		final String globus = "Globus";
		final String gs = "GS";
		final String aft = "AFTGridFTP";
		final String proxyFile = System.getProperty("java.io.tmpdir")
				+ File.separator + "proxy.pem";
		boolean isAFTSite = false;
		String vsiteType = vsite.getType().getDescription();
		Vector transfers = new Vector();
		// job may be null if this is a setup for a ServerRequest
		if (job != null) {
			boolean hasTransfers = getTransferTask(job, transfers);
			if (transfers.size() > 0) {
				// do we have any AFT transfers ?
				NamedResourceSet resourceSet = ResourceManager
						.getResourceSet(vsite);
				ResourceEnumeration enum = resourceSet.getResourceSet()
						.elements();
				while (enum.hasMoreElements()) {
					// check for special TextinfoResource advertising AFT
					// transfer for this Vsite
					Resource next = enum.nextElement();
					if (next instanceof TextInfoResource) {
						TextInfoResource nextInfo = (TextInfoResource) next;
						if (nextInfo.getTag().equals(aft)) {
							Vsite target = null;
							for (int i = 0; i < transfers.size(); i++) {
								Object nextTransfer = transfers.elementAt(i);
								if (nextTransfer instanceof Transfer) {
									target = ((Transfer) nextTransfer)
											.getTargetVsite();
									if (target.getName().equals(
											nextInfo.getValue())) {
										isAFTSite = true;
										logger.info("Proxy for AFT: "
												+ target.getName());
										break;
									}
								}
								else if (nextTransfer instanceof TransferFile) {
									target = ((TransferFile) nextTransfer)
											.getTargetVsite();
									if (target.getName().equals(
											nextInfo.getValue())) {
										isAFTSite = true;
										logger.info("Proxy for AFT: "
												+ target.getName());
										break;
									}
								}
							}
							if (isAFTSite) {
								break;
							}
						}
					}
				}
			}
		}
		byte[] sso = null;
		if (vsiteType.equals(globus) || vsiteType.equals(gs) || isAFTSite) {
			// try generating a proxy certificate
			try {
				User user = null;
				if (job != null) {
					user = job.getEndorser();
				}
				else {
					// for ServerRequests
					user = ResourceManager.getUser(vsite);
				}
				IProxyCertificate proxyCertificateFactory = ProxyCertificate
						.getInstance(user.getCertificate(),
								proxyCertificateDefaults.getLimited(),
								proxyCertificateDefaults.getValidTime(),
								proxyCertificateDefaults.getKeysize());
				X509Certificate proxyCert = proxyCertificateFactory
						.getProxyCertificate();
				X509Certificate[] userCert = {proxyCertificateFactory
						.getUserCertificate()};
				ByteArrayOutputStream bos = new ByteArrayOutputStream();
				proxyCertificateFactory.writePEM(bos);
				bos.close();
				ByteArrayInputStream bis = new ByteArrayInputStream(bos
						.toByteArray());
				sso = new byte[bis.available()];
				bis.read(sso);
				bis.close();
				if (System
						.getProperty("com.pallas.unicore.proxycertificate.store") != null) {
					FileOutputStream fos = new FileOutputStream(proxyFile);
					proxyCertificateFactory.writePEM(fos);
					logger.info("Wrote proxy file: " + proxyFile);
					fos.close();
				}
				// System.out.println(">>>>" + new String(sso));
				// finally set the SSO
				if (job != null) {
					job.setSSO(sso);
				}
			}
			catch (Exception e) {
				logger.log(Level.SEVERE, "", e);
			}
		}
		return sso;
	}

	/**
	 * Get a short info message for the plugin
	 * 
	 * @return String with info message
	 */
	public String getPluginInfo() {
		return "Generate a Globus proxy certificate\n" + "(C)2000-2004 Intel";
	}

	/**
	 * No help set available yet
	 * 
	 * @return a javax.help.HelpSet
	 */
	public HelpSet getHelpSet() {
		return null;
	}

	/**
	 * Gets item for JPA menu
	 * 
	 * @return a new menu item
	 */
	public JMenuItem getJPAItem() {
		// event handling for jpa menus will be done in the JPATree,
		// so we do not care about that here
		// plugin does not need a menu entry
		return null;
	}

	/**
	 * Gets an item for settings menu
	 * 
	 * @return null
	 */
	public JMenuItem getSettingsItem() {
		// handling setting menu events must be done by the plugin writers
		// as this is an optional feature
		JMenuItem settingsItem = new JMenuItem("Proxy defaults", 'P');
		settingsItem.addActionListener(new SettingsListener());
		return settingsItem;
	}

	/**
	 * Gets a sub menu for the extension menu
	 * 
	 * @return null
	 */
	public JMenuItem getCustomMenu() {
		return null;
	}

	/**
	 * Return a new container for this plugin
	 * 
	 * @param parentContainer
	 *            job that this task belongs to
	 * @return new initialized instance of plugin container
	 */
	public ActionContainer getContainerInstance(GroupContainer parentContainer) {
		// build new plugin container
		// plugin does not need a container
		return null;
	}

	/**
	 * Build a new panel that manages the parameters of a plugin container
	 * 
	 * @param container
	 *            Description of the Parameter
	 * @return JPAPanel that represents container parameters in GUI
	 */
	public JPAPanel getPanelInstance(ActionContainer container) {
		// return new instance of plugin JPAPanel
		return null;
	}

	/**
	 * Called to inititialize the plugin
	 * 
	 */
	public void startPlugin() {
		proxyCertificateDefaults = new ProxyCertificateDefaults();
		Security
				.addProvider(new org.bouncycastle.jce.provider.BouncyCastleProvider());
	}

	/**
	 * Called when terminating
	 */
	public void stopPlugin() {
		// do nothing
	}

	public boolean canProvideJPAPanel(ActionContainer container) {
		return (false);
	}

	private boolean getTransferTask(ActionGroup job, Vector contained) {
		boolean hasTransfers = false;
		Enumeration enum = job.getActions();
		while (enum != null && enum.hasMoreElements()) {
			AbstractAction next = (AbstractAction) enum.nextElement();
			if (next instanceof Transfer || next instanceof TransferFile) {
				contained.add(next);
				hasTransfers = true;
			}
			else if (next instanceof ActionGroup) {
				hasTransfers = getTransferTask((ActionGroup) next, contained);
			}
		}
		return (contained.size() > 0) || hasTransfers;
	}

	/**
	 * Show a dialog that configures plugin defaults
	 */
	private void showDefaultDialog() {
		ProxyCertificateDefaultsDialog proxyCertificateDefaultsDialog = new ProxyCertificateDefaultsDialog(
				getClient(), proxyCertificateDefaults);
		proxyCertificateDefaultsDialog.show();
	}

	private class SettingsListener implements ActionListener {

		public void actionPerformed(ActionEvent event) {
			showDefaultDialog();
		}
	}
}