/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.tables;

import java.awt.Color;
import java.awt.Component;
import java.util.Vector;
import javax.swing.JTable;
import javax.swing.event.ListSelectionListener;
import javax.swing.event.TableModelListener;
import javax.swing.table.DefaultTableCellRenderer;
import javax.swing.table.DefaultTableModel;

/**
 * @author Ralf Ratering
 * @version $Id: ListTable.java,v 1.1 2004/05/25 14:58:45 rmenday Exp $
 */
public class ListTable extends JTable {

	private class MyCellRenderer extends DefaultTableCellRenderer {

		public Component getTableCellRendererComponent(JTable table,
				Object value, boolean isSelected, boolean hasFocus, int row,
				int column) {
			super.getTableCellRendererComponent(table, value, isSelected,
					hasFocus, row, column);
			Color color = (Color) elementColors.get(row);
			if (isSelected) {
				super.setForeground(color.darker());
				super.setBackground(table.getSelectionBackground());
			}
			else {
				super.setForeground(color);
				super.setBackground(table.getBackground());
			}
			return this;
		}
	}
	private Vector columnNames = new Vector();
	private Vector data = new Vector();
	private Vector elementColors = new Vector();
	private DefaultTableModel model;

	public ListTable() {
		columnNames.add("");
		model = new DefaultTableModel(data, columnNames);
		// neccessary to get renderer work
		setOpaque(false);
		setModel(model);
		tableHeader.setVisible(false);
		setDefaultRenderer(Object.class, new MyCellRenderer());
	}

	public void addElement(NamedObject value) {
		Vector row = new Vector();
		row.add(value.getName());
		row.add(value);
		data.add(row);
		elementColors.add(getForeground());
	}

	public void addListSelectionListener(ListSelectionListener listener) {
		getSelectionModel().addListSelectionListener(listener);
	}

	public void addTableModelListener(TableModelListener listener) {
		model.addTableModelListener(listener);
	}

	public NamedObject getElement(int i) {
		Vector selectedRow = (Vector) data.elementAt(i);
		String name = (String) selectedRow.firstElement();
		NamedObject object = (NamedObject) selectedRow.elementAt(1);
		object.setName(name);
		return object;
	}

	public int getNrOfElements() {
		return model.getRowCount();
	}

	public NamedObject getSelectedValue() {
		if (getSelectedRow() < 0) {
			return null;
		}
		return getElement(getSelectedRow());
	}

	public void removeAllElements() {
		data.clear();
	}

	public void removeElement(NamedObject value) {
		for (int i = 0; i < data.size(); i++) {
			Vector row = (Vector) data.elementAt(i);
			NamedObject object = (NamedObject) row.elementAt(1);
			if (object.equals(value)) {
				model.removeRow(i);
				elementColors.remove(i);
				return;
			}
		}
	}

	public void setElementColor(int row, Color color) {
		elementColors.setElementAt(color, row);
	}

	public void setSelectedRow(int nr) {
		getSelectionModel().setSelectionInterval(nr, nr);
	}
}