/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.trees;

import java.awt.Color;
import java.awt.Component;
import java.util.Vector;
import java.util.logging.Logger;

import javax.swing.ImageIcon;
import javax.swing.JLabel;
import javax.swing.JTree;
import javax.swing.tree.DefaultTreeCellRenderer;

import org.unicore.ajo.AbstractAction;
import org.unicore.outcome.AbstractActionStatus;
import org.unicore.outcome.Outcome;

import com.pallas.unicore.resourcemanager.OutcomeEntry;
import com.pallas.unicore.resourcemanager.OutcomeManager;

/**
 *
 * @author	Thomas Kentemich
 * @version $Id: AjoCellRenderer.java,v 1.1 2004/05/25 14:58:50 rmenday Exp $
 */
public class AjoCellRenderer extends DefaultTreeCellRenderer {

	private static Logger logger =
		Logger.getLogger("com.pallas.unicore.client.trees");

	/**
	 * Sets the value of the current tree cell to value.
	 * 
	 * @param tree
	 *            is the JTree the receiver is being configured for
	 * @param object
	 *            is the current tree node
	 * @param selected
	 *            if true, the cell will be drawn as if selected.
	 * @param expanded
	 *            if true, the node is currently expanded
	 * @param leaf
	 *            if true, the node represets a leaf
	 * @param row
	 * @param hasFocus
	 *            if true, the node currently has focus
	 * @return the Component that the renderer uses to draw the value
	 */
	public Component getTreeCellRendererComponent(
		JTree tree,
		Object object,
		boolean selected,
		boolean expanded,
		boolean leaf,
		int row,
		boolean hasFocus) {

		Component c =
			super.getTreeCellRendererComponent(
				tree,
				object,
				selected,
				expanded,
				leaf,
				row,
				hasFocus);

		if (!(c instanceof JLabel)) {
			logger.warning("Tree component is not a JLabel, what else is it?");
			return c;
		}

		JLabel label = (JLabel) c;

		tree.setRowHeight(24);

		// if we have a PanelNode get icon from container
		// else choose a default icon
		if (object instanceof PanelNode) {
			PanelNode node = (PanelNode) object;
			ImageIcon icon = node.getCurrentIcon();
			if (icon != null) {
				label.setIcon(icon);
			}

			if (object instanceof AjoNode) {
				AbstractActionStatus status = AbstractActionStatus.NOT_DONE;
				Vector outcomes =
					OutcomeManager.getOutcomeEntries(
						(AbstractAction) node.getUserObject());
				if (outcomes.size() != 0) {
					Outcome outcome =
						((OutcomeEntry) outcomes
							.elementAt(outcomes.size() - 1))
							.getOutcome();
					if (outcome != null) {
						status = outcome.getStatus();
						label.setToolTipText(outcome.getStatus().toString());
					} 
				} 
				label.setToolTipText(status.toString());
			} else {
				label.setToolTipText("");
			}

			setBackgroundNonSelectionColor(tree.getBackground());

			Color fg = tree.getForeground();
			Color selectionBackground = Color.orange;
			Color selectionBorder = Color.black;
			if (fg != null
				&& fg.getRed() > 140
				&& fg.getGreen() > 140
				&& fg.getBlue() > 140) {
				selectionBackground = Color.blue.darker();
				selectionBorder = Color.white;
			}
			selectionBackground =
				new Color(
					selectionBackground.getRed(),
					selectionBackground.getGreen(),
					selectionBackground.getBlue(),
					100);

			setBackgroundSelectionColor(selectionBackground);
			setBorderSelectionColor(selectionBorder);

			if (node.isUpToDate()) {
				label.setForeground(fg);
			} else {
				// if background is too dark for gray, choose light gray
				Color bg = tree.getBackground();
				if (bg.getRed() < 170
					&& bg.getGreen() < 170
					&& bg.getBlue() < 170) {
					label.setForeground(Color.lightGray);
				} else {
					label.setForeground(Color.gray);
				}
			}
		}

		return this;
	}

}
