/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.util;

import javax.swing.JFrame;
import com.pallas.unicore.client.panels.ExportJPAPanel;
import com.pallas.unicore.client.panels.HoldJobPanel;
import com.pallas.unicore.client.panels.ImportJPAPanel;
import com.pallas.unicore.client.panels.JPAPanel;
import com.pallas.unicore.client.panels.OperationJPAPanel;
import com.pallas.unicore.client.panels.TransferJPAPanel;
import com.pallas.unicore.container.FileExportContainer;
import com.pallas.unicore.container.FileImportContainer;
import com.pallas.unicore.container.FileOperationContainer;
import com.pallas.unicore.container.FileTransferContainer;
import com.pallas.unicore.container.HoldJobContainer;
import com.pallas.unicore.container.TaskContainer;
import com.pallas.unicore.resourcemanager.ResourceManager;

/**
 * @author Thomas Kentemich
 * @author Ralf Ratering
 * @version $Id: ClientPluginManager.java,v 1.1 2004/05/25 14:58:50 rmenday Exp $
 */
public class ClientPluginManager extends PluginManager {

	public JPAPanel getPanelInstance(TaskContainer container) {
		// first check if we have a plugin container
		if (pluginClasses.size() > 0) {
			Class containerClass = container.getClass();
			for (int i = 0; i < pluginClasses.size(); i++) {
				UnicorePlugable plugable = (UnicorePlugable) pluginClasses
						.elementAt(i);
				if (plugable instanceof TaskPlugable) {
					TaskPlugable taskPlugable = (TaskPlugable) plugable;
					if (taskPlugable.hasContainerClass(container.getClass())) {
						return taskPlugable.getPanelInstance(container);
					}
				}
			}
		}
		// if we came here it must be some standard container
		// user task
		JFrame parent = ResourceManager.getCurrentInstance();
		// import task
		if (container instanceof FileImportContainer) {
			return new ImportJPAPanel(parent, (FileImportContainer) container);
		}
		// export task
		else if (container instanceof FileExportContainer) {
			return new ExportJPAPanel(parent, (FileExportContainer) container);
		}
		// transfer task
		else if (container instanceof FileTransferContainer) {
			return new TransferJPAPanel(parent,
					(FileTransferContainer) container);
		}
		// file operation task
		else if (container instanceof FileOperationContainer) {
			return new OperationJPAPanel(parent,
					(FileOperationContainer) container);
		}
		// hold job
		else if (container instanceof HoldJobContainer) {
			return new HoldJobPanel(parent, (HoldJobContainer) container);
		}
		// unknown container -> no panel
		return null;
	}
}