/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.util;

import java.lang.reflect.Array;
import java.util.Enumeration;
import java.util.Vector;
import com.pallas.unicore.utility.VectorSorter;

/**
 * Represents the complete countries and their codes.
 * 
 * @author Kirsten Foerster
 * @version $Id: ResourceCountryCodes.java,v 1.1 2004/05/25 14:58:50 rmenday Exp $
 */
public class ResourceCountryCodes extends java.util.ListResourceBundle {

	final static Object[][] contents = new String[][]{{"AF", "AFGHANISTAN"},
			{"AL", "ALBANIA"}, {"DZ", "ALGERIA"}, {"AS", "AMERICAN SAMOA"},
			{"AD", "ANDORRA"}, {"AO", "ANGOLA"}, {"AI", "ANGUILLA"},
			{"AQ", "ANTARCTICA"}, {"AG", "ANTIGUA AND BARBUDA"},
			{"AR", "ARGENTINA"}, {"AM", "ARMENIA"}, {"AW", "ARUBA"},
			{"AU", "AUSTRALIA"}, {"AT", "AUSTRIA"}, {"AZ", "AZERBAIJAN"},
			{"BS", "BAHAMAS"}, {"BH", "BAHRAIN"}, {"BD", "BANGLADESH"},
			{"BB", "BARBADOS"}, {"BY", "BELARUS"}, {"BE", "BELGIUM"},
			{"BZ", "BELIZE"}, {"BJ", "BENIN"}, {"BM", "BERMUDA"},
			{"BT", "BHUTAN"}, {"BO", "BOLIVIA"},
			{"BA", "BOSNIA AND HERZEGOWINA"}, {"BW", "BOTSWANA"},
			{"BV", "BOUVET ISLAND"}, {"BR", "BRAZIL"},
			{"IO", "0BRITISH INDIAN OCEAN TERRITORY"},
			{"BN", "BRUNEI DARUSSALAM"}, {"BG", "BULGARIA"},
			{"BF", "BURKINA FASO"}, {"BI", "BURUNDI"}, {"KH", "CAMBODIA"},
			{"CM", "CAMEROON"}, {"CA", "CANADA"}, {"CV", "CAPE VERDE"},
			{"KY", "CAYMAN ISLANDS"}, {"CF", "CENTRAL AFRICAN REPUBLIC"},
			{"TD", "CHAD"}, {"CL", "CHILE"}, {"CN", "CHINA"},
			{"CX", "CHRISTMAS ISLAND"}, {"CC", "COCOS (KEELING) ISLANDS"},
			{"CO", "COLOMBIA"}, {"KM", "COMOROS"}, {"CG", "CONGO"},
			{"CK", "COOK ISLANDS"}, {"CR", "COSTA RICA"},
			{"CI", "COTE D'IVOIRE"}, {"HR", "CROATIA (local name: Hrvatska)"},
			{"CU", "CUBA"}, {"CY", "CYPRUS"}, {"CZ", "CZECH REPUBLIC"},
			{"DK", "DENMARK"}, {"DJ", "DJIBOUTI"}, {"DM", "DOMINICA"},
			{"DO", "DOMINICAN REPUBLIC"}, {"TP", "EAST TIMOR"},
			{"EC", "ECUADOR"}, {"EG", "EGYPT"}, {"SV", "EL SALVADOR"},
			{"GQ", "EQUATORIAL GUINEA"}, {"ER", "ERITREA"}, {"EE", "ESTONIA"},
			{"ET", "ETHIOPIA"}, {"FK", "FALKLAND ISLANDS (MALVINAS)"},
			{"FO", "FAROE ISLANDS"}, {"FJ", "FIJI"}, {"FI", "FINLAND"},
			{"FR", "FRANCE"}, {"FX", "FRANCE, METROPOLITAN"},
			{"GF", "FRENCH GUIANA"}, {"PF", "FRENCH POLYNESIA"},
			{"TF", "FRENCH SOUTHERN TERRITORIES"}, {"GA", "GABON"},
			{"GM", "GAMBIA"}, {"GE", "GEORGIA"}, {"DE", "GERMANY"},
			{"GH", "GHANA"}, {"GI", "GIBRALTAR"}, {"GR", "GREECE"},
			{"GL", "GREENLAND"}, {"GD", "GRENADA"}, {"GP", "GUADELOUPE"},
			{"GU", "GUAM"}, {"GT", "GUATEMALA"}, {"GN", "GUINEA"},
			{"GW", "GUINEA-BISSAU"}, {"GY", "GUYANA"}, {"HT", "HAITI"},
			{"HM", "HEARD AND MC DONALD ISLANDS"}, {"HN", "HONDURAS"},
			{"HK", "HONG KONG"}, {"HU", "HUNGARY"}, {"IS", "ICELAND"},
			{"IN", "INDIA"}, {"ID", "INDONESIA"},
			{"IR", "IRAN, ISLAMIC REPUBLIC OF"}, {"IQ", "IRAQ"},
			{"IE", "IRELAND"}, {"IL", "ISRAEL"}, {"IT", "ITALY"},
			{"JM", "JAMAICA"}, {"JP", "JAPAN"}, {"JO", "JORDAN"},
			{"KZ", "KAZAKHSTAN"}, {"KE", "KENYA"}, {"KI", "KIRIBATI"},
			{"KP", "KOREA, DEMOCRATIC PEOPLE'S REPUBLIC OF"},
			{"KR", "KOREA, REPUBLIC OF"}, {"KW", "KUWAIT"},
			{"KG", "KYRGYZSTAN"}, {"LA", "LAO PEOPLE'S DEMOCRATIC REPUBLIC"},
			{"LV", "LATVIA"}, {"LB", "LEBANON"}, {"LS", "LESOTHO"},
			{"LR", "LIBERIA"}, {"LY", "LIBYAN ARAB JAMAHIRIYA"},
			{"LI", "LIECHTENSTEIN"}, {"LT", "LITHUANIA"}, {"LU", "LUXEMBOURG"},
			{"MO", "MACAU"},
			{"MK", "MACEDONIA, THE FORMER YUGOSLAV REPUBLIC OF"},
			{"MG", "MADAGASCAR"}, {"MW", "MALAWI"}, {"MY", "MALAYSIA"},
			{"MV", "MALDIVES"}, {"ML", "MALI"}, {"MT", "MALTA"},
			{"MH", "MARSHALL ISLANDS"}, {"MQ", "MARTINIQUE"},
			{"MR", "MAURITANIA"}, {"MU", "MAURITIUS"}, {"YT", "MAYOTTE"},
			{"MX", "MEXICO"}, {"FM", "MICRONESIA, FEDERATED STATES OF"},
			{"MD", "MOLDOVA, REPUBLIC OF"}, {"MC", "MONACO"},
			{"MN", "MONGOLIA"}, {"MS", "MONTSERRAT"}, {"MA", "MOROCCO"},
			{"MZ", "MOZAMBIQUE"}, {"MM", "MYANMAR"}, {"NA", "NAMIBIA"},
			{"NR", "NAURU"}, {"NP", "NEPAL"}, {"NL", "NETHERLANDS"},
			{"AN", "NETHERLANDS ANTILLES"}, {"NC", "NEW CALEDONIA"},
			{"NZ", "NEW ZEALAND"}, {"NI", "NICARAGUA"}, {"NE", "NIGER"},
			{"NG", "NIGERIA"}, {"NU", "NIUE"}, {"NF", "NORFOLK ISLAND"},
			{"MP", "NORTHERN MARIANA ISLANDS"}, {"NO", "NORWAY"},
			{"OM", "OMAN"}, {"PK", "PAKISTAN"}, {"PW", "PALAU"},
			{"PA", "PANAMA"}, {"PG", "PAPUA NEW GUINEA"}, {"PY", "PARAGUAY"},
			{"PE", "PERU"}, {"PH", "PHILIPPINES "}, {"PN", "PITCAIRN"},
			{"PL", "POLAND"}, {"PT", "PORTUGAL"}, {"PR", "PUERTO RICO"},
			{"QA", "QATAR"}, {"RE", "REUNION"}, {"RO", "ROMANIA"},
			{"RU", "RUSSIAN FEDERATION"}, {"RW", "RWANDA"},
			{"KN", "SAINT KITTS AND NEVIS"}, {"LC", "SAINT LUCIA"},
			{"VC", "SAINT VINCENT AND THE GRENADINES"}, {"WS", "SAMOA"},
			{"SM", "SAN MARINO"}, {"ST", "SAO TOME AND PRINCIPE"},
			{"SA", "SAUDI ARABIA"}, {"SN", "SENEGAL"}, {"SC", "SEYCHELLES"},
			{"SL", "SIERRA LEONE"}, {"SG", "SINGAPORE"},
			{"SK", "SLOVAKIA (Slovak Republic)"}, {"SI", "SLOVENIA"},
			{"SB", "SOLOMON ISLANDS"}, {"SO", "SOMALIA"},
			{"ZA", "SOUTH AFRICA"},
			{"GS", "SOUTH GEORGIA AND THE SOUTH SANDWICH ISLANDS"},
			{"ES", "SPAIN"}, {"LK", "SRI LANKA"}, {"SH", "ST. HELENA"},
			{"PM", "ST. PIERRE AND MIQUELON"}, {"SD", "SUDAN"},
			{"SR", "SURINAME"}, {"SJ", "SVALBARD AND JAN MAYEN ISLANDS"},
			{"SZ", "SWAZILAND"}, {"SE", "SWEDEN"}, {"CH", "SWITZERLAND"},
			{"SY", "SYRIAN ARAB REPUBLIC"}, {"TW", "TAIWAN"},
			{"TJ", "TAJIKISTAN"}, {"TZ", "TANZANIA, UNITED REPUBLIC OF"},
			{"TH", "THAILAND"}, {"TG", "TOGO"}, {"TK", "TOKELAU"},
			{"TO", "TONGA"}, {"TT", "TRINIDAD AND TOBAGO"}, {"TN", "TUNISIA"},
			{"TR", "TURKEY"}, {"TM", "TURKMENISTAN"},
			{"TC", "TURKS AND CAICOS ISLANDS"}, {"TV", "TUVALU"},
			{"UG", "UGANDA"}, {"UA", "UKRAINE"},
			{"AE", "UNITED ARAB EMIRATES"}, {"GB", "UNITED KINGDOM"},
			{"US", "UNITED STATES"},
			{"UM", "UNITED STATES MINOR OUTLYING ISLANDS"}, {"UY", "URUGUAY"},
			{"UZ", "UZBEKISTAN"}, {"VU", "VANUATU"},
			{"VA", "VATICAN CITY STATE (HOLY SEE)"}, {"VE", "VENEZUELA"},
			{"VN", "VIET NAM"}, {"VG", "VIRGIN ISLANDS (BRITISH)"},
			{"VI", "VIRGIN ISLANDS (U.S.)"},
			{"WF", "WALLIS AND FUTUNA ISLANDS"}, {"EH", "WESTERN SAHARA"},
			{"YE", "YEMEN"}, {"YU", "YUGOSLAVIA"}, {"ZR", "ZAIRE "},
			{"ZM", "ZAMBIA"}, {"ZW", "ZIMBABWE"}};

	public ResourceCountryCodes() {
	}

	public Object[][] getContents() {
		return contents;
	}

	public Enumeration getCountries() {
		Vector vector = new Vector();
		for (int i = 0; i < Array.getLength(contents); i++) {
			vector.addElement(contents[i][1]);
		}
		return vector.elements();
	}

	public Enumeration getCountryCodes() {
		Vector vector = new Vector();
		for (Enumeration el = this.getKeys(); el.hasMoreElements();) {
			vector.addElement(el.nextElement());
		}
		/*
		 * for(int i = 0; i < Array.getLength(contents); i++) {
		 * vector.addElement(contents[i][0]); }
		 */
		VectorSorter.sort(vector);
		return vector.elements();
	}
}