/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.client.util;

import javax.help.HelpSet;
import javax.swing.JMenuItem;
import com.pallas.unicore.client.Client;
import com.pallas.unicore.resourcemanager.ResourceManager;

/**
 * Abstract base class for all UNICORE plugins.
 * 
 * @author Ralf Ratering
 * @version $Id: UnicorePlugable.java,v 1.1 2004/05/25 14:58:50 rmenday Exp $
 */
public abstract class UnicorePlugable {

	/**
	 * Gets the current Client instance from the ResourceManager
	 * 
	 * @return reference to current Client frame
	 */
	protected Client getClient() {
		return ResourceManager.getCurrentInstance();
	}

	/**
	 * Return a help set that will be plugged into the client's help. If no help
	 * set is available return null.
	 * 
	 * @return a javax.help.HelpSet (or null)
	 */
	public HelpSet getHelpSet() {
		return null;
	}

	/**
	 * Return the plugin info string, containing some information about version,
	 * author, copyright, etc. This string will be displayed in the client's
	 * about dialog.
	 * 
	 * @return a string containing some plugin information
	 */
	public abstract String getPluginInfo();

	/**
	 * Get a menu item for the client's settings menu. Typical use for these
	 * items is to popup a plugin specific configuration dialog. The client does
	 * not attach a listener to this item so it is up to the plugin developer to
	 * respond to this item. The method teturns null if no menu item should be
	 * added to the clients settings menu.
	 * 
	 * @return a menu item that will be added to the client's settings menu
	 */
	public JMenuItem getSettingsItem() {
		return null;
	}

	/**
	 * Called to initialize the plugin after the plugin has been loaded.
	 *  
	 */
	public abstract void startPlugin();

	/**
	 * Called before exiting the client. Here some finalization can be done.
	 */
	public abstract void stopPlugin();
}