/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.connection;

import java.net.Authenticator;
import java.net.PasswordAuthentication;
import java.util.logging.Logger;
import javax.swing.JFrame;
import com.pallas.unicore.client.dialogs.LoginDialog;

/**
 * @author Ralf Ratering
 * @version $Id: ProxyManager.java,v 1.1 2004/05/25 14:58:51 rmenday Exp $
 */
public class ProxyManager {

	private static Logger logger = Logger
			.getLogger("com.pallas.unicore.connection");
	private static JFrame parent;
	private static PasswordAuthentication authentication;

	private ProxyManager() {
	}

	/**
	 * Sets the parent frame
	 */
	public static void setParent(JFrame _parent) {
		parent = _parent;
	}

	/**
	 * Gets the authentication
	 */
	public static PasswordAuthentication getAuthentication() {
		return authentication;
	}

	/**
	 * do not use proxy
	 */
	public static void noProxy() {
		System.setProperty("proxySet", "false");
	}

	/**
	 * use a proxy
	 */
	public static void useProxy(String hostname, int port, String noProxy) {
		String portString = new Integer(port).toString();
		System.setProperty("proxySet", "true");
		System.setProperty("http.proxyHost", hostname);
		System.setProperty("http.proxyPort", portString);
		System.setProperty("http.nonProxyHosts", noProxy);
		/*
		 * org.apache.axis.AxisProperties.setProperty( "http.proxyHost",
		 * System.getProperty("http.proxyHost"));
		 * org.apache.axis.AxisProperties.setProperty( "http.proxyPort",
		 * System.getProperty("http.proxyPort"));
		 * org.apache.axis.AxisProperties.setProperty( "nonProxyHosts",
		 * System.getProperty("nonProxyHosts"));
		 */
		Authenticator.setDefault(new ProxyAuthenticator());
	}

	/**
	 * use https proxy
	 */
	public static void useHttpsProxy(String hostname, int port, String noProxy) {
		String portString = new Integer(port).toString();
		System.setProperty("proxySet", "true");
		System.setProperty("https.proxyHost", hostname);
		System.setProperty("https.proxyPort", portString);
		System.setProperty("https.nonProxyHosts", noProxy);
		/*
		 * org.apache.axis.AxisProperties.setProperty( "https.proxyHost",
		 * System.getProperty("https.proxyHost"));
		 * org.apache.axis.AxisProperties.setProperty( "https.proxyPort",
		 * System.getProperty("https.proxyPort"));
		 * org.apache.axis.AxisProperties.setProperty( "nonProxyHosts",
		 * System.getProperty("nonProxyHosts"));
		 */
		Authenticator.setDefault(new ProxyAuthenticator());
	}

	private static class ProxyAuthenticator extends Authenticator {

		protected PasswordAuthentication getPasswordAuthentication() {
			logger.info("Getting proxy authorization...");
			LoginDialog proxyDialog = new LoginDialog(parent,
					"UNICORE: Proxy Authorization");
			proxyDialog.setVisible(true);
			if ((proxyDialog.getUsername() == null)
					|| (proxyDialog.getPassword() == null)) {
				return null;
			}
			authentication = new PasswordAuthentication(proxyDialog
					.getUsername(), proxyDialog.getPassword());
			// set up authentication for AXIS
			/*
			 * if (authentication != null) {
			 * org.apache.axis.AxisProperties.setProperty( "http.proxyUser",
			 * authentication.getUserName());
			 * org.apache.axis.AxisProperties.setProperty( "http.proxyPassword",
			 * new String(authentication.getPassword()));
			 * org.apache.axis.AxisProperties.setProperty( "https.proxyUser",
			 * authentication.getUserName());
			 * org.apache.axis.AxisProperties.setProperty(
			 * "https.proxyPassword", new String(authentication.getPassword())); }
			 */
			return authentication;
		}
	}
}