/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.container;

import org.unicore.ajo.LinkMapLevel;
import org.unicore.ajo.ListingLevel;
import org.unicore.ajo.OptimisationLevel;
import org.unicore.ajo.Portfolio;
import org.unicore.sets.PortfolioList;
import com.pallas.unicore.container.errorspec.ErrorSet;
import com.pallas.unicore.container.errorspec.UError;

/**
 * Container needed to import and execute a command on a vsite.
 * 
 * @author Thomas Kentemich
 * @version $Id: CompileContainer.java,v 1.1 2004/05/25 14:58:50 rmenday Exp $
 */
public abstract class CompileContainer extends ExecuteContainer {

	final static long serialVersionUID = 6730072481112939306L;
	protected boolean compileForDebug;
	protected boolean compileForProfiling;
	protected String[] includes;
	protected PortfolioList libraries;
	protected boolean linkForDebug;
	protected boolean linkForProfile;
	protected LinkMapLevel linkmapLevel;
	protected ListingLevel listingLevel;
	protected Portfolio listings;
	protected Portfolio objectPortfolio;
	protected PortfolioList objects;
	protected OptimisationLevel optimLevel;
	protected boolean redirectStdin;
	protected String[] sources;
	protected String stdinPath;

	public CompileContainer(GroupContainer parentContainer) {
		super(parentContainer);
	}

	/**
	 * Self check the correctness of the values relevant for this container
	 * 
	 *  
	 */
	public ErrorSet checkContents() {
		ErrorSet err = super.checkContents();
		if (getSources() == null || getSources().length == 0) {
			err.add(new UError(id, "No sources specified for compilation."));
		}
		if (getObjects() == null || getObjects().size() == 0) {
			err.add(new UError(id, "No objects specified for linker."));
		}
		setErrors(err);
		return err;
	}

	public boolean getCompileForDebug() {
		return compileForDebug;
	}

	public boolean getCompileForProfiling() {
		return compileForProfiling;
	}

	public String[] getIncludes() {
		return includes;
	}

	public PortfolioList getLibraries() {
		return libraries;
	}

	public boolean getLinkForDebug() {
		return linkForDebug;
	}

	public boolean getLinkForProfiling() {
		return linkForProfile;
	}

	public LinkMapLevel getLinkMapLevel() {
		return linkmapLevel;
	}

	public ListingLevel getListingLevel() {
		return listingLevel;
	}

	public Portfolio getListings() {
		return listings;
	}

	/**
	 * Gets the portfolio containing the objects generated by the CompileTask
	 * 
	 * @return The Objects value
	 */
	public Portfolio getObjectPortfolio() {
		return objectPortfolio;
	}

	public PortfolioList getObjects() {
		return objects;
	}

	public OptimisationLevel getOptimisationLevel() {
		return optimLevel;
	}

	public boolean getRedirectStdin() {
		return redirectStdin;
	}

	public String[] getSources() {
		return sources;
	}

	public String getStdin() {
		return stdinPath;
	}

	public void setCompileForDebug(boolean debug) {
		this.compileForDebug = debug;
	}

	public void setCompileForProfile(boolean profiling) {
		this.compileForProfiling = profiling;
	}

	public void setIncludes(String[] includes) {
		this.includes = includes;
	}

	public void setLibraries(PortfolioList libraries) {
		this.libraries = libraries;
	}

	public void setLinkForDebug(boolean debug) {
		this.linkForDebug = debug;
	}

	public void setLinkForProfile(boolean profiling) {
		this.linkForProfile = profiling;
	}

	public void setLinkMapLevel(LinkMapLevel linkmapLevel) {
		this.linkmapLevel = linkmapLevel;
	}

	public void setListingLevel(ListingLevel level) {
		this.listingLevel = level;
	}

	public void setListings(Portfolio listings) {
		this.listings = listings;
	}

	public void setObjects(PortfolioList objects) {
		this.objects = objects;
	}

	/**
	 * Sets the portfolio returned by the CompileTask, containing the object
	 * files generated
	 *  
	 */
	public void setObjectsPortfolio(Portfolio objectPortfolio) {
		this.objectPortfolio = objectPortfolio;
	}

	public void setOptimisationLevel(OptimisationLevel optimLevel) {
		this.optimLevel = optimLevel;
	}

	public void setRedirectStdin(boolean what) {
		this.redirectStdin = what;
	}

	public void setSources(String[] sources) {
		this.sources = sources;
	}

	public void setStdin(String stdin) {
		this.stdinPath = stdin;
	}
}