/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.container;

import com.pallas.unicore.container.errorspec.ErrorSet;
import com.pallas.unicore.container.errorspec.UError;
import com.pallas.unicore.extensions.FileTest;
import com.pallas.unicore.extensions.ReturnCodeTest;
import com.pallas.unicore.extensions.TimeTest;

/**
 * @author Ralf Ratering
 * @version $Id: ControlContainer.java,v 1.1 2004/05/25 14:58:50 rmenday Exp $
 */
public abstract class ControlContainer extends GroupContainer {

	/**
	 * test file conditions
	 */
	protected FileTest fileTest;
	/**
	 * test return codes
	 */
	protected ReturnCodeTest returnCodeTest;
	/**
	 * test time
	 */
	protected TimeTest timeTest;

	/**
	 * Constructor
	 */
	public ControlContainer() {
		returnCodeTest = new ReturnCodeTest();
		fileTest = new FileTest();
		timeTest = new TimeTest();
	}

	/**
	 * Look for errors in tests
	 * 
	 * @return error set
	 */
	public ErrorSet checkContents() {
		ErrorSet err = super.checkContents();
		int enabled = 0;
		returnCodeTest.removeAddedFlags();
		if (returnCodeTest.isEnabled()) {
			enabled++;
			returnCodeTest.checkContents(err, this);
		}
		if (fileTest.isEnabled()) {
			enabled++;
			fileTest.checkContents(err, this);
		}
		if (timeTest.isEnabled()) {
			enabled++;
			timeTest.checkContents(err, this);
		}
		if (enabled == 0) {
			err.add(new UError(id,
					"All tests are disabled. Please choose a test."));
		}
		else if (enabled > 1) {
			err
					.add(new UError(id,
							"More than one test enabled. Please choose only one test."));
		}
		setErrors(err);
		return err;
	}

	/**
	 * Gets the fileTest
	 * 
	 * @return The fileTest value
	 */
	public FileTest getFileTest() {
		return fileTest;
	}

	/**
	 * Gets the return code test
	 * 
	 * @return The return code test
	 */
	public ReturnCodeTest getReturnCodeTest() {
		return returnCodeTest;
	}

	/**
	 * Gets the time test
	 * 
	 * @return The time test
	 */
	public TimeTest getTimeTest() {
		return timeTest;
	}

	/**
	 * Sets the file test
	 * 
	 * @param fileTest
	 */
	public void setFileTest(FileTest fileTest) {
		this.fileTest = fileTest;
	}

	/**
	 * Sets the returnCodeTest
	 * 
	 * @param returnCodeTest
	 */
	public void setReturnCodeTest(ReturnCodeTest returnCodeTest) {
		this.returnCodeTest = returnCodeTest;
	}

	/**
	 * Sets the timeTest
	 * 
	 * @param timeTest
	 */
	public void setTimeTest(TimeTest timeTest) {
		this.timeTest = timeTest;
	}
}