/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.container;

import java.util.Enumeration;
import java.util.logging.Level;
import org.unicore.ajo.AbstractAction;
import org.unicore.ajo.ActionGroup;
import org.unicore.ajo.Dependency;
import org.unicore.ajo.FileCheck;
import org.unicore.ajo.ProbeTime;
import org.unicore.ajo.RepeatGroup;
import org.unicore.ajo.TestSuccess;
import org.unicore.outcome.FileCheck_Outcome;
import org.unicore.outcome.ProbeTime_Outcome;
import org.unicore.outcome.TestSuccess_Outcome;
import com.pallas.unicore.extensions.ReturnCodeTest;
import com.pallas.unicore.extensions.TestType;
import com.pallas.unicore.extensions.TimeTest;

/**
 * Repeat until a file, return code or time condition is fulfilled
 * 
 * @author Ralf Ratering
 * @version $Id: DoRepeatContainer.java,v 1.1 2004/05/25 14:58:50 rmenday Exp $
 */
public class DoRepeatContainer extends ControlContainer {

	final static long serialVersionUID = -9063565457856815042L;

	/**
	 * Build main ActionGroup
	 */
	public void buildActionGroup() {
		// build the action group
		RepeatGroup repeatGroup = new RepeatGroup(getName() + "_RepeatGroup");
		// until mode, while won't work, because
		// decision files do not exist at loop start
		repeatGroup.setUntil();
		buildActionGroup(repeatGroup);
		// get last action for dependency
		AbstractAction lastAction = null;
		Enumeration actions = repeatGroup.getActions();
		while (actions.hasMoreElements()) {
			lastAction = (AbstractAction) actions.nextElement();
		}
		if (returnCodeTest.isEnabled()) {
			ActionContainer testContainer = getReturnCodeTest()
					.getTestContainer();
			ActionGroup testGroup = testContainer.getActionGroup();
			TestType type = returnCodeTest.getType();
			if (type.equals(ReturnCodeTest.SUCCESSFUL)
					|| type.equals(ReturnCodeTest.NOT_SUCCESSFUL)) {
				TestSuccess testSuccess = new TestSuccess(getName()
						+ "_TestSuccess");
				testSuccess.setTarget(testGroup);
				repeatGroup.add(testSuccess);
				try {
					repeatGroup.addDependency(new Dependency(testGroup,
							testSuccess));
				}
				catch (ActionGroup.InvalidDependencyException ex) {
					logger.log(Level.SEVERE, "Could not add dependency.", ex);
				}
				repeatGroup.setTestTask(testSuccess);
				if (type.equals(ReturnCodeTest.SUCCESSFUL)) {
					repeatGroup.setTest(TestSuccess_Outcome.SUCCESSFUL);
				}
				else {
					repeatGroup.setTest(TestSuccess_Outcome.NOT_SUCCESSFUL);
				}
			}
			else {
				repeatGroup.setTest(new Integer(returnCodeTest.getValue())
						.toString());
				TaskContainer testTask = (TaskContainer) testContainer;
				repeatGroup.setTestTask(testTask.getExecuteTask());
				// add ignore failure here explicitly, because
				// repeatGroup will fail, if not.
				//testTask.getExecuteTask().setPropagateSuccessfulIfNotSuccessful(true);
			}
		}
		else if (fileTest.isEnabled()) {
			FileCheck fileCheck = fileTest.getFileCheckTask();
			repeatGroup.setTestTask(fileCheck);
			repeatGroup.setTest(FileCheck_Outcome.SATISFIED);
			repeatGroup.add(fileCheck);
			if (lastAction != null) {
				try {
					repeatGroup.addDependency(new Dependency(lastAction,
							fileCheck));
				}
				catch (ActionGroup.InvalidDependencyException ex) {
					logger.log(Level.SEVERE, "Could not add dependency.", ex);
				}
			}
		}
		else if (timeTest.isEnabled()) {
			ProbeTime probeTime = new ProbeTime(getName() + "_ProbeTime");
			probeTime.setTime(getTimeTest().getDate());
			repeatGroup.setTestTask(probeTime);
			if (timeTest.getType().equals(TimeTest.AFTER)) {
				repeatGroup.setTest(ProbeTime_Outcome.LATER);
			}
			repeatGroup.add(probeTime);
			if (lastAction != null) {
				try {
					repeatGroup.addDependency(new Dependency(lastAction,
							probeTime));
				}
				catch (ActionGroup.InvalidDependencyException ex) {
					logger.log(Level.SEVERE, "Could not add dependency.", ex);
				}
			}
		}
	}
}