/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.container;

import java.util.Vector;
import java.util.logging.Level;

import org.unicore.ajo.ActionGroup;
import org.unicore.ajo.Dependency;
import org.unicore.ajo.FileCheck;
import org.unicore.ajo.If;
import org.unicore.ajo.ProbeTime;
import org.unicore.ajo.TestSuccess;
import org.unicore.outcome.FileCheck_Outcome;
import org.unicore.outcome.ProbeTime_Outcome;
import org.unicore.outcome.TestSuccess_Outcome;

import com.pallas.unicore.extensions.ReturnCodeTest;
import com.pallas.unicore.extensions.TestType;
import com.pallas.unicore.extensions.TimeTest;
import com.pallas.unicore.resourcemanager.ResourceManager;

/**
 *@author     Ralf Ratering
 *@author     Sven Haubold
 *@version    $Id: IfContainer.java,v 1.1 2004/05/25 14:58:50 rmenday Exp $
 */
public class IfContainer extends ControlContainer {

	final static long serialVersionUID = -9063565457856815042L;

	/**
	 *  Description of the Method
	 */
	public void buildActionGroup() {
		// build main action group
		actionGroup =
			new ActionGroup(
				getName()
					+ "_IfGroup_"
					+ ResourceManager.getNextObjectIdentifier());

		// synchronize identifiers to find corresponding outcomes for
		// container in jmc
		setIdentifier(actionGroup.getId());

		If ifTask =
			new If(
				getName()
					+ "_IfTask_"
					+ ResourceManager.getNextObjectIdentifier());
		actionGroup.add(ifTask);

		if (getReturnCodeTest().isEnabled()) {
			ActionContainer testContainer =
				getReturnCodeTest().getTestContainer();
			// make sure ActionGroup has been built at this point
			TestType type = getReturnCodeTest().getType();
			if (type.equals(ReturnCodeTest.SUCCESSFUL)
				|| type.equals(ReturnCodeTest.NOT_SUCCESSFUL)) {
				TestSuccess testSuccess =
					new TestSuccess(
						getName()
							+ "_TestSuccess_"
							+ ResourceManager.getNextObjectIdentifier());
				testSuccess.setTarget(testContainer.getActionGroup());
				actionGroup.add(testSuccess);
				try {
					actionGroup.addDependency(
						new Dependency(testSuccess, ifTask));
				} catch (ActionGroup.InvalidDependencyException ex) {
					logger.log(Level.SEVERE, "Could not add dependency.", ex);
				}
				ifTask.setTestTask(testSuccess);
				if (type.equals(ReturnCodeTest.SUCCESSFUL)) {
					ifTask.setTest(TestSuccess_Outcome.SUCCESSFUL);
				} else {
					ifTask.setTest(TestSuccess_Outcome.NOT_SUCCESSFUL);
				}
			} else {
				TaskContainer testTask = (TaskContainer) testContainer;
				ifTask.setTest(
					new Integer(getReturnCodeTest().getValue()).toString());
				ifTask.setTestTask(testTask.getExecuteTask());
				// add ignore failure here explicitly, because
				// If task will fail, if not.
				//testTask.getExecuteTask().setPropagateSuccessfulIfNotSuccessful(true);
			}
		} else if (getFileTest().isEnabled()) {
			FileCheck fileCheck = getFileTest().getFileCheckTask();
			ifTask.setTestTask(fileCheck);
			ifTask.setTest(FileCheck_Outcome.SATISFIED);
			actionGroup.add(fileCheck);
			try {
				actionGroup.addDependency(new Dependency(fileCheck, ifTask));
			} catch (ActionGroup.InvalidDependencyException ex) {
				logger.log(Level.SEVERE, "Could not add dependency.", ex);
			}
		} else if (getTimeTest().isEnabled()) {
			ProbeTime probeTime =
				new ProbeTime(
					getName()
						+ "_ProbeTime_"
						+ ResourceManager.getNextObjectIdentifier());
			probeTime.setTime(getTimeTest().getDate());
			ifTask.setTestTask(probeTime);
			if (timeTest.getType().equals(TimeTest.AFTER)) {
				ifTask.setTest(ProbeTime_Outcome.LATER);
			}
			actionGroup.add(probeTime);
			try {
				actionGroup.addDependency(new Dependency(probeTime, ifTask));
			} catch (ActionGroup.InvalidDependencyException ex) {
				logger.log(Level.SEVERE, "Could not add dependency.", ex);
			}
		}

		getThenContainer().buildActionGroup();
		getElseContainer().buildActionGroup();

		if (this.getReturnCodeTest().isEnabled()
			&& this.getReturnCodeTest().getType().equals(
				ReturnCodeTest.NOT_EQUAL)) {
			ifTask.setTrueBranch(this.getElseContainer().getActionGroup());
			ifTask.setFalseBranch(this.getThenContainer().getActionGroup());
		} else {
			ifTask.setTrueBranch(getThenContainer().getActionGroup());
			ifTask.setFalseBranch(getElseContainer().getActionGroup());
		}
	}

	/**
	 *  Gets the elseGroup attribute of the IfContainer object
	 *
	 *@return    The elseGroup value
	 */
	public ElseContainer getElseContainer() {
		Vector tasks = getTasks();
		for (int i = 0; i < tasks.size(); i++) {
			ActionContainer container = (ActionContainer) tasks.elementAt(i);
			if (container instanceof ElseContainer) {
				return (ElseContainer) container;
			}
		}
		return null;
	}

	/**
	 *  Gets the thenGroup attribute of the IfContainer object
	 *
	 *@return    The thenGroup value
	 */
	public ThenContainer getThenContainer() {
		Vector tasks = getTasks();
		for (int i = 0; i < tasks.size(); i++) {
			ActionContainer container = (ActionContainer) tasks.elementAt(i);
			if (container instanceof ThenContainer) {
				return (ThenContainer) container;
			}
		}
		return null;
	}
}
