/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.extensions;

import java.util.Date;
import java.util.Vector;
import com.pallas.unicore.container.ActionContainer;
import com.pallas.unicore.container.errorspec.ErrorSet;

/**
 * Wait for a certain date or forever.
 * 
 * @author Ralf Ratering
 * @version $Id: HoldJobTest.java,v 1.1 2004/05/25 14:58:45 rmenday Exp $
 */
public class HoldJobTest extends AbstractTest {

	/**
	 * wait forever
	 */
	public final static HoldJobTestType FOREVER = new HoldJobTestType(
			HoldJobTestType.FOREVER);
	/**
	 * wait until a certain date
	 */
	public final static HoldJobTestType UNTIL = new HoldJobTestType(
			HoldJobTestType.UNTIL);
	final static long serialVersionUID = -5802782047852301472L;
	private static Vector types;
	private Date date = new Date();
	private boolean useToday;

	/**
	 * Get all test types
	 * 
	 * @return Vector containing all types
	 */
	public static Vector getTypes() {
		if (types == null) {
			types = new Vector();
			types.add(DISABLED);
			types.add(FOREVER);
			types.add(UNTIL);
		}
		return types;
	}

	/**
	 * Constructor
	 */
	public HoldJobTest() {
		// intially set "wait until"
		this.type = UNTIL;
	}

	/**
	 * check test parameters
	 * 
	 * @param errorSet
	 *            ErrorSet that errors will be added to
	 * @param container
	 *            container belonging to test
	 * @return updated error set
	 */
	public ErrorSet checkContents(ErrorSet errorSet, ActionContainer container) {
		super.checkContents(errorSet, container);
		return errorSet;
	}

	/**
	 * Gets the date
	 * 
	 * @return date to wait for
	 */
	public Date getDate() {
		return date;
	}

	/**
	 * wait for a certain time today
	 * 
	 * @return true if we wait for a time today
	 */
	public boolean getUseToday() {
		return useToday;
	}

	/**
	 * Set date to wait for
	 * 
	 * @param date
	 *            date to wait for
	 */
	public void setDate(Date date) {
		this.date = date;
	}

	/**
	 * Wait for a certain time today?
	 * 
	 * @param useToday
	 *            true, if we wait for a certain time today
	 */
	public void setUseToday(boolean useToday) {
		this.useToday = useToday;
	}

	/**
	 * Overwrite super class method
	 * 
	 * @return String description
	 */
	public String toString() {
		return "Wait " + type + " " + date;
	}
}