/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.requests;

import java.io.ByteArrayInputStream;
import java.io.ObjectInputStream;
import java.util.logging.Level;
import org.unicore.AAIdentifier;
import org.unicore.User;
import org.unicore.Vsite;
import org.unicore.ajo.AbstractJob;
import org.unicore.ajo.Control;
import org.unicore.ajo.ControlAction;
import org.unicore.ajo.WaitUntil;
import org.unicore.outcome.AbstractJob_Outcome;
import org.unicore.outcome.ControlAction_Outcome;
import org.unicore.outcome.Outcome;
import org.unicore.upl.Reply;
import org.unicore.upl.RetrieveOutcomeReply;
import org.unicore.upl.UnicoreResponse;
import org.unicore.utility.ConsignForm;
import com.pallas.unicore.client.trees.ContainerNode;
import com.pallas.unicore.container.ActionContainer;
import com.pallas.unicore.container.HoldJobContainer;
import com.pallas.unicore.container.JobContainer;
import com.pallas.unicore.resourcemanager.ResourceManager;
import com.pallas.unicore.utility.UserMessages;

/**
 * Send a control action to a job in the job monitor
 * 
 * @author Thomas Kentemich
 * @version $Id: ControlActionService.java,v 1.1 2004/05/25 14:58:54 rmenday Exp $
 */
public class ControlActionService extends ObservableNodeThread {

	private Control control;
	private UnicoreResponse response = new UnicoreResponse(0, "<None>");

	/**
	 * Constructor
	 * 
	 * @param node
	 *            Job node in job monitor tree, that will receive the control
	 *            action
	 * @param control
	 *            control action
	 */
	public ControlActionService(ContainerNode node, Control control) {
		super(node);
		this.control = control;
	}

	/**
	 * Method will be called from start() method in Thread
	 */
	public void run() {
		try {
			//generating the job
			//first, the " GetJobs" task
			if ((control == null)) {
				throw new Exception("Illegal parameter!!");
			}
			getNode().setState(ActionContainer.STATE_UPDATING);
			ActionContainer ac = (ActionContainer) getNode().getUserObject();
			JobContainer parent = null;
			if (ac.getParentJobContainer() == null) {
				parent = (JobContainer) ac;
			}
			else {
				parent = ac.getParentJobContainer();
			}
			Vsite vsite = parent.getVsite();
			User user = parent.getUser();
			AAIdentifier id = ac.getIdentifier();
			// for hold tasks do not use the ActionGroup identifier,
			// but instead the WaitUntil id.
			if (ac instanceof HoldJobContainer) {
				HoldJobContainer holdTask = (HoldJobContainer) ac;
				WaitUntil waitUntil = holdTask.getWaitUntil();
				id = waitUntil.getId();
			}
			ControlAction ca = new ControlAction(servicePrefix + "_Control_("
					+ id.getName() + ")", id, control);
			AbstractJob job = new AbstractJob(servicePrefix + "_Control_"
					+ ResourceManager.getNextObjectIdentifier(), null, null,
					vsite, user);
			job.add(ca);
			Reply roReply = nonPolling(job, vsite, user);
			response = roReply.getLastEntry();
			// now analyze outcome
			ControlAction_Outcome cao = null;
			if (!(roReply instanceof RetrieveOutcomeReply)) {
				throw new Exception("Cannot contact virtual site " + vsite
						+ "\nReason: " + roReply.getLastEntry().getComment());
			}
			else {
				// deserialize the Outcome Object
				Outcome outcome = (Outcome) new ObjectInputStream(
						new ByteArrayInputStream(
								((RetrieveOutcomeReply) roReply).getOutcome()))
						.readObject();
				if (outcome instanceof AbstractJob_Outcome) {
					AbstractJob_Outcome aj_out = ConsignForm
							.convertFrom((AbstractJob_Outcome) outcome);
					cao = (ControlAction_Outcome) aj_out.getOutcome(ca.getId());
					ac.setStatus(cao.getStatus(id));
				}
				else {
					throw new Exception("Unexpected type of outcome " + outcome);
				}
			}
		}
		catch (Exception e) {
			UserMessages.warning("Executing control action failed.");
			logger.log(Level.SEVERE, "Executing control action failed.", e);
		}
		notifyObservers(this, response);
	}
}