/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.requests;

import java.io.ByteArrayInputStream;
import java.io.ObjectInputStream;
import org.unicore.User;
import org.unicore.Vsite;
import org.unicore.ajo.AbstractJob;
import org.unicore.ajo.GetResourceDescription;
import org.unicore.outcome.AbstractJob_Outcome;
import org.unicore.outcome.GetResourceDescription_Outcome;
import org.unicore.outcome.Outcome;
import org.unicore.sets.OutcomeEnumeration;
import org.unicore.upl.Reply;
import org.unicore.upl.RetrieveOutcomeReply;
import org.unicore.utility.ConsignForm;
import com.pallas.unicore.extensions.NamedResourceSet;
import com.pallas.unicore.resourcemanager.ResourceCache;
import com.pallas.unicore.resourcemanager.ResourceManager;

/**
 * Get resource set from a virtual site
 * 
 * @author Ralf Ratering
 * @version $Id: GetResources.java,v 1.1 2004/05/25 14:58:54 rmenday Exp $
 */
public class GetResources extends ObservableRequestThread {

	private Vsite vsite;

	/**
	 * Constructor
	 * 
	 * @param vsite
	 *            virtual site to get resources from
	 */
	public GetResources(Vsite vsite) {
		this.vsite = vsite;
	}

	/**
	 * Get the virtual site
	 * 
	 * @return vsite
	 */
	public Vsite getVsite() {
		return vsite;
	}

	/**
	 * Start the Thread
	 */
	public void run() {
		logger.info("Detecting resources for vsite " + vsite.getName());
		//		ResourceManager.loadResources(vsite);
		ResourceCache resourceCache = ResourceManager.getResourceCache();
		if (ResourceManager.isOffline()
				|| !resourceCache.isVsiteAvailable(vsite)) {
			return;
		}
		// use user specified for the Vsite
		User user = ResourceManager.getUser(vsite);
		logger.info("Updating resources for vsite " + vsite.getName()
				+ " user " + user);
		//generating the job
		//first, the " GetResourceDescription" task
		GetResourceDescription grd = new GetResourceDescription(
				"ResourceDescription(" + vsite + ")", null);
		AbstractJob job = new AbstractJob(ResourceManager.getServicePrefix()
				+ "_GetResources" + ResourceManager.getNextObjectIdentifier(),
				null, null, vsite, user);
		job.add(grd);
		// submit the job in non-polling mode
		Reply roReply = nonPolling(job, vsite, user);
		// now analyze outcome
		if (!(roReply instanceof RetrieveOutcomeReply)) {
			logger.info("Could not contact virtual site " + vsite);
		}
		else {
			// deserialize the Outcome Object
			try {
				Outcome outcome = (Outcome) new ObjectInputStream(
						new ByteArrayInputStream(
								((RetrieveOutcomeReply) roReply).getOutcome()))
						.readObject();
				if (outcome instanceof AbstractJob_Outcome) {
					AbstractJob_Outcome aj_out = ConsignForm
							.convertFrom((AbstractJob_Outcome) outcome);
					OutcomeEnumeration oen = aj_out.getOutcomes();
					while (oen.hasMoreElements()) {
						Outcome next = oen.nextElement();
						if (next instanceof GetResourceDescription_Outcome) {
							GetResourceDescription_Outcome resourceOutcome = (GetResourceDescription_Outcome) next;
							NamedResourceSet resourceSet = new NamedResourceSet(
									"Site Resources for " + vsite,
									resourceOutcome.getResources());
							resourceCache.addResourceSet(vsite, resourceSet);
						}
					}
				}
			}
			catch (Exception e) {
				resourceCache.addUnavailableVsite(vsite,
						"Cannot load resources:" + "\nReason: "
								+ e.getMessage());
			}
		}
		notifyObservers(this, ResourceManager.getResourceSet(vsite));
	}
}