/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.requests;

import java.util.Vector;
import org.unicore.Vsite;
import com.pallas.unicore.extensions.Usite;
import com.pallas.unicore.resourcemanager.ResourceManager;
import com.pallas.unicore.threadpool.IObserver;
import com.pallas.unicore.utility.UserMessages;

/**
 * Update all Usites, Vsites and resource sets
 * 
 * @author Thomas Kentemich
 * @author Ralf Ratering
 * @version $Id: SiteDetector.java,v 1.1 2004/05/25 14:58:54 rmenday Exp $
 */
public class SiteDetector extends ObservableThread implements IObserver {

	private static boolean isRunning = false;
	private Vector runningThreads = new Vector();

	/**
	 * Get notified when a request returns
	 * 
	 * @param theObserved
	 *            Request that returns
	 * @param changeCode
	 *            notification object
	 */
	public void observableUpdate(Object theObserved, Object changeCode) {
		// ignore returning threads that have been canceled
		if (!runningThreads.contains(theObserved)) {
			return;
		}
		// pass event to observers
		notifyObservers(theObserved, changeCode);
		if (theObserved instanceof GetUsites) {
			logger.info("Detecting usites finished.");
			Vector usites = (Vector) changeCode;
			for (int i = 0; i < usites.size(); i++) {
				logger.info("Found Usite: " + (Usite) usites.elementAt(i));
				GetVsites getVsites = new GetVsites((Usite) usites.elementAt(i));
				runningThreads.add(getVsites);
				getVsites.addObserver(this);
				getVsites.start();
			}
		}
		else if (theObserved instanceof GetVsites) {
			logger.info("Detecting vsites for "
					+ ((GetVsites) theObserved).getUsite() + " finished.");
			Vector vsites = (Vector) changeCode;
			for (int i = 0; i < vsites.size(); i++) {
				Vsite vsite = (Vsite) vsites.elementAt(i);
				logger.info("Found Vsite: " + vsite);
				if (ResourceManager.isVsiteAvailable(vsite)) {
					GetResources getResources = new GetResources(vsite);
					runningThreads.add(getResources);
					getResources.addObserver(this);
					getResources.start();
				}
			}
		}
		else if (theObserved instanceof GetResources) {
			logger.info("Returned from getting resource set for vsite: "
					+ ((GetResources) theObserved).getVsite());
		}
		runningThreads.remove(theObserved);
		// tell observer about running threads left
		notifyObservers(this, new Integer(runningThreads.size()));
		isRunning = runningThreads.size() > 0;
	}

	/**
	 * Main processing method for the SiteDetector object
	 */
	public void run() {
		if (ResourceManager.isOffline()) {
			isRunning = false;
			return;
		}
		if (isRunning) {
			UserMessages
					.info("Resource update is already running."
							+ "\nPlease wait until last run is finished before re-loading again.");
			return;
		}
		isRunning = true;
		logger
				.info("Loading usite, vsite and resource information into cache.");
		startThreads();
	}

	private void startThreads() {
		logger.info("Reading usites from usite page.");
		GetUsites getUsites = new GetUsites();
		runningThreads.add(getUsites);
		getUsites.addObserver(this);
		getUsites.start();
	}

	/**
	 * Stop all threads
	 */
	public void stopThreads() {
		isRunning = false;
		runningThreads.clear();
		notifyObservers(this, new Integer(runningThreads.size()));
	}
}