/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.resourcemanager;

import java.util.Date;
import java.util.Vector;
import org.unicore.AAIdentifier;
import org.unicore.outcome.AbstractActionStatus;
import com.pallas.unicore.container.ActionContainer;

/**
 * @author Ralf Ratering
 * @version $Id: DetailsEntry.java,v 1.1 2004/05/25 14:58:51 rmenday Exp $
 */
public class DetailsEntry extends Vector implements Comparable {

	private static int compareIndex = 0;
	private static int secondIndex = 0;

	public static void setCompareIndex(int _compareIndex, int _secondIndex) {
		compareIndex = _compareIndex;
		secondIndex = _secondIndex;
	}
	private AAIdentifier action;
	private ActionContainer container;
	private String description;
	private String iteration;
	private String reason;
	private AbstractActionStatus status;
	private Date timeStamp;

	public DetailsEntry(Date timeStamp, ActionContainer container,
			String description, AbstractActionStatus status, String reason,
			String iteration, AAIdentifier action) {
		this.timeStamp = timeStamp;
		this.container = container;
		this.description = description;
		this.status = status;
		this.reason = reason;
		this.iteration = iteration;
		this.action = action;
		add(timeStamp);
		add(container);
		add(description);
		add(status);
		add(reason);
		add(iteration);
	}

	public Comparable comparableAt(int i) {
		if (elementAt(i) instanceof ActionContainer
				|| elementAt(i) instanceof AbstractActionStatus) {
			return elementAt(i).toString();
		}
		return (Comparable) elementAt(i);
	}

	public int compareTo(Object object) {
		int value = comparableAt(compareIndex).compareTo(
				((DetailsEntry) object).comparableAt(compareIndex));
		if (value == 0 && compareIndex != secondIndex) {
			value = comparableAt(secondIndex).compareTo(
					((DetailsEntry) object).comparableAt(secondIndex));
		}
		return value;
	}

	public ActionContainer getContainer() {
		return container;
	}

	public String getIteration() {
		return iteration;
	}

	public String getReason() {
		return reason;
	}

	public AbstractActionStatus getStatus() {
		return status;
	}

	public String toString() {
		String result = "Name:        " + container.getName() + "\n";
		result += "Description: " + description + "\n";
		result += "Action:      " + action.getName() + "\n";
		result += "Status:      " + status + "\n";
		result += "Time:        " + timeStamp + "\n";
		result += "Iteration:   " + iteration + "\n";
		result += "Reason:      " + reason + "\n";
		return result;
	}
}