/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.resourcemanager;

import java.io.File;
import java.util.Date;
import org.unicore.ajo.AbstractAction;
import org.unicore.outcome.Outcome;

/**
 * @author Ralf Ratering
 * @version $Id: OutcomeEntry.java,v 1.1 2004/05/25 14:58:51 rmenday Exp $
 */
public class OutcomeEntry implements Comparable {

	private AbstractAction action;
	private String iteration;
	protected Outcome outcome;
	private File stdoutFile, stderrFile;

	public OutcomeEntry(AbstractAction action) {
		this.action = action;
	}

	public int compareTo(Object object) {
		OutcomeEntry entry2 = (OutcomeEntry) object;
		if (outcome == entry2.getOutcome()) {
			return 0;
		}
		if (outcome == null && entry2.getOutcome() != null) {
			return -1;
		}
		if (outcome != null && entry2.getOutcome() == null) {
			return 1;
		}
		Date time1 = outcome.getStatusHistory().getLastTime();
		Date time2 = entry2.getOutcome().getStatusHistory().getLastTime();
		return time1.compareTo(time2);
	}

	public AbstractAction getAction() {
		return action;
	}

	public String getIteration() {
		return iteration;
	}

	public String getLog() {
		return outcome.getLog().toString();
	}

	public Outcome getOutcome() {
		return outcome;
	}

	public File getStderrFile() {
		return stderrFile;
	}

	public File getStdoutFile() {
		return stdoutFile;
	}

	public Date getTimeStamp() {
		return outcome.getStatusHistory().getLastTime();
	}

	public void setIteration(String iteration) {
		this.iteration = iteration;
	}

	public void setOutcome(Outcome outcome) {
		this.outcome = outcome;
	}

	public void setStderrFile(File stderrFile) {
		this.stderrFile = stderrFile;
	}

	public void setStdoutFile(File stdoutFile) {
		this.stdoutFile = stdoutFile;
	}

	public String toString() {
		return "******** Outcome:   " + outcome + "\n" + "******** Iteration: "
				+ iteration + "\n" + "******** Stdout:    " + stdoutFile + "\n"
				+ "******** Stderr:    " + stdoutFile + "\n";
	}
}