/*
 * Copyright (c) 2000-2004, Intel Corporation All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * (1) Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the disclaimer at the end. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution.
 * 
 * (2) Neither the name of Intel Corporation nor the names of its contributors
 * may be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package com.pallas.unicore.security;

import java.security.Signature;
import java.util.logging.Level;
import java.util.logging.Logger;
import org.unicore.User;
import com.pallas.unicore.resourcemanager.ResourceManager;

/**
 * @author Thomas Kentemich
 * @version $Id: AjoSigner.java,v 1.1 2004/05/25 14:58:55 rmenday Exp $
 */
public class AjoSigner
		implements
			org.unicore.utility.ConsignForm.SignatureFactory {

	private static Logger logger = Logger
			.getLogger("com.pallas.unicore.security");

	public static AjoSigner getSigner(User user) {
		return new AjoSigner(user);
	}
	//private final static AjoSigner ajoSigner = new AjoSigner();
	private User user = null;

	private AjoSigner(User user) {
		if (user != null) {
			logger.fine("Generate new job signer for: "
					+ user.getCertificate().getSubjectDN());
		}
		else {
			logger.fine("Generate new job signer for: <NULL>");
		}
		this.user = user;
	}

	/**
	 * Implementation of the AJO SignatureFactory interface This is called when
	 * consigning AJO's in order to sign each sub-AJO with a newly initialized
	 * Signature object.
	 * 
	 *  
	 */
	public Signature getInstance() {
		Signature signature = null;
		try {
			return ResourceManager.getKeystoreManager().getSignature(
					user.getCertificate());
		}
		catch (Exception e) {
			logger.log(Level.WARNING, "Could not get signature for user "
					+ user.getCertificate().getSubjectDN() + " from keystore.",
					e);
		}
		return signature;
	}
}