package org.unicore.ajo;

import java.util.Date;

import org.unicore.sets.ResourceSet;

/**
 * Book some resources.
 * <p>
 * @see org.unicore.outcome.BookResources_Outcome
 * 
 * @author D. Snelling (fecit)
 * @author S. van den Berghe (fecit)
 *
 * @since AJO 3
 *
 * @version BookResources.java 1.5 09/09/02 
 *
 **/
public final class BookResources extends QueryService {

    static final long serialVersionUID = -3405342389036550829L;

    public BookResources() {
        this("");
    }

    /**
     * Create a new BookResources.
     * <p>
     * @param name The name of the BookResources
     * @param extra_information Client supplied extra information about the BookResources
     * @param to_book The resource to book
     * @param start_time Time to book resources for
     *
     **/
    public BookResources(String name, 
                         byte[] extra_information, 
                         ResourceSet to_book, 
                         Date start_time) {
        super(name,extra_information);

        this.to_book = to_book;
        this.start_time = start_time;
    }

    /**
     * Create a new BookResources.
     * <p>
     * @param name The name of the BookResources
     * @param to_book The resource to book
     * @param start_time Time to book resources for
     *
     **/
    public BookResources(String name, ResourceSet to_book, Date start_time) {
        this(name, (byte[]) null, to_book, start_time);
    }

    /**
     * Create a new BookResources.
     * <p>
     * @param name The name of the BookResources
     *
     **/
    public BookResources(String name) {
        this(name,(byte[]) null, (ResourceSet) null, (Date) null);
    }

    private ResourceSet to_book;

    /**
     * Return the resource to book.
     *
     **/
    public ResourceSet getResourcesToBook() {return to_book;}

    /**
     * Set the resource to book.
     *
     **/
    public void setResourcesToBook(ResourceSet to_book) {this.to_book = to_book;}

    private Date start_time;

    /**
     * Return the time to book the resources for.
     *
     **/
    public Date getStartTime() {return start_time;}

    /**
     * Set the time to book the resources for.
     *
     **/
    public void setStartTime(Date start_time) {this.start_time = start_time;}
}
//
// Change history:
//          18 Mar 2002 SvdB V4 no arg constructor
//           5 May 2000 SvdB Created for V3.0 
//
//             Copyright (c) UNICORE Forum e.V. 2000 - 2002
//
//     Use and distribution is subject to the Community Source Licence.
//     A copy of the Community Source Licence came with this distribution.
//
//     Further information can be obtained from www.unicore.org
