package org.unicore.ajo;

import java.util.Enumeration;

/**
 * The controls that can be applied to AbstractActions.
 *
 * @see org.unicore.ajo.ControlAction
 *
 * @author S. van den Berghe (fecit)
 *
 * @since AJO 2
 *
 * @version Control.java 1.5 05/13/02
 *
 **/
 
public final class Control extends Enum {

    static final long serialVersionUID = -900609092103692692L;

    /**
     * Abort. 
     * <p>
     * Kill the AbstractAction and save any Outcome created so far.
     *
     **/
    public final static Control 
            ABORT = new Control(0,"Abort");

    /**
     * Cancel. 
     * <p>
     * Kill the AbstractAction and do not save the Outcome.
     *
     **/
    public final static Control 
            CANCEL = new Control(1,"Cancel");

    /**
     * Hold. 
     * <p>
     * Suspend execution of active AbstractActions.
     * Do not start execution of any pending ones.
     * Do not start any new child actions (if the target is 
     * a ActionGroup).
     *
     **/
    public final static Control 
            HOLD = new Control(2,"Hold");

    /**
     * Resume. 
     * <p>
     * Resume execution of held AbstractActions.
     *
     **/
    public final static Control 
            RESUME = new Control(3,"Resume");

    /**
     * Constructor for this Class.
     *
     * @param aValue The value for this instance.
     * @param aName The name for this instance.
     *
     **/
    private Control(int aValue, String aName) {
        super(aValue,aName);
    }

    /**
     * Return a enumeration over the instances of Control.
     *
     * @return The enumeration
     *
     **/
    public static Enumeration elements() {
        return Enum.elements( ABORT.getClass() );
    }


}
//
// Change history:
//          18 Dec 2000 SvdB corrected sense of Cancel and Abort
//           5 May 2000 SvdB V3.0 
//           7 Dec 1998 SvdB Second release to Unicore 
//           5 Nov 1998 SvdB Created 
//
//             Copyright (c) UNICORE Forum e.V. 2000 - 2002
//
//     Use and distribution is subject to the Community Source Licence.
//     A copy of the Community Source Licence came with this distribution.
//
//     Further information can be obtained from www.unicore.org
