package org.unicore.ajo;

import org.unicore.Unicore;

/**
 * Dependency is an ordering relationship between two 
 * AbstractActions in an {@link org.unicore.ajo.ActionGroup}.
 * <p>
 * The successor task cannot be considered for execution until the predecessor
 * task is complete. 
 *<p>
 *
 * @author S. van den Berghe (fecit)
 *
 * @since AJO 1
 *
 * @version Dependency.java 1.4 05/13/02 
 * 
 **/
public final class Dependency extends Unicore {

    static final long serialVersionUID = 6240822680091605094L;

        private AbstractAction predecessor;
        /**
         * Get the predecessor AbstractAction.
         *
         **/
        public AbstractAction getPredecessor() {return predecessor;}

        private AbstractAction successor;
        /**
         * Get the successor AbstractAction.
         *
         * @return The second <tt>AbstractAction</tt> of the <tt>Dependency</tt>.
         *
         **/
        public AbstractAction getSuccessor() {return successor;}

        public Dependency() {
            this(null,null);
        }

        /**
         * Create a new Dependency.
         *
         * @param pred The predecessor AbstractAction
         * @param succ The successor AbstractAction
         *
         **/
        public Dependency(AbstractAction pred, AbstractAction suc) {
            predecessor = pred;
            successor   = suc;
        }

        /**
         * Dependencies are the same if they have the same predecessor
         * and successor. 
         *
         **/
        public boolean equals(Object in) {
         return ( in.getClass() ==  this.getClass() &&
             ((Dependency)in).getPredecessor().equals( predecessor ) &&
             ((Dependency)in).getSuccessor().equals( successor ) );
        }


        // Dependencies are likely to be kept in collections and
        // so hashCode will be called. If a Dependency is equal we
        // want the same hashCode. This will clash, but what else
        // can we do?

        public int hashCode() { 
            return predecessor.hashCode() ^ successor.hashCode(); 
        }

}
//
// Change history:
//          18 Mar 2002 SvdB V4 no arg constructor
//           5 May 2000 SvdB V3.0 
//           7 Dec 1998 SvdB Second release to Unicore 
//          12 Jun 1998 SvdB Initial release to Unicore 
//
//             Copyright (c) UNICORE Forum e.V. 2000 - 2002
//
//     Use and distribution is subject to the Community Source Licence.
//     A copy of the Community Source Licence came with this distribution.
//
//     Further information can be obtained from www.unicore.org
