package org.unicore.ajo;

import org.unicore.FifoIdentifier;

/**
 * An NJS handle to an object that will be incarnated in a way
 * that supports the fifo-like operations where one end of the
 * fifo is an application and the other end is the NJS.
 *
 * @see MakeFifo
 * @see org.unicore.idiomatic.Stream
 * @see MoveFifoToOutcome
 *
 * @author S. van den Berghe (fecit)
 * @author D. Snelling (fecit)
 *
 * @since AJO 4.0
 *
 * @version Fifo.java 1.1 05/13/02 
 * 
 **/
public final class Fifo extends org.unicore.Unicore {

    static final long serialVersionUID = 0;

    public Fifo() {
        this("");
    }

    /**
     * Create a new Fifo of this name.
     *
     **/
    public Fifo(String name) {
        id = new FifoIdentifier(name);
    }

    /**
     * Create a new Fifo of this name and Identity.
     *
     **/
    public Fifo(String name, int identity) {
        id = new FifoIdentifier(name, identity);
    }

    /**
     * Return the Fifo's name. 
     * <p>
     * The incarnated fifo will use this name
     *
     **/
    public String getName() {return id.getName();}

    /**
     * Set the Fifo's name.
     *
     **/
    public void setName(String name) {id.setName(name);}

    private FifoIdentifier id;
    /**
     * Return the Identifier of the Fifo.
     *
     **/
    public FifoIdentifier getId() { return id; }

    /**
     * Test for equality using the Fifo's Identifier. 
     * <p>
     * The Identifier is used to identify the Fifo and so we
     * need to provide an implementation of equals that uses
     * this value.
     *
     **/
    public boolean equals(Object in) {
        return( in.getClass() ==  this.getClass() &&
                id.equals(((Fifo)in).getId()) 
              );
    }

    /**
     * Return a hash code based on the Fifo's Identifier.
     *
     **/
    public int hashCode() {return id.hashCode();}


    private String notes;
    /**
     * Return the notes added to this Fifo.
     * <p>
     * The notes string is a space for clients to add information
     * about the purpose of an Fifo.
     *
     **/
    public String getNotes() {return notes;}

    /**
     * Set some notes to this Fifo.
     *
     **/
    public void setNotes(String notes) {this.notes = notes;}

    public String toString() {return getName();}

}
//
// Change log:
//          23 Apr 2002 SvdB Created
//
//             Copyright (c) UNICORE Forum e.V. 2000 - 2002
//
//     Use and distribution is subject to the Community Source Licence.
//     A copy of the Community Source Licence came with this distribution.
//
//     Further information can be obtained from www.unicore.org
