package org.unicore.ajo;

import org.unicore.sets.PortfolioSet;
import org.unicore.sets.PortfolioList;
import org.unicore.sets.OptionSet;
import org.unicore.sets.ResourceSet;

/**
 * Compile Fortran source code using a Fortran 90 compiler.
 * <p>
 * @see org.unicore.outcome.FortranTask_Outcome
 *
 * @author S. van den Berghe (fecit)
 *
 * @since AJO 1
 *
 * @version FortranTask.java 1.5 05/13/02 
 * 
 **/
public final class FortranTask extends CompileTask {

    static final long serialVersionUID = 2256911625681887316L;

    /**
     * Create a new FortranTask
     *
     **/
    public FortranTask ( String name,
                         byte[] extra_information,
                         ResourceSet resource_limits,
                         OptionSet environment_variables,
                         String command_line,
                         Portfolio stdin,
                         boolean redirect_stdout,
                         boolean redirect_stderr,
                         boolean verbose,
                         boolean version,
                         PortfolioSet sources,
                         ListingLevel list_level,
                         OptimisationLevel opt_level,
                         PortfolioList includes,
                         boolean compile_for_debug,
                         boolean compile_for_profile,
                         boolean bounds_checking,
                         boolean arg_checking,
                         IntegerLength integer_length,
                         RealLength real_length,
                         DoubleLength double_length,
                         FortranSourceForm source_form,
                         PreprocessLevel preprocess,
                         OptionSet defines,
                         OptionSet undefines
                       ) {
        super(name,extra_information,resource_limits,
              environment_variables,command_line,
              stdin,redirect_stdout, redirect_stderr,verbose,version,sources,list_level,
              opt_level,includes, compile_for_debug, compile_for_profile);

        this.bounds_checking = bounds_checking;
        this.arg_checking = arg_checking;
        this.integer_length = integer_length;
        this.real_length = real_length;
        this.double_length = double_length;
        this.source_form = source_form;
        this.defines = defines;
        this.undefines = undefines;
        this.preprocess = preprocess;
    }
                           
    /**
     * Create a new FortranTask
     *
     **/
    public FortranTask ( String name,
                         ResourceSet resource_limits,
                         OptionSet environment_variables,
                         String command_line,
                         Portfolio stdin,
                         boolean redirect_stdout,
                         boolean redirect_stderr,
                         boolean verbose,
                         boolean version,
                         PortfolioSet sources,
                         ListingLevel list_level,
                         OptimisationLevel opt_level,
                         PortfolioList includes,
                         boolean compile_for_debug,
                         boolean compile_for_profile,
                         boolean bounds_checking,
                         boolean arg_checking,
                         IntegerLength integer_length,
                         RealLength real_length,
                         DoubleLength double_length,
                         FortranSourceForm source_form,
                         PreprocessLevel preprocess,
                         OptionSet defines,
                         OptionSet undefines
                       ) {
        this(name,(byte[]) null,resource_limits,
              environment_variables,command_line,
              stdin,redirect_stdout, redirect_stderr,verbose,version,sources,list_level,
              opt_level,includes, compile_for_debug, compile_for_profile,
              bounds_checking, arg_checking, integer_length, real_length,
              double_length, source_form, preprocess, defines, undefines);
    }
                           
    /**
     * Create a new FortranTask
     *
     **/
    public FortranTask (String name) {
        this( name,(byte[]) null, (ResourceSet) null,
              (OptionSet) null, (String) null,
              (Portfolio) null, false, false, false, false, (PortfolioSet)null, ListingLevel.NONE,
              OptimisationLevel.NONE, (PortfolioList) null,  false,  false,
              false,  false, IntegerLength.DONTCARE, RealLength.DONTCARE,
              DoubleLength.DONTCARE, FortranSourceForm.FREE, PreprocessLevel.NONE, 
              (OptionSet) null, (OptionSet) null);
    }

    public FortranTask () {
        this("");
    }
                           
    private boolean bounds_checking;
    /**
     * Should the compiler insert bounds checking code?
     *
     **/
    public boolean isBoundsCheckingOn() {return bounds_checking;}

    /**
     * Set bounds checking policy
     *
     **/
    public void setBoundsChecking(boolean bounds_checking) {this.bounds_checking = bounds_checking;}


    private boolean arg_checking;
    /**
     * Should the compiler insert arguemnt checking code?
     *
     **/
    public boolean isArgCheckingOn() {return arg_checking;}

    /**
     * Set argument checking policy
     *
     **/
    public void setArgChecking(boolean arg_checking) {this.arg_checking = arg_checking;}

    private IntegerLength integer_length;
    /**
     * Return the length of variables declared using
     * the default "integer". 
     *
     **/
    public IntegerLength getIntegerLength() {return integer_length;}

    /**
     * Set the length of variables declared using
     * the default "integer". 
     *
     **/
    public void setIntegerLength(IntegerLength integer_length) {this.integer_length = integer_length;}

    private RealLength real_length;
    /**
     * Return the length of variables declared using
     * the default "real" nor "complex". 
     *
     **/
    public RealLength getRealLength() {return real_length;}

    /**
     * Set the length of variables declared using
     * the default "real" nor "complex". 
     *
     **/
    public void setRealLength(RealLength real_length) {this.real_length = real_length;}

    private DoubleLength double_length;
    /**
     * Return the length of variables declared using
     * the default "double precision". 
     *
     **/
    public DoubleLength getDoubleLength() {return double_length;}

    /**
     * Set the length of variables declared using
     * the default "double precision". 
     *
     **/
    public void setDoubleLength(DoubleLength double_length) {this.double_length = double_length;}

    private FortranSourceForm source_form;
    /**
     * Return the form of the source code.
     *
     **/
    public FortranSourceForm getSourceForm() {return source_form;}

    /**
     * Set the form of the source code.
     *
     **/
    public void setSourceForm(FortranSourceForm source_form) {this.source_form = source_form;}

    private PreprocessLevel preprocess;
    /**
     * Return the level of source code preprocessing to use (if any).
     *
     **/
    public PreprocessLevel getPreprocessLevel() {return preprocess;}

    /**
     * Set the level of source code preprocessing to use (if any).
     *
     * @since AJO 3
     *
     **/
    public void setPreprocessLevel(PreprocessLevel preprocess) {this.preprocess = preprocess;}

    private OptionSet defines;
    /**
     * Define the pre-processor tokens (-D) (if preprocessing). 
     *
     * @since AJO 3
     *
     **/
    public OptionSet getDefines() {return defines;}

    /**
     * Change the set of preprocessing tokens. Overwrites previous values.
     *
     * @since AJO 3
     *
     **/
    public void setDefines(OptionSet defines) {this.defines = defines;}

    /**
     * Add to the set of preprocessing tokens. 
     *
     * @since AJO 3
     *
     **/
    public void addDefine(Option define) {
        if(defines == null) defines = new OptionSet();
        if(!defines.isIn(define)) defines.add(define);
    }

    private OptionSet undefines;
    /**
     * Define the pre-processor undefines (-U) (if preprocessing) 
     *
     * @since AJO 3
     *
     **/
    public OptionSet getUndefines() {return undefines;}

    /**
     * Change the set of preprocessing undefines. Overwrites previous values.
     *
     * @since AJO 3
     *
     **/
    public void setUnDefines(OptionSet undefines) {this.undefines = undefines;}

    /**
     * Add to the set of preprocessing undefines. 
     *
     * @since AJO 3
     *
     **/
    public void addUnDefine(Option undefine) {
        if(undefines == null) undefines = new OptionSet();
        if(!undefines.isIn(undefine)) undefines.add(undefine);
    }

    private Portfolio preprocess_files;
    /**
     * Return the files created by the preprocessor.
     *
     * @since AJO 3
     *
     **/
    public Portfolio getPreprocessedFiles() {
        if(preprocess.equals(PreprocessLevel.NONE)) {
            return null;
        }
        else {
            if(preprocess_files == null) preprocess_files = new Portfolio("preprocess");
            return preprocess_files;
        }
    }

}
//
// Change history:
//          18 Mar 2002 SvdB V4 no arg constructor
//           5 May 2000 SvdB V3.0 
//           7 Dec 1998 SvdB Second release to Unicore 
//          04 Nov 1998 SvdB Added Includes field 
//          12 Jun 1998 SvdB Initial release to Unicore 
//
//             Copyright (c) UNICORE Forum e.V. 2000 - 2002
//
//     Use and distribution is subject to the Community Source Licence.
//     A copy of the Community Source Licence came with this distribution.
//
//     Further information can be obtained from www.unicore.org
