package org.unicore.ajo;

import org.unicore.PortfolioIdentifier;
import org.unicore.AJOIdentifier;

import org.unicore.sets.ResourceSet;

/**
 * Copy a Portfolio from another Uspace to the local Uspace.
 * <p>
 * The destination of the  Portfolio is in the Uspace of the containing AJO, the path
 * to the Portfolio is given in the instance of {@link org.unicore.resources.USpace}
 * (default root of the Uspace).  The source of the Portfolio is given
 * by the instance of {@link org.unicore.resources.Spool} or 
 * {@link org.unicore.resources.AlternativeUspace} (default is Spool).
 * <p>
 * The remote Uspace is on the same Vsite.
 *
 * @see org.unicore.outcome.GetPortfolio_Outcome
 *
 * @author S. van den Berghe (fecit)
 *
 * @since AJO 3
 *
 * @version GetPortfolio.java 1.10 09/18/02 
 **/
public final class GetPortfolio extends FileTransfer {

    static final long serialVersionUID = 3391469352125198878L;

    /**
     * Create a new GetPortfolio.
     * <p>
     * @param name The name of the GetPortfolio
     * @param extra_information Client supplied extra information about the GetPortfolio
     * @param resources Resources needed to execute the GetPortfolio
     * @param source_portfolio The Portfolio to copy
     * @param source_uspace Uspace containg the Portfolio to copy
     *
     * @deprecated AJO 4.0 Uspace is set by the AlternativeUspace resource
     *
     **/
    public GetPortfolio( String name,
                         byte[] extra_information,
                         ResourceSet resource_limits,
                         PortfolioIdentifier source_portfolio,
                         AJOIdentifier source_uspace
                               ) {

        super(name,extra_information,resource_limits);

        this.source_portfolio = source_portfolio;
        this.source_uspace = source_uspace;
        this.overwrite = overwrite;
    }

    /**
     * Create a new GetPortfolio.
     * <p>
     * @param name The name of the GetPortfolio
     * @param resources Resources needed to execute the GetPortfolio
     * @param source_portfolio The Portfolio to copy
     * @param source_uspace Uspace containg the Portfolio to copy
     *
     * @deprecated AJO 4.0 Uspace is set by the AlternativeUspace resource
     *
     **/
    public GetPortfolio( String name,
                         ResourceSet resource_limits,
                         PortfolioIdentifier source_portfolio,
                         AJOIdentifier source_uspace
                               ) {

        this(name,(byte[]) null ,resource_limits, source_portfolio, source_uspace);
    }

    /**
     * Create a new GetPortfolio.
     * <p>
     * @param name The name of the GetPortfolio
     * @param extra_information Client supplied extra information about the GetPortfolio
     * @param resources Resources needed to execute the GetPortfolio
     * @param source_portfolio The Portfolio to copy
     * @param source_uspace Uspace containing the Portfolio to copy
     * @param overwrite Whether the copied files should overwrite any existing files
     *
     **/
    public GetPortfolio( String name,
                         byte[] extra_information,
                         ResourceSet resource_limits,
                         PortfolioIdentifier source_portfolio,
                         boolean overwrite
                               ) {

        super(name,extra_information,resource_limits);

        this.source_portfolio = source_portfolio;
    }

    /**
     * Create a new GetPortfolio.
     * <p>
     * @param name The name of the GetPortfolio
     * @param resources Resources needed to execute the GetPortfolio
     * @param source_portfolio The Portfolio to copy
     * @param source_uspace Uspace containing the Portfolio to copy
     * @param overwrite Whether the copied files should overwrite any existing files
     *
     **/
    public GetPortfolio( String name,
                         ResourceSet resource_limits,
                         PortfolioIdentifier source_portfolio,
                         boolean overwrite
                               ) {

        this(name,(byte[]) null ,resource_limits, source_portfolio, overwrite);
    }

    /**
     * Create a new GetPortfolio.
     * <p>
     * @param name The name of the GetPortfolio
     *
     **/
    public GetPortfolio(String name) {
        this(name,(byte[]) null , (ResourceSet) null, (PortfolioIdentifier) null, false);
    }

    public GetPortfolio() {
        this("");
    }

    private PortfolioIdentifier source_portfolio;
    /**
     * Return the identifier of the Portfolio to fetch.
     *
     **/
    public PortfolioIdentifier getSource() {return source_portfolio;}

    /**
     * Set the identifier of the Portfolio to fetch.
     *
     **/
    public void setSource(PortfolioIdentifier source_portfolio) {
        this.source_portfolio = source_portfolio;
    }

    private AJOIdentifier source_uspace;
    /**
     * Return the identifier of the Uspace in which to find
     * the source Portfolio. 
     *
     * @deprecated AJO 4.0 Uspace is set by the AlternativeUspace resource
     *
     **/
    public AJOIdentifier getSourceUspace() {return source_uspace;}

    /**
     * Set the identifier of the Uspace in which to find
     * the source Portfolio. 
     *
     * @deprecated AJO 4.0 Uspace is set by the AlternativeUspace resource
     *
     **/
    public void setSourceUspace(AJOIdentifier source_uspace) {
        this.source_uspace = source_uspace;
    }

    private Portfolio target;
    /**
     * Return the Portfolio created by the execution of this task.
     *
     **/
    public Portfolio getTarget() {
        if(target == null) target = new Portfolio("GetPortfolio-"+getName());
        return target;
    }

    public void setTarget(Portfolio p) {
        target = p;
    }

    boolean overwrite;
    /**
     * Overwrite existing destination files?
     * <p>
     * If no overwriting is allowed (this method returns false), then the GetPortfolio will
     * fail if the copy would overwrite an existing file. If the Portfolio refers to a
     * directory, then the test will be applied to each file in the directory (that
     * is, writing files into existing directories is always allowed).
     * <p>
     * Overwriting existing files or writing into existing directories is always
     * subject to permissions on the existing files or directories and the task
     * will fail if there is no suitable write permission.
     *
     **/
    public boolean willOverwrite() {return overwrite;}

    /**
     * Set overwrite policy.
     *
     **/
    public void setOverwrite(boolean overwrite) {this.overwrite = overwrite;}

}
//
// Change history
//          3 Jul 2002 SvdB Added setTarget() to emulate CopySpool/UnSpool better
//         18 Mar 2002 SvdB V4 no arg constructor, etc
//         12 Jun 2000 SvdB renamed getSourcePortfolio to getSource etc, more consistent?
//          5 May 2000 SvdB Created 
//
//             Copyright (c) UNICORE Forum e.V. 2000 - 2002
//
//     Use and distribution is subject to the Community Source Licence.
//     A copy of the Community Source Licence came with this distribution.
//
//     Further information can be obtained from www.unicore.org
