package org.unicore.ajo;

import org.unicore.sets.ResourceSet;

/**
 * Create a symbolic link from a file to the AbstractAction's current
 * Uspace directory.
 * <p>
 * For details of where the target and link are located see {@link FileAction}
 * <p>
 * The link is always in Uspace, the target file can be in Xspace.
 *
 * @see org.unicore.outcome.SymbolicLink_Outcome
 *
 * @author S. van den Berghe (fecit)
 *
 * @since AJO 4.0
 *
 * @version SymbolicLink.java 1.3 09/09/02  
 * 
 **/
public final class SymbolicLink extends FileAction {

    static final long serialVersionUID = 0;

    /**
     * Create a new SymbolicLink.
     * <p>
     * @param name The name of SymbolicLink
     * @param extra_information Client supplied extra information about the SymbolicLink
     * @param resources Resources needed to execute the SymbolicLink
     * @param target The name of the target of the link
     * @param link The link
     * @param overwrite Should the symbolic link overwrite the target
     *
     **/
    public SymbolicLink( String name,
                         byte[] extra_information,
                         ResourceSet resources,
                         String target,
                         String link,
                         boolean overwrite
                       ) {

        super(name,extra_information,resources);

        this.target = target;
        this.link = link;
        this.overwrite = overwrite;
    }

    /**
     * Create a new SymbolicLink.
     * <p>
     * @param name The name of SymbolicLink
     * @param resources Resources needed to execute the SymbolicLink
     * @param target The name of the target of the link
     * @param link The link
     * @param overwrite Should the symbolic link overwrite the target
     *
     **/
    public SymbolicLink( String name,
                         ResourceSet resource_limits,
                         String target,
                         String link,
                         boolean overwrite
                       ) {

        this(name,(byte[]) null, resource_limits, target, link, overwrite);
    }

    /**
     * Create a new SymbolicLink.
     * <p>
     * @param name The name of SymbolicLink
     *
     **/
    public SymbolicLink(String name) {
        this(name,(byte[]) null,(ResourceSet) null, (String) null, (String) null, true);
    }

    public SymbolicLink() {
        this("");
    }

    private String target;
    /**
     *  Return name of the target file.
     *
     **/
    public String getTarget() {return target;}

    /**
     *  Set name of the target file.
     *
     **/
    public void setTarget(String target) {this.target = target;}

    private String link;
    /**
     *  Return name of the link.
     *
     **/
    public String getLink() {return link;}

    /**
     *  Set name of the link.
     *
     **/
    public void setLink(String link) {this.link = link;}

    boolean overwrite;
    /**
     * Overwrite any existing destination file?
     *
     **/
    public boolean willOverwrite() {return overwrite;}

    /**
     * Set overwrite policy.
     *
     **/
    public void setOverwrite(boolean overwrite) {this.overwrite = overwrite;}

}
//
// Change history:
//          12 Apr 2002 SvdB Created
//
//             Copyright (c) UNICORE Forum e.V. 2000
//
//     Use and distribution is subject to the Community Source Licence.
//     A copy of the Community Source Licence came with this distribution.
//
//     Further information can be obtained from www.unicore.org
