package org.unicore.idiomatic;

/**
 * Marker for all Idiomatic actions.
 * <p>
 * An idiomatic action is a commonly performed task.
 * The contract for the task and interface to its execution
 * are expressed in the definition of the
 * Idiomatic class.
 * <p>
 * An idiomatic action also contains an <em>implementation</em> of the
 * contract as a DAG of AbstractActions that 
 * performs the required task.
 * <p>
 * An NJS can execute the idiomatic action by executing
 * the AbstractActions in the idiomatic action's DAG or,
 * if the NJS has been appropriately written, by any other means
 * that meet the stated contract.
 * <p>
 * For example, the {@link Transfer} idiomatic action describes
 * the transfer of a Portfolio from a Uspace to another Uspace
 * on a remote Vsite. It also contains an implementation of this
 * contract which an NJS could use to execute the Transfer.
 * However, a clever NJS could recognise
 * when both Vsites were on the same Usite and use a direct
 * Upsace to Uspace copy insttead of the DAG in the Idiomatic action.
 *
 * @author S. van den Berghe (fecit)
 *
 * @since AJO 3
 *
 * @version Idiomatic.java 1.5 05/13/02 <br>
 * 
 **/
public interface Idiomatic {

}
//
//  Change history:
//          16 Nov 2000 SvdB Made an interface
//          15 May 2000 SvdB Created
//
//             Copyright (c) UNICORE Forum e.V. 2000 - 2002
//
//     Use and distribution is subject to the Community Source Licence.
//     A copy of the Community Source Licence came with this distribution.
//
//     Further information can be obtained from www.unicore.org
