package org.unicore.idiomatic;

import org.unicore.*;
import org.unicore.ajo.*;
import org.unicore.resources.*;

/**
 * Copy a file from one Vsite to another 
 *
 * @author S. van den Berghe (fecit)
 *
 * @since AJO 4.0
 *
 * @version TransferFile.java 1.4 04/17/03 <br>
 * 
 **/
public class TransferFile extends StreamFile {

    /**
     * Create a new TransferFile  to copy the file between Vsites
     *
     * @param name A name for the TransferFile
     * @param extra_information Storage for data from the creator of this TransferFile
     * @param sso security object
     * @param endorser The endorser of the AJO (see {@link org.unicore.ajo.AbstractJob#setEndorser})
     * @param source_file The file to be copied
     * @param source_storage The {@link org.unicore.resources.Storage} where the file can be found
     * @param target_file The destination file name
     * @param target_storage The {@link org.unicore.resources.Storage} where the file is placed
     * @param target_vsite The destination Vsite
     * @param overwrite Should the target overwrite an existing to file
     *
     **/
    public TransferFile( String name,
                     byte[] extra_information,
                     byte[] sso, 
                     User endorser,
                     String source_file,
                     PathedStorage source_storage,
                     String target_file,
                     PathedStorage target_storage,
                     Vsite target_vsite,
                     boolean overwrite
                   ) {
        super(name,extra_information,sso,endorser,source_file,source_storage,target_file,target_storage,target_vsite,overwrite);
    }

    public TransferFile() {
        this("", (byte[]) null, (byte[]) null, (User)null, (String) null, 
                  (PathedStorage) null, (String) null, (PathedStorage) null, (Vsite) null, false);
    }

    public CopyFile getImport() {return super.getImport();}

    public DeleteFile getDelete() {return super.getDelete();}

    public PathedStorage getSourceStorage() {
        return super._getSourceStorage();
    }

    public void setSourceStorage(PathedStorage source_storage) {
        super._setSourceStorage(source_storage);
    }

    public PathedStorage getTargetStorage() {
        return super._getTargetStorage();
    }

    public void setTargetStorage(PathedStorage target_storage) {
        super._setTargetStorage(target_storage);
    }

    static final long serialVersionUID = 400;
}
//
//  Change history:
//          04 Apr 2003 SvdB Now parented by StreamFile
//          23 Apr 2002 SvdB Created
//
//             Copyright (c) UNICORE Forum e.V. 2002
//
//     Use and distribution is subject to the Community Source Licence.
//     A copy of the Community Source Licence came with this distribution.
//
//     Further information can be obtained from www.unicore.org
