package org.unicore.outcome;

import org.unicore.ajo.AbstractTask;

import org.unicore.sets.ResourceSet;

/**
 * The results of executing an {@link org.unicore.ajo.AbstractTask}.
 * <p>
 * AbstractTasks can be executed on the target system (compared to
 * ,say, ControlServices which are executed solely on the NJS) and so
 * have further information to report to the user. This information
 * includes the resources consumed by the execution of the AbstractTask
 * and the identifier given to the job executing the AbstractTask by
 * the BSS.
 *
 * @see org.unicore.ajo.AbstractTask
 *
 * @author S. van den Berghe (fecit)
 *
 * @since AJO 2
 *
 * @version AbstractTask_Outcome.java 1.5 05/13/02 
 * 
 **/
public abstract class AbstractTask_Outcome extends Outcome {

    static final long serialVersionUID = 7419049551417149919L;

    /**
     * Create a new AbstractTask_Outcome.
     * <p>
     * This will hold the standard information from {@link Outcome}
     * plus information derived from the execution of the AbstractTask's
     * execution on the target system such as the BSS identifier (if any)
     * and a statement of the resources consumed by the job.
     *
     * @param source The AbstractTask for which this Outcome will hold the results.
     * @param initial The status of the AbstractTask at the time that the Outcome is created.
     *
     **/
    protected AbstractTask_Outcome(AbstractTask         task,
                                   AbstractActionStatus initial_status) {
                      
        super(task, initial_status);

        resources_consumed = new ResourceSet();
    }

    private ResourceSet resources_consumed;
    /**
     * Return the description of the resources used by the
     * AbstractTask during its execution.
     * <p>
     * This is not as yet supported by all NJSs.
     *
     **/
    public ResourceSet getResources() {return resources_consumed;}

    private String bss_id;
    /**
     * Get the identifier assigned to the AbstractTask's incarnation
     * by the BSS on the target machine (if any).
     * <p>
     * Some AbstractTasks will be executed on the target machine
     * and if the target machine's BSS supplies an identifier, then it will be recorded
     * here. AbstractTasks may not be executed under the control of
     * an external BSS (this is a choice made by the NJS) and so
     * this field may be null.
     *
     **/
    public String getBSSid() {return bss_id;}

    /**
     * Set the BSS identifier for the AbstractTask's incarnation.
     *
     **/
    public void setBSSid(String bss_id) {this.bss_id = bss_id;}


}
//
// Change history:
//          20 Dec 2000 SvdB Removed clone method
//           5 May 2000 SvdB V3.0, added BSS id field 
//          10 Dec 1998 SvdB Made abstract class 
//           7 Dec 1998 SvdB Second release to Unicore 
//           6 Nov 1998 SvdB Created 
//
//             Copyright (c) UNICORE Forum e.V. 2000 - 2002
//
//     Use and distribution is subject to the Community Source Licence.
//     A copy of the Community Source Licence came with this distribution.
//
//     Further information can be obtained from www.unicore.org
