package org.unicore.outcome;

import org.unicore.ajo.CopyActionOutcome;

import org.unicore.AAIdentifier;

/**
 * The result of executing a {@link org.unicore.ajo.CopyActionOutcome}
 * which is a copy of the target's Outcome.
 *
 * @see org.unicore.ajo.CopyActionOutcome
 *
 * @author S. van den Berghe (fecit)
 *
 * @since AJO 2
 *
 * @version CopyActionOutcome_Outcome.java 1.6 05/13/02 
 * 
 **/
public class CopyActionOutcome_Outcome extends AbstractService_Outcome {

    static final long serialVersionUID = 8128456215244143551L;

    protected Outcome outcome;
    protected AAIdentifier target_id;

    public CopyActionOutcome_Outcome() {
        this(null, null);
    }

    /**
     * Create a new CopyActionOutcome_Outcome.
     * <p>
     * This will hold the standard information from {@link Outcome}
     * plus a copy of the target's Outcome.
     *
     * @param source The CopyActionOutcome for which this Outcome will hold the results.
     * @param initial The status of the CopyActionOutcome at the time that the Outcome is created.
     *
     **/
    public CopyActionOutcome_Outcome( CopyActionOutcome    source,
                                      AbstractActionStatus initial_status
                                      ) {
        super(source, initial_status);
    }

    /**
     * Return the copy of the target's Outcome.
     *
     **/
    public Outcome getOutcome() {return outcome;}

    /**
     * Set the copy of the target's Outcome.
     *
     **/
    public void setOutcome(Outcome o) {outcome = o;}

    /**
     * Return the Identifier of the target AbstractAction.
     *
     **/
    public AAIdentifier getActionIdentifier() {return target_id;}

    /**
     * Set the Identifier of the target AbstractAction.
     *
     **/
    public void setActionIdentifier(AAIdentifier i) {target_id = i;}


}
//
// Change history:
//          18 Mar 2002 SvdB V4 no arg constructor
//          15 feb 2001 SvdB Added record of target Id
//          20 Dec 2000 SvdB Removed clone method
//           5 May 2000 SvdB V3.0 
//          10 Dec 1998 SvdB Constructor to public 
//           7 Dec 1998 SvdB Second release to Unicore 
//           6 Nov 1998 SvdB Created 
//
//             Copyright (c) UNICORE Forum e.V. 2000 - 2002
//
//     Use and distribution is subject to the Community Source Licence.
//     A copy of the Community Source Licence came with this distribution.
//
//     Further information can be obtained from www.unicore.org
