package org.unicore.outcome;

import org.unicore.ajo.GetJobs;

import org.unicore.sets.AJOIdentifierSet;

import org.unicore.AJOIdentifier;

/**
 * The results of executing a {@link org.unicore.ajo.GetJobs}.
 * <p>
 * This returns the AJOs owned by the user that were known to
 * the Vsite at the time of execution of this AbstractService.
 *
 * @see org.unicore.ajo.GetJobs
 *
 * @author S. van den Berghe (fecit)
 *
 * @since AJO 2
 *
 * @version GetJobs_Outcome.java 1.6 05/13/02 
 * 
 **/
public class GetJobs_Outcome extends AbstractService_Outcome {

    static final long serialVersionUID = 2837589080230954362L;

    protected AJOIdentifierSet jobs;

    public GetJobs_Outcome() {
        this(null,null);
    }

    /**
     * Create a new GetJobs_Outcome.
     * <p>
     * This will hold the standard information from {@link Outcome}
     * plus a list of AJO Identifiers.
     *
     * @param source The GetJobs for which this Outcome will hold the results.
     * @param initial The status of the GetJobs at the time that the Outcome is created.
     *
     **/
    public GetJobs_Outcome( GetJobs              source,
                            AbstractActionStatus initial_status
                            ) {
        super(source, initial_status);

        jobs = new AJOIdentifierSet();
    }

    /**
     * Return the set of AbstractJobs that were consigned to the Vsite
     * by the consigner of this AbstractAction.
     *
     **/
    public AJOIdentifierSet getJobs() {return jobs;}

    /**
     * Set the set of AbstractJobs that were consigned to the Vsite
     * by the consigner of this AbstractAction.
     *
     **/
    public void setJobs(AJOIdentifierSet jobs) {this.jobs = jobs;}


    /**
     * Add an AbstractJob to the set of AbstractJobs that were consigned to the Vsite
     * by the consigner of this AbstractAction.
     *
     **/
    public void addJob(AJOIdentifier job) {jobs.add(job);}

}
//
// Change history:
//          18 Mar 2002 SvdB V4 no arg constructor
//           8 Jan 2001 SvdB Added setJobs, addJob methods
//          20 Dec 2000 SvdB Removed clone method
//           5 May 2000 SvdB V3.0 
//          10 Dec 1998 SvdB Constructor to public 
//           7 Dec 1998 SvdB Second release to Unicore 
//           6 Nov 1998 SvdB Created 
//
//             Copyright (c) UNICORE Forum e.V. 2000 - 2002
//
//     Use and distribution is subject to the Community Source Licence.
//     A copy of the Community Source Licence came with this distribution.
//
//     Further information can be obtained from www.unicore.org
