package org.unicore.outcome;

import org.unicore.Unicore;

import org.unicore.ajo.AbstractAction;
import org.unicore.AAIdentifier;

/**
 * An IfSuccess_Outcome contains the results 
 * of the taken branch of an IfSuccess action.
 * <p>
 * @see org.unicore.ajo.IfSuccess
 *
 * @author David F. Snelling (fecit)
 *
 * @since AJO 3.2
 *
 * @version IfSuccess_Outcome.java 1.2 07/11/02
 * 
 **/
public class IfSuccess_Outcome extends ConditionalAction_Outcome {
 
    public IfSuccess_Outcome() {
        this((AbstractAction)null,null);
    }

    /**
     * Create a new IfSuccess_Outcome.
     * <p>
     * @param source The IfSuccess for which this Outcome will hold the results.
     * @param initial The status of the IfSuccess at the time that the Outcome is created
     *
     **/
    public IfSuccess_Outcome(AbstractAction source, AbstractActionStatus initial) {
      super (source, initial);
    }

    /**
     * Create a new IfSuccess_Outcome.
     * <p>
     * @param source_id The AAIdentifier of the IfSuccess for which this Outcome will hold the results.
     * @param initial The status of the IfSuccess at the time that the Outcome is created
     *
     **/
    public IfSuccess_Outcome(AAIdentifier source_id, AbstractActionStatus initial) {
      super (source_id, initial);
    }

    /**
     * Return true if the success branch of the If action was taken.
     * <p>
     * @return Boolean.TRUE if the success branch was taken, Boolean.FALSE if the not success
     *         branch was taken and null otherwise (not yet executed or did not run)
     *
     **/
    public Boolean successTaken () {
        if(getTakenOutcome() == null) return null;
        if(getTakenOutcome() == true_branch_outcome)  return Boolean.TRUE;
        if(getTakenOutcome() == false_branch_outcome) return Boolean.FALSE;
        return null;
    }

}
//
// Change History:
//           7 jul 2002 SvdB Changed successTaken to refer to results
//          18 Mar 2002 SvdB V4 no arg constructor
//          31 Jan 2001 DFS Created
//
//             Copyright (c) UNICORE Forum e.V. 2000 - 2002
//
//     Use and distribution is subject to the Community Source Licence.
//     A copy of the Community Source Licence came with this distribution.
//
//     Further information can be obtained from www.unicore.org
