package org.unicore.outcome;

import org.unicore.ajo.ListDirectory;

import org.unicore.sets.XFileSet;

/**
 * The result of executing a {@link org.unicore.ajo.ListDirectory}.
 * <p>
 * The result is a listing of the files in the requested directory
 * cast into a seamless form.
 *
 * @see org.unicore.ajo.ListDirectory
 * @see XFile
 * @see XDirectory
 *
 * @author S. van den Berghe (fecit)
 *
 * @since AJO 3
 *
 * @version ListDirectory_Outcome.java 1.10 05/13/02 
 * 
 **/
public final class ListDirectory_Outcome extends AbstractTask_Outcome {

    static final long serialVersionUID = 4086188496514399445L;

    protected XFileSet listing;

    public ListDirectory_Outcome() {
        this(null,null);
    }

    /**
     * Create a new ListDirectory_Outcome.
     * <p>
     * This will hold the standard information from {@link Outcome}
     * plus the directory listing.
     *
     * @param source The ListDirectory for which this Outcome will hold the results.
     * @param initial The status of the ListDirectory at the time that the Outcome is created.
     *
     **/
    public ListDirectory_Outcome( ListDirectory source, AbstractActionStatus initial ) {
        super(source, initial);
    }
    
    /**
     * Get the listing.
     * <p>
     * The listing is either the information for a single file
     * or for a directory depending on the list request.
     *
     **/
    public XFileSet getListing() {return listing;}
    
    /**
     * Set the listing.
     *
     **/
    public void setListing(XFileSet listing) { 
        this.listing = listing;
    }

}
//
// Change history:
//          18 Mar 2002 SvdB V4 no arg constructor
//          23 Apr 2001 SvdB Returns XFileSet
//          20 Dec 2000 SvdB Removed clone method
//           1 Aug 2000 SvdB Should have been XFile (to allow lists of single files),
//                           Constructor to public
//          13 Jun 2000 SvdB Keeps an XDirectory, not separate bits
//           5 May 2000 SvdB Created 
//
//             Copyright (c) UNICORE Forum e.V. 2000 - 2002
//
//     Use and distribution is subject to the Community Source Licence.
//     A copy of the Community Source Licence came with this distribution.
//
//     Further information can be obtained from www.unicore.org
