package org.unicore.outcome;

import org.unicore.ajo.Portfolio;

import org.unicore.ajo.Spool;

/**
 * The status and logs of executing an {@link org.unicore.ajo.Spool}.
 * <p>
 * This also reports the names of the files written to the 
 * spool area.
 *
 * @see org.unicore.ajo.Spool
 *
 * @author S. van den Berghe (fecit)
 * 
 * @since AJO 3.2
 *
 * @version Spool_Outcome.java 1.4 05/13/02 
 * 
 **/
public class Spool_Outcome extends AbstractTask_Outcome {

    static final long serialVersionUID = 1855796385527558189L;

    public Spool_Outcome() {
        this(null,null);
    }

    /**
     * Create a new Spool_Outcome.
     * <p>
     * This will hold the standard information from {@link Outcome}.
     *
     * @param source The Spool for which this Outcome will hold the results.
     * @param initial The status of the Spool at the time that the Outcome is created.
     *
     **/
    public Spool_Outcome( Spool source,
                          AbstractActionStatus initial_status
                        ) {
        super(source, initial_status); 
    }

    String[] written_files;

    /**
     * Get the list of file names 
     * written by the Spool.
     *
     **/
    public String[] getWrittenFiles() {return written_files;}

    /**
     * Set the list of file names 
     * written by the Spool.
     *
     **/
    public void setWrittenFiles(String[] files) {written_files = files;}

    /**
     * Add a file name to the list of files
     * written by the Spool.
     *
     **/
    public void addWrittenFile(String file) {
        if(written_files == null) {
            written_files = new String[1];
            written_files[1] = file;
        }
        else {
            String[] temp = new String[written_files.length+1];
            System.arraycopy(written_files,0,temp,0,written_files.length);
            temp[written_files.length] = file;
            written_files = temp;
        }
    }

    private Portfolio portfolio;
    /**
     * The Portfolio that was Spooled
     *
     **/
    public Portfolio getPortfolio() {return portfolio;}

    public void setPortfolio(Portfolio portfolio) {this.portfolio = portfolio;}


}
//
// Change history:
//          18 Mar 2002 SvdB V4 no arg constructor
//          20 Mar 2001 SvdB Added Portfolio
//          30 Jan 2001 SvdB Created 
//
//             Copyright (c) UNICORE Forum e.V. 2000 - 2002
//
//     Use and distribution is subject to the Community Source Licence.
//     A copy of the Community Source Licence came with this distribution.
//
//     Further information can be obtained from www.unicore.org
