package org.unicore.resources;

/**
 * Resource for the Nodes of a message passing cluster. 
 * <p>
 * A Node consists of a number of {@link Processor}.
 * <p>
 * If no Node resource is present, the default value for the site is used.
 *
 * @author D. Snelling (fecit)
 * @author S. van den Berghe (fecit)
 *
 * @since AJO 3
 *
 * @version Node.java 1.11 11/29/02
 *
 **/
public final class Node extends CapacityResource {

    static final long serialVersionUID = -6500767267386670270L;

    public Node () {
        this("",0.0,0.0,0.0);
    }

    /**
     * Create a new Node.
     * <p>
     * Sets the units to "Nodes"
     *
     * @param description A description ofthe Node
     * @param maxrequest Maximum amount of resource allowed
     * @param defaultrequest Amount of resource granted if no specific request received
     * @param minrequest Minimum amount of resource allowed
     *
     **/
    public Node (String description, 
                 double maxrequest,
                 double defaultrequest,
                 double minrequest) {
        super(description, maxrequest, defaultrequest, minrequest);
        this.units = "Nodes";
    }

    public String toString() {
        return "Node";
    }
}
//
// Change history:
//          15 Mar 2002 SvdB V4, no arg constructor
//          14 Aug 2000 DFS Added minimum request.
//          21 Jan 2000 DFS  First release with V3.0 resource model.
//
//             Copyright (c) UNICORE Forum e.V. 2000 - 2002
//
//     Use and distribution is subject to the Community Source Licence.
//     A copy of the Community Source Licence came with this distribution.
//
//     Further information can be obtained from www.unicore.org
