package org.unicore.resources;

import java.util.*;

/**
 * Class to provide resource booking capability. 
 * <p>
 * The presence of this
 * resource in a Resource Description indicates that the site supports
 * resource booking. 
 * <p>
 * To book a resource, a {@link org.unicore.ajo.BookResources} must
 * be sent to the site with the resource set required. 
 * The outcome of the BookResources contains an instance of this class with
 * a booking reference that will be recognised by the site that booked the resource.
 * <p>
 * A Task claiming a booking includes an instance of this class in its 
 * Resource Request.
 * <p>
 * A booking can only be claimed by the User who requested it.
 *
 * @author D. Snelling (fecit)
 * @author S. van den Berghe (fecit)
 *
 * @since AJO 3
 *
 * @version ResourceBooking.java 1.12 09/09/02 
 *
 **/
public final class ResourceBooking extends CapabilityResource {

    static final long serialVersionUID = -1924319318267114840L;

    /**
     * Create a new ResourceBooking.
     *
     * @param description A description
     * @param booking Date for the booking
     * @param reference Reference for the booking
     *
     **/
    public ResourceBooking (String description, Date booking, String reference) {
        super (description);
        this.booking = booking;
        setReference(reference);
    }
    
    /**
     * Create a new ResourceBooking.
     *
     **/
    public ResourceBooking() {
        super("undescibed ResourceBooking");
    }

    private Date booking;
    /**
     * Return the date and time the this booking starts. 
     *
     **/
    public  Date getBooking ()             { return booking; }

    /**
     * Set the date and time the this booking starts. 
     *
     **/
    public  void setBooking (Date booking) { this.booking = booking; }

    private String reference = "";
    /**
     * Return the refeence that identifies the booking.
     * <p>
     * This refeence is set by the site when a booking is made. It can be a 
     * random string, as long as the site recognizes it as a valid booking.
     *
     **/
    public  String getReference ()          { return reference; }

    /**
     * Set the reference that identifies the booking.
     *
     **/
    public  void setReference (String reference) { 
        if(reference == null) {
            this.reference = "";
        }
        else {
            this.reference = reference; 
        }
    }

    /**
     * ResourceBooking are equal if they have the same reference.
     * <p>
     * So all ResourceBookings without a set reference are equal to
     * each other
     *
     **/
    public boolean equals(Object o) {
        try {
            return ( o.getClass() == getClass() && reference.equals(((ResourceBooking)o).reference));
        }
        catch(NullPointerException nex) {
            return false;
        }
    }

    /**
     * Return a hash code for this ResourceBooking. 
     * <p>
     * Returns the hash code of the reference
     *
     **/
    public int hashCode() {
        return reference.hashCode();
    }

    public String toString() {
        return "ResourceBooking "+getBooking() + " " + getReference();
    }

}
//
// Change history:
//          10 May 2002 SvdB V4 long code to String reference
//          13 Jul 2000 SvdB override equals
//          21 Jan 2000  DFS First release with V3.0 resource model. 
//
//             Copyright (c) UNICORE Forum e.V. 2000 - 2002
//
//     Use and distribution is subject to the Community Source Licence.
//     A copy of the Community Source Licence came with this distribution.
//
//     Further information can be obtained from www.unicore.org
