package org.unicore.resources;

import org.unicore.ajo.Ticket;

/**
 * Advertise the capability to perform a ResourceCheck.
 * <p>
 * Class to describe a service that provides a check of exact resource
 * requirements at the site, prior to job sumbission. The presence of
 * this resource in a Resource Description indicates that the user may send a
 * {@link org.unicore.ajo.CheckResources} to the Vsite and recieve confirmation 
 * that the resources are valid at the site. This is primarily used 
 * to support complex interactions between resources at partictular sites.
 * The site must provide a service to the NJS to support this resource.
 *
 * When sent to a site, this resource contains a {@link org.unicore.ajo.Ticket}.
 * The Ticket was provided by the site in response to a
 * {@link org.unicore.ajo.CheckResources} and represents the Site's
 * commitment to run that task given that set of resources.
 *
 * @author D. Snelling (fecit)
 * @author S. van den Berghe (fecit)
 *
 * @since AJO 3.6
 *
 * @version ResourceCheck.java 1.14 09/09/02
 *
 **/
public class ResourceCheck extends CapabilityResource {

    static final long serialVersionUID = -7473248138857969844L;

    /**
     * Create a new ResourceCheck
     *
     * @param description A description of the ResourceCheck
     * @param ticket An AJO's claim for previously cehcked resources
     *
     **/
    public ResourceCheck (String description, Ticket ticket) {
        super (description);
        this.ticket = ticket;
    }

    /**
     * Create a new ResourceCheck
     *
     **/
    public ResourceCheck() {
        this("ResourceCheck", (Ticket) null);
    }

    protected Ticket ticket = null;

    /** 
     * Sets the Ticket for this ResourceCheck
     *
     * @param ticket Ticket
     *
     **/
    public void setTicket(Ticket ticket) {
        this.ticket = ticket;
    }
    
    /** 
     * Returns the ticket of this ResourceCheck
     *
     * @return Ticket
     **/
    public Ticket getTicket(){
        return this.ticket;
    }
    
    /**
     * All ResourceChecks are equal. 
     * <p>
     * <em> This may not be expected behaviour.</em>
     *
     **/
    public boolean equals(Object o) {
        try {
            return ( o.getClass() == getClass() );
        }
        catch(NullPointerException nex) {
            return false;
        }
    }

    /**
     * Return a hash code for this ResourceCheck. 
     * <p>
     * Returns the same hash code for all instances.
     *
     **/
    public int hashCode() {
        return 1414213562;
    }


    public String toString() {
        return "ResourceCheck";
    }

}
//
// Change history:
//          11 Dec 2001 DFS Created
//
//             Copyright (c) UNICORE Forum e.V. 2000 - 2002
//
//     Use and distribution is subject to the Community Source Licence.
//     A copy of the Community Source Licence came with this distribution.
//
//     Further information can be obtained from www.unicore.org
