package org.unicore.upl;

import org.unicore.AJOIdentifier;
import org.unicore.Vsite;

/**
 * A RetrieveOutcome is sent to request the Outcome of an AJO.
 * <p>
 * RetrieveOutcomes are used to poll the NJS for the status
 * of an AJO. If the AJO has not finished executing the NJS
 * sends a RetrieveOutcomeReply that contains at least a copy of the
 * current Outcome of the AJO with the status and logs of
 * all child AbstractActions but <em>without</em> any streamed data.
 * When the AJO has finished executing
 * the NJS returns the full Outcome <em>including</em> the streamed
 * data.
 *
 * @author S. van den Berghe (fecit)
 *
 * @since AJO 2.9 (AJO 2 in other versions)
 *
 * @version RetrieveOutcome.java 1.7 06/19/02  
 * 
 **/
public final class RetrieveOutcome extends ServerRequest {

    /**
     * Create an empty RetrieveOutcome
     *
     **/
    public RetrieveOutcome() {
        this(null,null,null);
    }

    /**
     * Create a RetrieveOutcome
     *
     * @param target The AJO whose Outcome is requested
     * @param vsite The Vsite where the AJO is executing
     *
     **/
    public RetrieveOutcome(AJOIdentifier target, Vsite vsite) {
        this(target,vsite,null);
    }

    /**
     * Create a RetrieveOutcome
     *
     * @param target The AJO whose Outcome is requested
     * @param vsite The Vsite where the AJO is executing
     * @param sso Security information required by the site
     *
     **/
    public RetrieveOutcome(AJOIdentifier target, Vsite vsite, byte[] sso) {
        super(target,vsite,sso);
    }

    static final long serialVersionUID = 3324124511654326368L;

}
//
// Change history:
//          15 Mar 2002 SvdB V4 changes, allows sso
//          30 Jan 2001 SvdB Removed partial Outcome retrieve
//          16 Nov 2000 SvdB Added partial Outcome retrieve
//           4 Feb 2000 SvdB Modifications for Unicore-Plus AJO 
//           7 Dec 1998 SvdB Added User field 
//           7 Dec 1998 SvdB Second release to Unicore 
//          12 Nov 1998 SvdB SvdB Created 
//
//             Copyright (c) UNICORE Forum e.V. 2000 - 2002
//
//     Use and distribution is subject to the Community Source Licence.
//     A copy of the Community Source Licence came with this distribution.
//
//     Further information can be obtained from www.unicore.org
