package org.unicore.upl;

import org.unicore.outcome.Outcome;
import java.io.*;

/**
 * A RetrieveOutcomeReply is returned in response to a 
 * {@link RetrieveOutcome} or in response to
 * a {@link ConsignJob} if the mode is not Polling
 * and the NJS has accepted this.
 *
 * @author S. van den Berghe (fecit)
 *
 * @since AJO 2.9 (AJO 2 in other versions)
 *
 * @version RetrieveOutcomeReply.java 1.5 05/13/02  
 * 
 **/

public final class RetrieveOutcomeReply extends Reply {

    /**
     * Create an empty RetrieveOutcomeReply
     *
     **/
    public RetrieveOutcomeReply() {
    }

    /**
     * Create a RetrieveOutcomeReply
     *
     * @param outcome The requested Outcome
     * @param has_streamed If true, then there are Portfolios in this reply
     *                     being sent as streamed data.
     *
     **/
    public RetrieveOutcomeReply(byte[] outcome,
                                boolean has_streamed) {
        this.outcome = outcome;
        this.has_streamed = has_streamed;
    }

    private byte[] outcome;
    /**
     * Return the requested Outcome.
     *
     **/
    public byte[] getOutcome() {return outcome;}

    /**
     * Set the requested Outcome (serialised into a byte array).
     * <p>
     * This level of serialisation stops Gateways having to
     * have access to all Outcome classes. Note that there is
     * a further level of serialisation of child Outcomes so
     * that NJSs do not need all the classes of all other NJSs
     * {@link org.unicore.utility.ConsignForm}
     *
     **/
    public void setOutcome(byte[] outcome) {this.outcome = outcome;}

    boolean has_streamed;
    /**
     * Does this retrieve have streamed data?
     *
     **/
    public boolean hasStreamed() {return has_streamed;}

    /**
     * Set whether the reply has streamed data
     *
     **/
    public void setStreamed(boolean has_streamed) {this.has_streamed = has_streamed;}

    static final long serialVersionUID = 6395511790932474234L;

}
//
// Change history:
//           4 May 2000 SvdB Changes for V3.0 
//           4 Feb 2000 SvdB Changes for Unicore-Plus 
//          11 Jan 1999 SvdB Redefine to allowed failed requests 
//          17 Dec 1998 SvdB Proper definition 
//           7 Dec 1998 SvdB Second release to Unicore 
//           3 Dec 1998 SvdB Created 
//
//             Copyright (c) UNICORE Forum e.V. 2000 - 2002
//
//     Use and distribution is subject to the Community Source Licence.
//     A copy of the Community Source Licence came with this distribution.
//
//     Further information can be obtained from www.unicore.org
